'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d0e7980b.js');
const slot = require('./slot-0257c52f.js');
const scroll = require('./scroll-3d693a27.js');
const popover = require('./popover-066523ca.js');
const iconLibraryRegistry = require('./icon-library-registry-72cc3e12.js');
const focusVisible = require('./focus-visible-ca12186c.js');

const alertCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:contents;margin:0}.alert{position:relative;display:flex;align-items:stretch;background-color:var(--xena-color-white);border:solid 1px var(--xena-color-gray-300);border-top-width:3px;border-radius:var(--xena-border-radius-medium);box-shadow:var(--box-shadow);font-family:var(--xena-font-sans);font-size:var(--xena-font-size-medium);font-weight:var(--xena-font-weight-normal);line-height:var(--xena-line-height-normal);color:var(--xena-color-gray-700);opacity:0;transform:scale(0.9);transition:var(--xena-transition-medium) opacity ease, var(--xena-transition-medium) transform ease;margin:inherit}.alert:not(.alert--visible){position:absolute;width:1px;height:1px;clip:rect(0 0 0 0);clip-path:inset(50%);overflow:hidden;pointer-events:none;visibility:hidden}.alert--open{opacity:1;transform:none}.alert__icon{flex:0 0 auto;display:flex;align-items:center;font-size:var(--xena-font-size-large)}.alert__icon ::slotted(*){margin-left:var(--xena-spacing-medium)}.alert__action{flex:0 0 auto;display:flex;align-items:center}.alert__action ::slotted(*){margin-right:var(--xena-spacing-medium)}.alert--primary{border-top-color:var(--xena-color-blue-500)}.alert--primary .alert__icon{color:var(--xena-color-blue-500)}.alert--success{border-top-color:var(--xena-color-green-500)}.alert--success .alert__icon{color:var(--xena-color-green-500)}.alert--info{border-top-color:var(--xena-color-cool-500)}.alert--info .alert__icon{color:var(--xena-color-cool-500)}.alert--warning{border-top-color:var(--xena-color-yellow-500)}.alert--warning .alert__icon{color:var(--xena-color-yellow-500)}.alert--danger{border-top-color:var(--xena-color-red-500)}.alert--danger .alert__icon{color:var(--xena-color-red-500)}.alert__message{flex:1 1 auto;padding:var(--xena-spacing-medium);overflow:hidden}.alert__message .alert__header{font-weight:var(--xena-font-weight-bold)}.alert__close{flex:0 0 auto;display:flex;align-items:center;font-size:var(--xena-font-size-large);margin-right:var(--xena-spacing-medium)}.alert__close xena-icon-button::part(base){color:var(--xena-color-gray-300)}.alert__close xena-icon-button::part(base):hover{color:var(--xena-color-gray-600)}.alert--remove-borders{border-right-width:0;border-bottom-width:0;border-left-width:0}.alert--inline{border-width:0 0 0 3px;border-radius:3px}.alert--inline .alert__icon{position:absolute;left:-0.55em;top:calc(50% - 0.5em);background-color:white;border-radius:50%}.alert--inline .alert__icon ::slotted(*){margin-left:0}.alert--inline .alert__message{padding:var(--xena-spacing-x-small) var(--xena-spacing-medium);line-height:var(--xena-line-height-dense)}.alert--inline.alert--primary{border-left-color:var(--xena-color-blue-500)}.alert--inline.alert--success{border-left-color:var(--xena-color-green-500)}.alert--inline.alert--info{border-left-color:var(--xena-color-cool-500)}.alert--inline.alert--warning{border-left-color:var(--xena-color-yellow-500)}.alert--inline.alert--danger{border-left-color:var(--xena-color-red-500)}";

const notificationStack = Object.assign(document.createElement('div'), { className: 'xena-notification-stack' });
let Alert = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.xnShow = index.createEvent(this, "xnShow", 7);
    this.xnAfterShow = index.createEvent(this, "xnAfterShow", 7);
    this.xnHide = index.createEvent(this, "xnHide", 7);
    this.xnAfterHide = index.createEvent(this, "xnAfterHide", 7);
    this.isVisible = false;
    this.hasActionSlot = false;
    /** Indicates whether or not the alert is open. You can use this in lieu of the show/hide methods. */
    this.open = false;
    /** Set to true to make the alert closable. */
    this.closable = false;
    /**
     * @internal - property hidden from public API
     * Set to true to remove any borders except coloured border for the type of the alert. Ie. for usage in modals with no header and no body padding.
     */
    this.removeBorders = false;
    /** The type of alert. */
    this.type = 'primary';
    /** Set to true to make the alert inline. */
    this.inline = false;
    /**
     * The length of time, in milliseconds, the alert will show before closing itself. If the user interacts with the
     * alert before it closes (e.g. moves the mouse over it), the timer will restart.
     */
    this.duration = Infinity;
  }
  handleOpenChange() {
    this.open ? this.show() : this.hide();
  }
  handleDurationChange() {
    this.restartAutoHide();
  }
  connectedCallback() {
    this.handleCloseClick = this.handleCloseClick.bind(this);
    this.handleMouseMove = this.handleMouseMove.bind(this);
    this.handleTransitionEnd = this.handleTransitionEnd.bind(this);
  }
  componentWillLoad() {
    // Show on init if open
    if (this.open) {
      this.show();
    }
  }
  /** Shows the alert. */
  async show() {
    // Prevent subsequent calls to the method, whether manually or triggered by the `open` watcher
    if (this.isVisible) {
      return;
    }
    const xnShow = this.xnShow.emit();
    if (xnShow.defaultPrevented) {
      this.open = false;
      return;
    }
    this.isVisible = true;
    this.open = true;
    if (this.duration < Infinity) {
      this.autoHideTimeout = setTimeout(() => this.hide(), this.duration);
    }
  }
  /** Hides the alert */
  async hide() {
    // Prevent subsequent calls to the method, whether manually or triggered by the `open` watcher
    if (!this.isVisible) {
      return;
    }
    const xnHide = this.xnHide.emit();
    if (xnHide.defaultPrevented) {
      this.open = true;
      return;
    }
    clearTimeout(this.autoHideTimeout);
    this.isVisible = false;
    this.open = false;
  }
  /**
   * Displays the alert as a toast notification. This will move the alert out of its position in the DOM and, when
   * dismissed, it will be removed from the DOM completely. By storing a reference to the alert, you can reuse it by
   * calling this method again. The returned promise will resolve after the alert is hidden.
   */
  async toast() {
    return new Promise(resolve => {
      if (!notificationStack.parentElement) {
        document.body.append(notificationStack);
      }
      notificationStack.append(this.host);
      requestAnimationFrame(() => this.show());
      this.host.addEventListener('xnAfterHide', () => {
        this.host.remove();
        resolve();
        // Remove the toast stack from the DOM when there are no more alerts
        if (notificationStack.querySelector('xena-alert') === null) {
          notificationStack.remove();
        }
      }, { once: true });
    });
  }
  handleSlotChange() {
    this.hasActionSlot = slot.hasSlot(this.host, 'action');
  }
  handleCloseClick() {
    this.hide();
  }
  handleMouseMove() {
    this.restartAutoHide();
  }
  handleTransitionEnd(event) {
    const target = event.target;
    // Ensure we only emit one event when the target element is no longer visible
    if (event.propertyName === 'opacity' && target.classList.contains('alert')) {
      this.isVisible = this.open;
      this.open ? this.xnAfterShow.emit() : this.xnAfterHide.emit();
    }
  }
  restartAutoHide() {
    clearTimeout(this.autoHideTimeout);
    if (this.open && this.duration < Infinity) {
      this.autoHideTimeout = setTimeout(() => this.hide(), this.duration);
    }
  }
  render() {
    return (index.h("div", { ref: el => (this.alert = el), part: "base", class: {
        alert: true,
        'alert--open': this.open,
        'alert--visible': this.isVisible,
        'alert--closable': this.closable,
        'alert--remove-borders': this.removeBorders,
        'alert--inline': this.inline,
        'alert--primary': this.type === 'primary',
        'alert--success': this.type === 'success',
        'alert--info': this.type === 'info',
        'alert--warning': this.type === 'warning',
        'alert--danger': this.type === 'danger'
      }, role: "alert", "aria-live": "assertive", "aria-atomic": "true", "aria-hidden": this.open ? 'false' : 'true', onMouseMove: this.handleMouseMove, onTransitionEnd: this.handleTransitionEnd }, index.h("span", { part: "icon", class: "alert__icon" }, index.h("slot", { name: "icon" })), index.h("span", { part: "message", class: "alert__message" }, this.header ? index.h("div", { class: "alert__header" }, this.header) : '', index.h("slot", null)), index.h("span", { part: "action", class: "alert__action" }, index.h("slot", { name: "action" })), this.closable && !this.hasActionSlot && (index.h("span", { class: "alert__close" }, index.h("xena-icon-button", { exportparts: "base:close-button", name: "fas-times", onClick: this.handleCloseClick })))));
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "open": ["handleOpenChange"],
    "duration": ["handleDurationChange"]
  }; }
};
Alert.style = alertCss;

const buttonCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block}:host([loading]){pointer-events:none}button,a.button{user-select:none;cursor:pointer;display:inline-flex;align-items:stretch;justify-content:center;vertical-align:middle;width:100%;color:var(--xena-color-gray-800);font-family:var(--xena-input-font-family);font-size:var(--xena-button-font-size-medium);font-weight:var(--xena-font-weight-semibold);white-space:nowrap;padding:0 var(--xena-spacing-small);min-height:var(--xena-input-height-medium);line-height:calc(var(--xena-input-height-medium) - var(--xena-input-border-width) * 2);background-color:var(--xena-color-transparent);border:solid var(--xena-input-border-width) var(--xena-color-gray-300);border-radius:var(--xena-input-border-radius-medium);outline:solid 0 var(--xena-focus-ring-color-gray);transition:color var(--xena-transition-fast) ease-in-out, background-color var(--xena-transition-fast) ease-in-out, border-color var(--xena-transition-fast) ease-in-out, outline var(--xena-transition-x-fast) ease-in-out}button::-moz-focus-inner,a.button::-moz-focus-inner{border:0}button:focus:not(:disabled),a.button:focus:not(:disabled){outline-width:var(--xena-focus-ring-width)}button:hover:not(:disabled),a.button:hover:not(:disabled){background-color:var(--xena-color-gray-100);color:var(--xena-color-gray-800)}button:active:not(:disabled),a.button:active:not(:disabled){background-color:var(--xena-color-gray-200);color:var(--xena-color-black)}button[disabled],button[aria-disabled=true],a.button[disabled],a.button[aria-disabled=true]{opacity:0.5;cursor:default}button[disabled] *,button[aria-disabled=true] *,a.button[disabled] *,a.button[aria-disabled=true] *{pointer-events:none}button ::slotted(xena-icon),a.button ::slotted(xena-icon){pointer-events:none}a.button{text-decoration:none}.prefix,.suffix{flex:0 0 auto;display:flex;align-items:center}.prefix ::slotted(:first-child){margin-left:calc(-1 * var(--xena-spacing-3x-small));margin-right:var(--xena-spacing-x-small)}.suffix ::slotted(:last-child){margin-left:var(--xena-spacing-x-small);margin-right:calc(-1 * var(--xena-spacing-3x-small))}.label{overflow:hidden;text-overflow:ellipsis}.label ::slotted(xena-icon){vertical-align:-2px}.has-caret .caret{display:flex;align-items:center;margin-left:var(--xena-spacing-x-small)}.is-loading{position:relative}.is-loading xena-spinner{--indicator-color:currentColor;--track-color:transparent;position:absolute;font-size:1em;width:1em;height:1em;top:calc(50% - 0.5em);left:calc(50% - 0.5em)}.is-loading .caret{visibility:hidden}.is-loading .prefix{visibility:hidden}.is-loading .suffix{visibility:hidden}.is-loading .label{visibility:hidden}button.primary,a.button.primary{background-color:var(--xena-color-blue-500);border-color:var(--xena-color-blue-500);color:var(--xena-color-white)}button.primary:hover:not(:disabled),a.button.primary:hover:not(:disabled){background-color:var(--xena-color-blue-600);border-color:var(--xena-color-blue-600);color:var(--xena-color-white)}button.primary:focus:not(:disabled),a.button.primary:focus:not(:disabled){background-color:var(--xena-color-blue-600);border-color:var(--xena-color-blue-600);color:var(--xena-color-white);outline-color:var(--xena-focus-ring-color-blue)}button.primary:active:not(:disabled),a.button.primary:active:not(:disabled){background-color:var(--xena-color-blue-700);border-color:var(--xena-color-blue-700);color:var(--xena-color-white)}button.danger,a.button.danger{background-color:var(--xena-color-red-500);border-color:var(--xena-color-red-500);color:var(--xena-color-white)}button.danger:hover:not(:disabled),a.button.danger:hover:not(:disabled){background-color:var(--xena-color-red-600);border-color:var(--xena-color-red-600);color:var(--xena-color-white)}button.danger:focus:not(:disabled),a.button.danger:focus:not(:disabled){background-color:var(--xena-color-red-600);border-color:var(--xena-color-red-600);color:var(--xena-color-white);outline-color:var(--xena-focus-ring-color-red)}button.danger:active:not(:disabled),a.button.danger:active:not(:disabled){background-color:var(--xena-color-red-700);border-color:var(--xena-color-red-700);color:var(--xena-color-white)}.text{background-color:transparent !important;border-color:transparent !important;color:var(--xena-color-gray-800)}.text:hover:not(:disabled){color:var(--xena-color-gray-800)}.text:focus:not(:disabled){color:var(--xena-color-gray-800);outline-color:var(--xena-focus-ring-color-gray)}.text:active:not(:disabled){color:var(--xena-color-black)}.text.primary{color:var(--xena-color-blue-500)}.text.primary:hover:not(:disabled){color:var(--xena-color-blue-600)}.text.primary:focus:not(:disabled){color:var(--xena-color-blue-600);outline-color:var(--xena-focus-ring-color-blue)}.text.primary:active:not(:disabled){color:var(--xena-color-blue-700)}.text.danger{color:var(--xena-color-red-500)}.text.danger:hover:not(:disabled){color:var(--xena-color-red-600)}.text.danger:focus:not(:disabled){color:var(--xena-color-red-600);outline-color:var(--xena-focus-ring-color-danger)}.text.danger:active:not(:disabled){color:var(--xena-color-red-700)}.ghost{background-color:var(--xena-color-white) !important;border-color:var(--xena-color-gray-300);color:var(--xena-color-gray-800)}.ghost:hover:not(:disabled){border-color:var(--xena-color-gray-400);color:var(--xena-color-gray-800)}.ghost:focus:not(:disabled){border-color:var(--xena-color-gray-400);color:var(--xena-color-gray-800);outline-color:var(--xena-focus-ring-color-gray)}.ghost:active:not(:disabled){border-color:var(--xena-color-gray-300);color:var(--xena-color-black)}.ghost.primary{background-color:var(--xena-color-white) !important;border-color:var(--xena-color-blue-500);color:var(--xena-color-blue-500)}.ghost.primary:hover:not(:disabled){border-color:var(--xena-color-blue-600);color:var(--xena-color-blue-600)}.ghost.primary:focus:not(:disabled){border-color:var(--xena-color-blue-600);color:var(--xena-color-blue-600);outline-color:var(--xena-focus-ring-color-blue)}.ghost.primary:active:not(:disabled){border-color:var(--xena-color-blue-700);color:var(--xena-color-blue-700)}.ghost.danger{background-color:var(--xena-color-white) !important;border-color:var(--xena-color-red-500);color:var(--xena-color-red-500)}.ghost.danger:hover:not(:disabled){border-color:var(--xena-color-red-600);color:var(--xena-color-red-600)}.ghost.danger:focus:not(:disabled){border-color:var(--xena-color-red-600);color:var(--xena-color-red-600);outline-color:var(--xena-focus-ring-color-red)}.ghost.danger:active:not(:disabled){border-color:var(--xena-color-red-700);color:var(--xena-color-red-700)}.link{background-color:transparent;border-color:transparent;color:var(--xena-color-blue-500)}.link:hover:not(:disabled){text-decoration:underline;background-color:transparent;border-color:transparent;color:var(--xena-color-blue-400)}.link:focus:not(:disabled){background-color:transparent;border-color:transparent;color:var(--xena-color-blue-400);box-shadow:0 0 0 var(--xena-focus-ring-width) var(--xena-color-blue-200)}.link:active:not(:disabled){background-color:transparent;border-color:transparent;color:var(--xena-color-blue-600)}.small{font-size:var(--xena-button-font-size-small);min-height:var(--xena-input-height-small);line-height:calc(var(--xena-input-height-small) - var(--xena-input-border-width) * 2);border-radius:var(--xena-input-border-radius-small);padding:0 var(--xena-spacing-medium)}.large{font-size:var(--xena-button-font-size-large);min-height:var(--xena-input-height-large);line-height:calc(var(--xena-input-height-large) - var(--xena-input-border-width) * 2);border-radius:var(--xena-input-border-radius-large);padding:0 var(--xena-spacing-x-large)}";

let Button = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.xnBlur = index.createEvent(this, "xnBlur", 7);
    this.xnFocus = index.createEvent(this, "xnFocus", 7);
    this.hasFocus = false;
    /** The button's type. (link type is deprecated) */
    this.type = 'default';
    /** The button's mode. */
    this.mode = 'standard';
    /** The button's size. */
    this.size = 'medium';
    /** Set to true to disable the button. For links the `href` will be removed */
    this.disabled = false;
    /** Set to true to show loading state. */
    this.loading = false;
    /** Set to true to show a caret at the end of the button. */
    this.caret = false;
    /** Indicates if activating the button should submit the form. Ignored when `href` is set. */
    this.submit = false;
  }
  connectedCallback() {
    this.handleBlur = this.handleBlur.bind(this);
    this.handleFocus = this.handleFocus.bind(this);
    this.handleClick = this.handleClick.bind(this);
  }
  /** Sets focus on the button. */
  async setFocus() {
    this.button.focus();
  }
  /** Removes focus from the button. */
  async removeFocus() {
    this.button.blur();
  }
  handleBlur() {
    this.hasFocus = false;
    this.xnBlur.emit();
  }
  handleFocus() {
    this.hasFocus = true;
    this.xnFocus.emit();
  }
  handleClick(event) {
    if (this.disabled || this.loading) {
      event.preventDefault();
      event.stopPropagation();
    }
  }
  render() {
    const isLink = this.href ? true : false;
    const isButton = !isLink;
    const Button = isLink ? 'a' : 'button';
    if (this.type === 'link') {
      console.log('link type is deprecated. Please use text type instead.');
    }
    return (index.h(Button, { ref: el => (this.button = el), part: "base", class: {
        button: isLink,
        // Modes
        text: this.mode === 'text',
        ghost: this.mode === 'ghost',
        // Types
        primary: this.type === 'primary',
        danger: this.type === 'danger',
        // Sizes
        small: this.size === 'small',
        large: this.size === 'large',
        'is-loading': this.loading,
        'has-caret': this.caret
      }, disabled: (isButton && this.disabled) || this.loading, type: !isLink ? (this.submit ? 'submit' : 'button') : null, name: isButton ? this.name : null, value: isButton ? this.value : null, href: isLink && this.href && !this.disabled ? this.href : null, role: isLink && this.disabled ? 'link' : null, "aria-disabled": isLink && this.disabled ? 'true' : null, "aria-busy": this.loading ? 'true' : null, target: isLink && this.target ? this.target : null, download: isLink && this.download ? this.download : null, rel: isLink && this.target ? 'noreferrer noopener' : null, onBlur: this.handleBlur, onFocus: this.handleFocus, onClick: this.handleClick }, index.h("span", { part: "prefix", class: "prefix" }, index.h("slot", { name: "prefix" })), index.h("span", { part: "label", class: "label" }, index.h("slot", null)), index.h("span", { part: "suffix", class: "suffix" }, index.h("slot", { name: "suffix" })), this.caret ? (index.h("span", { part: "caret", class: "caret" }, index.h("xena-icon", { name: "fas-angle-down" }))) : (''), this.loading ? index.h("xena-spinner", null) : null));
  }
};
Button.style = buttonCss;

const dropdownCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block}.dropdown{position:relative}.dropdown__trigger{display:block}.dropdown__positioner{position:absolute;z-index:var(--xena-z-index-dropdown)}.dropdown__panel{max-height:75vh;font-family:var(--xena-font-sans);font-size:var(--xena-font-size-medium);font-weight:var(--xena-font-weight-normal);color:var(--color);background-color:var(--xena-panel-background-color);border:solid 1px var(--xena-panel-border-color);border-radius:var(--xena-border-radius-medium);box-shadow:var(--xena-shadow-large);opacity:0;overflow:auto;overscroll-behavior:none;transform:scale(0.9);transition:var(--xena-transition-fast) opacity, var(--xena-transition-fast) transform}.dropdown__positioner .dropdown__arrow{position:absolute;display:block;width:10px;height:10px;border-style:solid;border-width:6px;border-color:var(--xena-panel-background-color);-webkit-transform:rotate(45deg);transform:rotate(45deg);z-index:2;opacity:0;transition:var(--xena-transition-fast) opacity, var(--xena-transition-fast) transform}.dropdown__positioner.popover-visible .dropdown__panel,.dropdown__positioner.popover-visible .dropdown__arrow{opacity:1}.dropdown__positioner.popover-visible .dropdown__panel{transform:none}.dropdown__positioner[data-popper-placement^=top] .dropdown__panel{transform-origin:bottom}.dropdown__positioner[data-popper-placement^=top] .dropdown__arrow{left:calc(50% - 5px);bottom:-5px;box-shadow:2px 2px 4px 0 rgba(0, 0, 0, 0.1)}.dropdown__positioner[data-popper-placement^=bottom] .dropdown__panel{transform-origin:top}.dropdown__positioner[data-popper-placement^=bottom] .dropdown__arrow{left:calc(50% - 5px);top:-5px;box-shadow:-2px -2px 4px 0 rgba(0, 0, 0, 0.1)}.dropdown__positioner[data-popper-placement^=left] .dropdown__panel{transform-origin:right}.dropdown__positioner[data-popper-placement^=left] .dropdown__arrow{top:calc(50% - 5px);right:-5px;box-shadow:3px -2px 4px 0 rgba(0, 0, 0, 0.1)}.dropdown__positioner[data-popper-placement^=right] .dropdown__panel{transform-origin:left}.dropdown__positioner[data-popper-placement^=right] .dropdown__arrow{top:calc(50% - 5px);left:-5px;box-shadow:-3px 2px 4px 0 rgba(0, 0, 0, 0.1)}";

let id = 0;
let Dropdown = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.xnShow = index.createEvent(this, "xnShow", 7);
    this.xnAfterShow = index.createEvent(this, "xnAfterShow", 7);
    this.xnHide = index.createEvent(this, "xnHide", 7);
    this.xnAfterHide = index.createEvent(this, "xnAfterHide", 7);
    this.componentId = `dropdown-${++id}`;
    this.isShowing = false;
    this.triggerIsEditable = false;
    /** Indicates whether or not the dropdown is open. You can use this in lieu of the show/hide methods. */
    this.open = false;
    /**
     * The preferred placement of the dropdown panel. Note that the actual placement may vary as needed to keep the panel
     * inside of the viewport.
     */
    this.placement = 'bottom-start';
    /** Determines whether the dropdown should hide when a menu item is selected. */
    this.closeOnSelect = true;
    /** The distance in pixels from which to offset the panel away from its trigger. */
    this.distance = 2;
    /** The distance in pixels from which to offset the panel along its trigger. */
    this.skidding = 0;
    /**
     * Enable this option to prevent the panel from being clipped when the component is placed inside a container with
     * `overflow: auto|scroll`.
     */
    this.hoist = false;
    /**
     * Disables toggle keys for dropdown. Keys for toggling will only close the dropdown, not open it.
     */
    this.noToggleKey = false;
    /**
     * Action taken against the dropdown when trigger is clicked.
     */
    this.triggerClickAction = 'toggle';
    /**
     * Show arrow on the dropdown pointing to the trigger.
     */
    this.arrow = false;
  }
  handleOpenChange() {
    this.open ? this.show() : this.hide();
  }
  getDistance() {
    return this.arrow ? this.distance + 10 : this.distance;
  }
  handlePopoverOptionsChange() {
    this.popover.setOptions({
      strategy: this.hoist ? 'fixed' : 'absolute',
      placement: this.placement,
      distance: this.getDistance(),
      skidding: this.skidding
    });
  }
  connectedCallback() {
    if (!this.containingElement) {
      this.containingElement = this.host;
    }
    this.handleDocumentKeyDown = this.handleDocumentKeyDown.bind(this);
    this.handleDocumentMouseDown = this.handleDocumentMouseDown.bind(this);
    this.handleMenuItemActivate = this.handleMenuItemActivate.bind(this);
    this.handlePanelSelect = this.handlePanelSelect.bind(this);
    this.handleTriggerClick = this.handleTriggerClick.bind(this);
    this.handleTriggerKeyDown = this.handleTriggerKeyDown.bind(this);
    this.handleTriggerKeyUp = this.handleTriggerKeyUp.bind(this);
  }
  componentDidLoad() {
    this.popover = new popover.Popover(this.trigger, this.positioner, {
      strategy: this.hoist ? 'fixed' : 'absolute',
      placement: this.placement,
      distance: this.getDistance(),
      skidding: this.skidding,
      transitionElement: this.panel,
      onAfterHide: () => this.xnAfterHide.emit(),
      onAfterShow: () => this.xnAfterShow.emit(),
      onTransitionEnd: () => {
        if (!this.open) {
          this.panel.scrollTop = 0;
        }
      }
    });
    // Show on init if open
    if (this.open) {
      this.show();
    }
    const slot = this.trigger.querySelector('slot');
    if (slot.assignedElements) {
      const trigger = slot.assignedElements({ flatten: true })[0];
      if (typeof trigger.disabled === 'boolean' &&
        typeof trigger.readonly === 'boolean' &&
        typeof trigger.type === 'string' &&
        trigger.readonly === false &&
        trigger.disabled === false) {
        this.triggerIsEditable = true;
      }
      else {
        this.triggerIsEditable = false;
      }
    }
  }
  disconnectedCallback() {
    var _a;
    this.hide();
    (_a = this.popover) === null || _a === void 0 ? void 0 : _a.destroy();
  }
  /** Shows the dropdown panel */
  async show() {
    // Prevent subsequent calls to the method, whether manually or triggered by the `open` watcher
    if (this.isShowing) {
      return;
    }
    const xnShow = this.xnShow.emit();
    if (xnShow.defaultPrevented) {
      this.open = false;
      return;
    }
    this.panel.addEventListener('xnActivate', this.handleMenuItemActivate);
    this.panel.addEventListener('xnSelect', this.handlePanelSelect);
    document.addEventListener('keydown', this.handleDocumentKeyDown);
    document.addEventListener('mousedown', this.handleDocumentMouseDown);
    this.isShowing = true;
    this.open = true;
    this.popover.show();
  }
  /** Hides the dropdown panel */
  async hide() {
    // Prevent subsequent calls to the method, whether manually or triggered by the `open` watcher
    if (!this.isShowing) {
      return;
    }
    const slHide = this.xnHide.emit();
    if (slHide.defaultPrevented) {
      this.open = true;
      return;
    }
    this.panel.removeEventListener('xnActivate', this.handleMenuItemActivate);
    this.panel.removeEventListener('xnSelect', this.handlePanelSelect);
    document.addEventListener('keydown', this.handleDocumentKeyDown);
    document.removeEventListener('mousedown', this.handleDocumentMouseDown);
    this.isShowing = false;
    this.open = false;
    this.popover.hide();
  }
  /**
   * This method can be called to force the dropdown to reposition itself. In most cases it should do so automatically,
   * but there may be some edge cases where changes are not detected.
   */
  async scheduleUpdate() {
    this.popover.update();
  }
  focusOnTrigger() {
    const trigger = this.resolveContainedTrigger();
    if (trigger) {
      if (typeof trigger.setFocus === 'function') {
        trigger.setFocus();
      }
      else if (typeof trigger.focus === 'function') {
        trigger.focus();
      }
    }
  }
  resolveContainedTrigger() {
    const slot = this.trigger.querySelector('slot');
    const trigger = slot.assignedElements({ flatten: true })[0];
    return trigger;
  }
  getMenu() {
    const list = this.panel.querySelector('slot').assignedElements({ flatten: true });
    for (let i = 0; i < list.length; i++) {
      const el = list[i];
      if (el.tagName.toLowerCase() === 'xena-menu') {
        return el;
      }
      else {
        for (let e = 0; e < el.children.length; e++) {
          const child = el.children[e];
          if (child.tagName.toLowerCase() === 'xena-menu') {
            return child;
          }
        }
        if (!el.shadowRoot)
          return;
        for (let e = 0; e < el.shadowRoot.children.length; e++) {
          const child = el.shadowRoot.children[e];
          if (child.tagName.toLowerCase() === 'xena-menu') {
            return child;
          }
        }
      }
    }
  }
  handleDocumentKeyDown(event) {
    // Close when escape is pressed
    if (event.key === 'Escape' && this.open) {
      this.hide();
      this.focusOnTrigger();
      return;
    }
    // Handle tabbing & Horizontal Arrows
    if (['ArrowLeft', 'ArrowRight', 'Tab'].includes(event.key)) {
      setTimeout(() => {
        var _a;
        // Tabbing outside of the containing element closes the panel
        //
        // If the dropdown is used within a shadow DOM, we need to obtain the activeElement within that shadowRoot,
        // otherwise `document.activeElement` will only return the name of the parent shadow DOM element.
        const activeElement = this.containingElement.getRootNode() instanceof ShadowRoot
          ? (_a = document.activeElement.shadowRoot) === null || _a === void 0 ? void 0 : _a.activeElement
          : document.activeElement;
        if ((activeElement === null || activeElement === void 0 ? void 0 : activeElement.closest(this.containingElement.tagName.toLowerCase())) !== this.containingElement) {
          this.hide();
          return;
        }
      });
    }
  }
  handleDocumentMouseDown(event) {
    // Close when clicking outside of the containing element
    const path = event.composedPath();
    if (!path.includes(this.containingElement)) {
      this.hide();
      return;
    }
  }
  handleMenuItemActivate(event) {
    if (event.target.tagName !== 'XENA-MENU-ITEM')
      return;
    const item = event.target;
    scroll.scrollIntoView(item, this.panel);
  }
  handlePanelSelect(event) {
    const target = event.target;
    // Hide the dropdown when a menu item is selected
    if (this.closeOnSelect && target.tagName.toLowerCase() === 'xena-menu') {
      this.hide();
      this.focusOnTrigger();
    }
  }
  handleTriggerClick() {
    if (this.resolveContainedTrigger().disabled || this.triggerClickAction === 'none') {
      return;
    }
    if (this.triggerClickAction === 'toggle') {
      this.open ? this.hide() : this.show();
    }
    if (this.triggerClickAction === 'open') {
      this.show();
    }
  }
  handleTriggerKeyDown(event) {
    const menu = this.getMenu();
    // Close when escape or tab is pressed
    if (event.key === 'Escape') {
      this.hide();
      this.focusOnTrigger();
      return;
    }
    // When spacebar/enter is pressed, show the panel but don't focus on the menu. This let's the user press the same
    // key again to hide the menu in case they don't want to make a selection.
    const toggleKeys = !this.triggerIsEditable ? [' ', 'Enter'] : ['Enter'];
    if (toggleKeys.includes(event.key)) {
      event.preventDefault();
      if (!this.noToggleKey || this.isShowing) {
        this.open ? this.hide() : this.show();
      }
      return;
    }
    // When up/down is pressed, we make the assumption that the user is familiar with the menu and plans to make a
    // selection. Rather than toggle the panel, we focus on the menu (if one exists) and activate the first item for
    // faster navigation. If noToggleKey is true, then only enter if the menu is already open.
    if (['ArrowDown', 'ArrowUp'].includes(event.key)) {
      event.preventDefault();
      if (!this.noToggleKey || this.open) {
        // Show the menu if it's not already open
        if (!this.open) {
          this.show();
        }
        // Focus on the menu, if one exists
        if (menu) {
          menu.setFocus();
          return;
        }
      }
      else {
        return;
      }
    }
    // Other keys bring focus to the menu and initiate type-to-select behavior
    const ignoredKeys = ['Tab', 'Shift', 'Meta', 'Ctrl', 'Alt', ' '];
    if (this.open && menu && !ignoredKeys.includes(event.key) && !this.triggerIsEditable) {
      menu.setFocus();
      menu.typeToSelect(event.key);
      return;
    }
  }
  handleTriggerKeyUp(event) {
    // Prevent space from triggering a click event in Firefox
    if (event.key === ' ' && !this.triggerIsEditable) {
      event.preventDefault();
    }
  }
  render() {
    return (index.h("div", { part: "base", id: this.componentId, class: {
        dropdown: true,
        dropdown__open: this.open
      }, "aria-expanded": this.open, "aria-haspopup": "true" }, index.h("span", { part: "trigger", class: "dropdown__trigger", ref: el => (this.trigger = el), onClick: this.handleTriggerClick, onKeyDown: this.handleTriggerKeyDown, onKeyUp: this.handleTriggerKeyUp }, index.h("slot", { name: "trigger" })), index.h("div", { ref: el => (this.positioner = el), class: "dropdown__positioner" }, this.arrow && index.h("div", { class: "dropdown__arrow" }), index.h("div", { ref: el => (this.panel = el), part: "panel", class: "dropdown__panel", role: "menu", "aria-hidden": !this.open, "aria-labelledby": this.componentId }, index.h("slot", null)))));
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "open": ["handleOpenChange"],
    "distance": ["handlePopoverOptionsChange"],
    "hoist": ["handlePopoverOptionsChange"],
    "placement": ["handlePopoverOptionsChange"],
    "skidding": ["handlePopoverOptionsChange"]
  }; }
};
Dropdown.style = dropdownCss;

const iconFiles = new Map();
const requestIcon = (url) => {
  if (iconFiles.has(url)) {
    return iconFiles.get(url);
  }
  else {
    const request = fetch(url).then(async (response) => {
      if (response.ok) {
        const div = document.createElement('div');
        div.innerHTML = await response.text();
        const svg = div.firstElementChild;
        return {
          ok: response.ok,
          status: response.status,
          svg: svg && svg.tagName.toLowerCase() === 'svg' ? svg.outerHTML : ''
        };
      }
      else {
        return {
          ok: response.ok,
          status: response.status,
          svg: null
        };
      }
    });
    iconFiles.set(url, request);
    return request;
  }
};

const iconCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block;width:1em;height:1em;contain:strict;box-sizing:content-box !important}.icon,svg{display:block;height:100%;width:100%}";

let parser = typeof DOMParser !== 'undefined' ? new DOMParser() : undefined;
let Icon = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.xnLoad = index.createEvent(this, "xnLoad", 7);
    this.xnError = index.createEvent(this, "xnError", 7);
    /** The name of a registered custom icon library. */
    this.library = 'default';
    if (!parser) {
      /** During tests DOMParser will not be available before class is instantiated.
       * Therefore we set the parser with the first constructor being called. */
      parser = new DOMParser();
    }
  }
  handleChange() {
    this.setIcon();
  }
  connectedCallback() {
    iconLibraryRegistry.watchIcon(this.host);
  }
  componentDidLoad() {
    this.setIcon();
  }
  disconnectedCallback() {
    iconLibraryRegistry.unwatchIcon(this.host);
  }
  /** @internal Fetches the icon and redraws it. Used to handle library registrations. */
  async redraw() {
    this.setIcon();
  }
  async setIcon() {
    const library = iconLibraryRegistry.getLibrary(this.library);
    let url = this.src;
    if (this.name && library) {
      url = library.resolver(this.name);
    }
    if (url) {
      try {
        const file = await requestIcon(url);
        if (file.ok) {
          const doc = parser.parseFromString(file.svg, 'text/html');
          const svg = doc.body.querySelector('svg');
          if (svg) {
            if (library && library.mutator) {
              library.mutator(svg);
            }
            this.svg = svg.outerHTML;
            this.xnLoad.emit();
          }
          else {
            this.svg = '';
            this.xnError.emit({ status: file.status });
          }
        }
        else {
          this.xnError.emit({ status: file.status });
        }
      }
      catch (error) {
        this.xnError.emit();
      }
    }
    else if (this.svg) {
      // If we can't resolve a URL and an icon was previously set, remove it
      this.svg = null;
    }
  }
  render() {
    return (index.h("div", { part: "base", class: "icon", role: "img", "aria-hidden": !this.label ? 'true' : null, "aria-label": this.label, innerHTML: this.svg }));
  }
  static get assetsDirs() { return ["icons"]; }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "name": ["handleChange"],
    "src": ["handleChange"],
    "library": ["handleChange"]
  }; }
};
Icon.style = iconCss;

const iconButtonCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block}.icon-button{appearance:none;cursor:pointer;display:flex;flex:0 0 auto;align-items:center;background:none;border:none;border-radius:var(--xena-border-radius-medium);font-size:inherit;color:var(--xena-color-gray-800);padding:var(--xena-spacing-x-small);outline:solid 0 var(--xena-focus-ring-color-gray);transition:color var(--xena-transition-fast) ease-in-out, background-color var(--xena-transition-fast) ease-in-out, outline var(--xena-transition-x-fast) ease-in-out}.icon-button:hover:not(:disabled){background-color:var(--xena-color-gray-100);color:var(--xena-color-gray-800)}.icon-button:active:not(:disabled){background-color:var(--xena-color-gray-200);color:var(--xena-color-black)}.icon-button:focus{outline-width:var(--xena-focus-ring-width)}:disabled{opacity:0.5}";

let IconButton = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Set to true to disable the button. */
    this.disabled = false;
  }
  componentDidLoad() {
    focusVisible.focusVisible.observe(this.button);
  }
  disconnectedCallback() {
    focusVisible.focusVisible.unobserve(this.button);
  }
  render() {
    const isLink = this.href ? true : false;
    const isButton = !isLink;
    const Button = isLink ? 'a' : 'button';
    return (index.h(Button, { ref: el => (this.button = el), part: "base", class: {
        'icon-button': true,
        'icon-button--disabled': this.disabled
      }, type: isButton ? 'button' : null, disabled: isButton && this.disabled, href: isLink && this.href && !this.disabled ? this.href : null, target: isLink && this.target ? this.target : null, download: isLink && this.download ? this.download : null, rel: isLink && this.target ? 'noreferrer noopener' : null, role: isLink && this.disabled ? 'link' : null, "aria-label": this.label, "aria-disabled": isLink && this.disabled ? 'true' : null }, index.h("xena-icon", { library: this.library, name: this.name, src: this.src, "aria-hidden": "true" })));
  }
};
IconButton.style = iconButtonCss;

const spinnerCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{--track-color:#0d131e20;--indicator-color:var(--xena-color-blue-500);--stroke-width:2px;--size:1em;--square-size:calc(var(--size) / 2.275);display:inline-flex;flex-direction:column;align-items:center;gap:var(--xena-spacing-small)}.spinner-text{font-size:var(--xena-font-size-small);opacity:var(--xena-color-gray-500);text-transform:uppercase;letter-spacing:var(--xena-letter-spacing-loose)}.circle.spinner{display:inline-block;width:var(--size);height:var(--size);border-radius:50%;border:solid var(--stroke-width) var(--track-color);border-top-color:var(--indicator-color);border-right-color:var(--indicator-color);animation:1s linear infinite spin}@keyframes spin{0%{transform:rotate(0deg)}100%{transform:rotate(360deg)}}.squares.spinner{width:var(--size);height:var(--size);display:inline-block;position:relative}.squares.spinner::before,.squares.spinner::after{content:\"\";display:block;width:var(--square-size);height:var(--square-size);background-color:var(--indicator-color);position:absolute;animation-duration:2s;animation-iteration-count:infinite;-webkit-animation-timing-function:ease-in-out;animation-timing-function:ease-in-out}.squares.spinner::before{top:0;left:50%;animation-name:square1}.squares.spinner::after{top:50%;left:0;animation-name:square2}@keyframes square1{0%{top:0;left:50%}25%{top:50%;left:50%}50%{top:50%;left:0}75%{top:0;left:0}}@keyframes square2{0%{top:50%;left:0}25%{top:0;left:0}50%{top:0;left:50%}75%{top:50%;left:50%}}";

let Spinner = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Spinner style */
    this.mode = 'circle';
    /** Spinner label */
    this.label = '';
  }
  render() {
    return (index.h(index.Host, { class: this.mode }, index.h("span", { class: {
        spinner: true,
        circle: this.mode === 'circle',
        squares: this.mode === 'squares'
      }, part: "base", "aria-busy": "true", "aria-live": "polite" }), this.label.length > 0 ? index.h("span", { class: "spinner-text" }, this.label) : ''));
  }
};
Spinner.style = spinnerCss;

exports.xena_alert = Alert;
exports.xena_button = Button;
exports.xena_dropdown = Dropdown;
exports.xena_icon = Icon;
exports.xena_icon_button = IconButton;
exports.xena_spinner = Spinner;
