'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d0e7980b.js');
const colors = require('./colors-89af41af.js');

const colorPickerCss = ":host{display:block}xena-dropdown::part(panel){overflow:visible;margin-top:0.25rem}.color{min-height:34px;min-width:34px;border-radius:50%;border:2px solid rgba(68, 68, 68, 0.25);box-sizing:border-box}.color:hover{cursor:pointer}.cursor-default:hover{cursor:default}.color-picker{width:240px;border-radius:4px;box-shadow:1px 1px 4px rgba(0, 0, 0, 0.25)}h4{font-weight:var(--xena-font-weight-semibold);margin:0}.swatches{padding:var(--xena-spacing-medium);display:flex;flex-direction:column;gap:var(--xena-spacing-medium)}.swatches-header{display:flex;justify-content:end}.swatches-header xena-icon::part(base){opacity:0.25}.swatches-header xena-icon::part(base):hover{cursor:pointer}.swatches-colors{display:flex;flex-wrap:wrap;gap:var(--xena-spacing-x-small);justify-content:space-between}.color-options{padding:var(--xena-spacing-medium);display:flex;flex-direction:column;gap:1rem}.input-selected{display:flex;gap:var(--xena-spacing-x-small)}a{color:var(--xena-font-weak);text-decoration:none;text-align:center;height:18px;border-radius:var(--xena-border-radius-medium);transition:all var(--xena-transition-fast)}a:hover{color:var(--xena-font-color)}#color xena-slider::part(container){background-color:transparent;border:0}#color xena-slider::part(handler){background-color:white}#hue xena-slider::part(container){height:10px;background-image:linear-gradient(to right, #ff0000, #ffff00, #00ff00, #00ffff, #0000ff, #ff00ff, #ff0000);border:1px solid rgba(68, 68, 68, 0.25);box-sizing:border-box;border-radius:6px}#hue xena-slider::part(handler){background-color:white;transform:translate(-50%, -25%)}";

let ColorPicker = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.valueChange = index.createEvent(this, "valueChange", 7);
    this.hue = 0;
    this.saturation = 0;
    this.lightness = 0;
    this.showCustomColorPicker = false;
    this.isDragging = false;
    this.customToggle = true;
    /** The components value. The value is set by selecting a color with the color picker. */
    this.value = '';
    /** Swatches are predefined colors shown at the top of the color picker. Swatches must be written as hex values with `#` as prefix like this: `#517770`. */
    this.swatches = '';
    /** The components type. */
    this.type = 'default';
    this.stayInHundreds = (value) => {
      if (value < 0) {
        return 0;
      }
      if (value > 100) {
        return 100;
      }
      return value;
    };
  }
  valueChangedHandler(value) {
    this.value = value;
    this.valueChange.emit(this.value);
  }
  componentWillLoad() {
    this.checkForSwatches();
    this.updateColorHexHsl();
    this.checkForType();
  }
  componentDidLoad() {
    this.dropdown = this.element.shadowRoot.querySelector('xena-dropdown');
  }
  checkForType() {
    if (this.type === 'default') {
      this.showCustomColorPicker = true;
    }
  }
  parseSwatches(swatches) {
    if (!swatches.trim()) {
      return [];
    }
    else {
      return swatches
        .split(';')
        .map(s => s.trim())
        .filter(s => s !== '');
    }
  }
  toggleVisibility() {
    this.showCustomColorPicker = !this.showCustomColorPicker;
    this.customToggle = !this.customToggle;
    this.updateColorHexHsl();
  }
  checkForSwatches() {
    const swatchesArray = this.parseSwatches(this.swatches);
    if (swatchesArray.length === 0) {
      this.showCustomColorPicker = !this.showCustomColorPicker;
    }
  }
  handleSwatchClick(hexValue) {
    this.value = hexValue;
    this.updateColorHexHsl();
    this.valueChange.emit(this.value);
  }
  handleColorInput(event) {
    if (this.isDragging)
      return;
    const inputElement = event.target;
    let value = inputElement.value;
    if (!value.startsWith('#')) {
      value = '#' + value;
    }
    this.value = value;
    this.updateColorHexHsl();
  }
  handleInputEnter(event) {
    if (event.key === 'Enter') {
      this.dropdown.hide();
      event.stopPropagation();
    }
  }
  hueChangeHandler(event) {
    const value = event.detail;
    this.hue = value.x;
    this.updateColorHslHex();
    event.stopPropagation();
  }
  toneChangeHandler(event) {
    const value = event.detail;
    this.saturation = value.x;
    this.lightness = value.y * (100 - value.x * 0.5) * 0.01;
    this.updateColorHslHex();
    event.stopPropagation();
  }
  updateColorHslHex() {
    const selectedHue = this.hue;
    const saturationValue = this.saturation;
    const lightnessValue = this.lightness;
    const { r, g, b } = colors.Colors.hslToRgb(selectedHue, saturationValue, lightnessValue);
    const hexColor = colors.Colors.rgbToHex(r, g, b);
    this.value = hexColor;
  }
  updateColorHexHsl() {
    const hexValue = this.value;
    const { r, g, b } = colors.Colors.hexToRgb(hexValue);
    const { h, s, l } = colors.Colors.rgbToHsl(r, g, b);
    this.hue = h;
    this.saturation = s;
    this.lightness = l;
  }
  render() {
    const swatchesArray = this.parseSwatches(this.swatches);
    const placeholder = '#517770';
    const getHue = { x: this.hue, y: 0 };
    const getTone = {
      x: this.saturation,
      y: this.stayInHundreds(this.lightness / (0.01 * (100 - 0.5 * this.saturation)))
    };
    return (index.h("xena-dropdown", null, index.h("div", { id: "colorInput", slot: "trigger", class: "color", style: { backgroundColor: this.value } }), index.h("div", { class: "color-picker", part: "base" }, swatchesArray.length > 0 && (index.h("div", { class: "swatches" }, index.h("div", { class: "swatches-colors" }, swatchesArray.map(hexValue => (index.h("div", { class: "color", style: { backgroundColor: hexValue }, onClick: () => this.handleSwatchClick(hexValue) })))), this.type === 'expandable' && this.customToggle ? (index.h("a", { id: "custom-toggle", href: "javascript:void(0)", role: "button", onClick: () => this.toggleVisibility() }, index.h("xena-icon", { name: "fas-angle-down" }))) : null)), this.showCustomColorPicker === true ? (index.h("div", { id: "custom-color" }, index.h("div", { id: "color" }, index.h("xena-slider", { onValueChange: e => this.toneChangeHandler(e), type: "both", min: 0, max: 100, value: getTone, style: {
        background: `
                      linear-gradient(rgba(255,255,255,0), rgba(0,0,0,1)), 
                      linear-gradient(to right, hsl(${this.hue} 100% 50% / 0), hsl(${this.hue} 100% 50% / 1)`
      }, width: "100%" })), index.h("div", { class: "color-options" }, index.h("div", { id: "hue" }, index.h("xena-slider", { onValueChange: e => this.hueChangeHandler(e), type: "horizontal", min: 0, max: 360, value: getHue, width: "100%" })), index.h("div", { class: "input-selected" }, index.h("xena-input", { value: this.value, onInput: event => this.handleColorInput(event), onKeyDown: event => this.handleInputEnter(event), placeholder: placeholder }, index.h("span", { slot: "prefix" }, "Hex")), index.h("div", { class: "color cursor-default", style: { backgroundColor: this.value } })), this.type === 'expandable' && !this.customToggle ? (index.h("a", { id: "custom-toggle", href: "javascript:void(0)", role: "button", onClick: () => this.toggleVisibility() }, index.h("xena-icon", { name: "fas-angle-up" }))) : null))) : null)));
  }
  get element() { return index.getElement(this); }
  static get watchers() { return {
    "value": ["valueChangedHandler"]
  }; }
};
ColorPicker.style = colorPickerCss;

exports.xena_color_picker = ColorPicker;
