'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d0e7980b.js');
const dates = require('./dates-9075723d.js');
const i18n = require('./i18n-72793797.js');
require('./platform-850a3acc.js');

const fiscalCalendarCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:block;min-width:312px;}.datepicker{background-color:var(--xena-color-white);user-select:none}.datepicker .datepicker-header{border-bottom:var(--xena-input-border-width) solid var(--xena-color-gray-200);overflow:hidden;display:flex;align-items:center;justify-content:space-between;padding:var(--xena-spacing-x-small) var(--xena-spacing-x-small) var(--xena-spacing-x-small) var(--xena-spacing-small)}.datepicker .datepicker-navigate{display:flex;gap:var(--xena-spacing-x-small)}.datepicker .datepicker-dates{width:100%;text-align:center;table-layout:fixed;border:0;border-collapse:collapse;font-size:var(--xena-font-size-small);margin:var(--xena-spacing-2x-small) 0}.datepicker .datepicker-dates th{height:30px;font-weight:var(--xena-font-weight-bold)}.datepicker .datepicker-dates .date-cell-inner{border-radius:var(--xena-border-radius-small);display:inline-block;height:30px;min-width:30px;line-height:30px}.datepicker .datepicker-dates td{cursor:pointer;padding:var(--xena-spacing-2x-small) 0}.datepicker .datepicker-dates td:hover .date-cell-inner{background-color:var(--xena-color-blue-50)}.datepicker .datepicker-dates .datepicker-week{color:var(--xena-color-gray-400)}.datepicker .datepicker-dates .datepicker-other-month{color:var(--xena-color-gray-400)}.datepicker .datepicker-dates .datepicker-today .date-cell-inner{background-color:var(--xena-color-gray-200)}.datepicker .datepicker-dates .datepicker-selected .date-cell-inner{background-color:var(--xena-color-blue-500) !important;color:var(--xena-color-white)}";

let FiscalCalendar = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.dateChange = index.createEvent(this, "dateChange", 7);
    this.daysNamesShort = [];
    this.daysNames = [];
    this.monthNames = [];
    /** The selected date of the calendar, given as a fiscalDate number. */
    this.date = dates.Dates.dateToFiscalDate(new Date());
    /**
     * Defines the systemDate as a fiscalDate. If not set, the current date will automatically be selected.
     */
    this.systemDate = -1;
    for (var i = 0; i < 7; i++) {
      const weekdayIndex = i == 6 ? 0 : i + 1; // Make monday first day of week
      this.daysNamesShort.push(dates.Dates.formatWeekDay(weekdayIndex, 'short'));
      this.daysNames.push(dates.Dates.formatWeekDay(weekdayIndex));
    }
    for (var i = 0; i < 12; i++) {
      this.monthNames.push(dates.Dates.formatMonth(i));
    }
  }
  handleDateChange() {
    this.select(this.date, false);
  }
  componentWillLoad() {
    if (this.systemDate < 0) {
      this.systemDate = dates.Dates.dateToFiscalDate(new Date());
    }
    this.gotoDate(this.systemDate);
  }
  setDates(fdate) {
    var date = fdate;
    if (this.date === date)
      return;
    this.gotoDate(date);
    this.date = date;
  }
  gotoDate(fdate) {
    var date = dates.Dates.fiscalDateToDate(fdate);
    if (!date)
      return;
    this.year = date.getFullYear();
    this.month = date.getMonth();
  }
  getFirstDayOfMonth() {
    return new Date(this.year, this.month, 1).getDay();
  }
  getDaysInMonth() {
    return 32 - new Date(this.year, this.month, 32).getDate();
  }
  getWeekDates(firstDate) {
    var result = [];
    for (var i = 0; i < 7; i++) {
      result.push(firstDate + i);
    }
    return result;
  }
  getWeekdayDates(firstDate, rows) {
    var result = [];
    for (var i = 0; i < rows; i++) {
      let fdate = firstDate + i * 7;
      var date = dates.Dates.fiscalDateToDate(fdate);
      if (date.getMonth() === this.month)
        result.push(fdate);
    }
    return result;
  }
  adjustMonth(offset) {
    var date = new Date(this.year, this.month + offset);
    this.year = date.getFullYear();
    this.month = date.getMonth();
    //this.draw();
  }
  select(fdate, emit = true) {
    this.date = fdate;
    this.gotoDate(fdate);
    if (emit) {
      this.dateChange.emit(this.date);
    }
  }
  selectWeekdayDates(firstDate, rows) {
    const dates = this.getWeekdayDates(firstDate, rows);
    this.select(dates[0]);
  }
  selectWeekDates(fdate) {
    const dates = this.getWeekDates(fdate);
    this.select(dates[0]);
  }
  getWeek(date) {
    var date = new Date(date.getTime());
    date.setHours(0, 0, 0, 0);
    date.setDate(date.getDate() + 3 - ((date.getDay() + 6) % 7));
    var week1 = new Date(date.getFullYear(), 0, 4);
    return 1 + Math.round(((date.getTime() - week1.getTime()) / 86400000 - 3 + ((week1.getDay() + 6) % 7)) / 7);
  }
  render() {
    var firstDay = 1;
    var leadDays = (this.getFirstDayOfMonth() - firstDay + 7) % 7;
    var rows = Math.ceil((leadDays + this.getDaysInMonth()) / 7);
    var fdate = dates.Dates.dateToFiscalDate(new Date(this.year, this.month, 1 - leadDays));
    var ftoday = this.systemDate;
    //let moreBefore = (Math.min.apply(null, this.fdates) < fdate) ? " datepicker-more" : "";
    //let moreAfter = (Math.max.apply(null, this.fdates) >= (fdate + rows * 7)) ? " datepicker-more" : "";
    let dateMatrix = [];
    let currentDate = fdate;
    for (var row = 0; row < rows; row++) {
      dateMatrix.push([]);
      //days
      for (var col = 0; col < 7; col++) {
        dateMatrix[row].push(currentDate);
        currentDate++;
      }
    }
    return (index.h("div", { class: "datepicker", part: "base" }, index.h("div", { class: "datepicker-header" }, index.h("div", { class: "datepicker-title" }, this.monthNames[this.month], " ", this.year), index.h("div", { class: "datepicker-navigate" }, index.h("xena-tooltip", { content: i18n.i18n('PREVIOUS_MONTH'), placement: "bottom" }, index.h("xena-icon-button", { name: "fas-chevron-left", class: "datepicker-jump", onClick: () => this.adjustMonth(-1), tabindex: "-1" })), index.h("xena-tooltip", { content: i18n.i18n('NEXT_MONTH'), placement: "bottom-end" }, index.h("xena-icon-button", { name: "fas-chevron-right", class: "datepicker-jump", onClick: () => this.adjustMonth(+1), tabindex: "-1" })))), index.h("table", { class: "datepicker-dates" }, index.h("thead", null, index.h("tr", null, index.h("th", { class: "datepicker-week" }), this.daysNamesShort.map((day, i) => (index.h("th", { title: this.daysNames[i], onClick: () => this.selectWeekdayDates(fdate + i, rows) }, day))))), index.h("tbody", null, dateMatrix.map(row => (index.h("tr", null, index.h("th", { class: "datepicker-week", onClick: () => this.selectWeekDates(row[0]) }, this.getWeek(dates.Dates.fiscalDateToDate(row[0]))), row.map(col => (index.h("td", { class: {
        'datepicker-today': col === ftoday,
        'datepicker-selected': col === this.date,
        'datepicker-other-month': dates.Dates.fiscalDateToDate(col).getMonth() !== this.month
      }, onClick: () => this.select(col) }, index.h("div", { class: "date-cell-inner" }, dates.Dates.fiscalDateToDate(col).getDate())))))))))));
  }
  static get watchers() { return {
    "date": ["handleDateChange"]
  }; }
};
FiscalCalendar.style = fiscalCalendarCss;

exports.xena_fiscal_calendar = FiscalCalendar;
