'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d0e7980b.js');
const dates = require('./dates-9075723d.js');
require('./platform-850a3acc.js');

const fiscalDatepickerCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block;width:100%}xena-dropdown{display:block}xena-fiscal-calendar{max-width:260px}::slotted([slot=prefix]),::slotted([slot=suffix]){display:flex}";

let FiscalDatepicker = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.dateChange = index.createEvent(this, "dateChange", 7);
    this.isFocused = false;
    this.text = '';
    /**
     * Defines the currently selected date. If not set, the current date date will be used.
     */
    this.date = dates.Dates.dateToFiscalDate(new Date());
    /**
     * Defines the systemDate as a fiscalDate. If not set, the current date will automatically be selected.
     */
    this.systemDate = -1;
    /**
     * If `true`, the user cannot interact with the input.
     */
    this.disabled = false;
    /** The datepicker's label. */
    this.label = '';
    /** The datepicker's help text. */
    this.helpText = '';
    /** Indicates whether or not the dropdown is open. You can use this in lieu of the show/hide methods. */
    this.open = false;
    /**
     * Defines the shape of the input field.
     */
    this.shape = 'default';
    /**
     * Defines the size of the input field.
     */
    this.size = 'medium';
  }
  /**
   * Retrieves the native input element.
   */
  async getInputElement() {
    return this.textInput.getInputElement();
  }
  /**
   * Set focus on the native input element.
   */
  async setFocus() {
    this.textInput.setFocus();
  }
  /**
   * Closes the calendar popup if open.
   */
  async hide() {
    this.dropdown.hide();
  }
  /**
   * Opens the calendar popup if closed.
   */
  async show() {
    this.dropdown.show();
  }
  handleTextChange() {
    if (this.textInput) {
      this.textInput.value = this.text;
    }
  }
  componentWillLoad() {
    if (this.systemDate < 0) {
      this.systemDate = dates.Dates.dateToFiscalDate(new Date());
    }
    this.text = this.formattedDate;
    this.hasPrefixSlot = !!this.el.querySelector('[slot="prefix"]');
    this.hasSuffixSlot = !!this.el.querySelector('[slot="suffix"]');
  }
  handleDropdownShow() {
    this.open = true;
  }
  handleDropdownAfterHide() {
    this.open = false;
  }
  handleInputChange(_ev) {
    if (!this.isFocused)
      return;
    this.dropdown.show();
    var value = this.textInput.value;
    this.text = value;
    var fdate = dates.Dates.stringToFiscalDate(this.text, this.systemDate);
    if ((!fdate && value !== '') || fdate < 1)
      return;
    this.calendar.date = fdate;
  }
  updateValues(date) {
    this.text = this.formattedDate;
    if (date === this.date)
      return;
    this.date = date;
    if (this.calendar.date != this.date) {
      this.calendar.date = this.date;
    }
    this.text = this.formattedDate;
    this.dateChange.emit(this.date);
  }
  dateSelected(date) {
    this.updateValues(date);
    this.dropdown.hide();
  }
  handleFocus() {
    this.isFocused = true;
    this.dropdown.show();
  }
  handleBlur() {
    this.isFocused = false;
    this.updateValues(this.calendar.date);
  }
  get formattedDate() {
    return dates.Dates.format(dates.Dates.fiscalDateToDate(this.date));
  }
  render() {
    return (index.h(index.Host, null, index.h("xena-dropdown", { noToggleKey: true, triggerClickAction: 'none', hoist: true, ref: el => (this.dropdown = el), onXnShow: _ev => this.handleDropdownShow(), onXnAfterHide: _ev => this.handleDropdownAfterHide() }, index.h("xena-input", { label: this.label, helpText: this.helpText, disabled: this.disabled, part: "input", slot: "trigger", onFocus: () => this.handleFocus(), onBlur: () => this.handleBlur(), onValueChange: ev => this.handleInputChange(ev), value: this.text, shape: this.shape, size: this.size, ref: el => (this.textInput = el) }, this.hasPrefixSlot ? (index.h("span", { slot: "prefix", part: "prefix" }, index.h("slot", { name: "prefix" }))) : (''), this.hasSuffixSlot ? (index.h("span", { slot: "suffix", part: "suffix" }, index.h("slot", { name: "suffix" }))) : ('')), index.h("xena-fiscal-calendar", { part: "calendar", ref: el => (this.calendar = el), date: this.date, onDateChange: e => this.dateSelected(e.detail) }))));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "text": ["handleTextChange"]
  }; }
};
FiscalDatepicker.style = fiscalDatepickerCss;

exports.xena_fiscal_datepicker = FiscalDatepicker;
