'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d0e7980b.js');

const pageSizeCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block;line-height:var(--xena-line-height-dense)}label{margin-right:4px}";

const DEFAULT_SIZES = [10, 30, 50, 100];
let PageSize = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.sizeChange = index.createEvent(this, "sizeChange", 7);
    this._sizes = DEFAULT_SIZES;
    /** The selectable page sizes. */
    this.sizes = DEFAULT_SIZES;
    /** The current page size. */
    this.size = 10;
    /** Label added just before the size selector. */
    this.label = 'Items per page';
  }
  validateSize() {
    if (this._sizes.indexOf(this.size) < 0) {
      this.size = this._sizes[0];
    }
  }
  sizesUpdated() {
    this.parseSizes();
  }
  componentWillLoad() {
    this.parseSizes();
  }
  parseSizes() {
    if (typeof this.sizes === 'string') {
      this._sizes = JSON.parse(this.sizes);
    }
    else {
      this._sizes = this.sizes;
    }
  }
  onSelection(_ev) {
    this.setPageSize(parseInt(this.nativeSelect.value));
  }
  setPageSize(pageSize) {
    this.size = pageSize;
    this.sizeChange.emit(pageSize);
  }
  get pageSizeList() {
    const sizes = [];
    for (let i = 0; i < this._sizes.length; i++) {
      sizes.push(this._sizes[i]);
    }
    return sizes;
  }
  render() {
    return (index.h("span", null, index.h("label", null, this.label, ":"), index.h("select", { ref: el => (this.nativeSelect = el), class: "paging-select", onChange: ev => this.onSelection(ev) }, this.pageSizeList.map(pageSize => (index.h("option", { value: pageSize, selected: pageSize === this.size }, pageSize))))));
  }
  static get watchers() { return {
    "size": ["validateSize"],
    "sizes": ["sizesUpdated"]
  }; }
};
PageSize.style = pageSizeCss;

exports.xena_page_size = PageSize;
