import { Component, Element, Event, h, Method, Prop } from '@stencil/core';
/**
 * @since 1.0
 * @status stable
 */
export class AutocompleteList {
  constructor() {
    /**
     * The text to show when no results are in the list.
     */
    this.noResultText = 'No results';
    /**
     * The property name for the id of the item.
     */
    this.idProperty = 'id';
    /**
     * The property name for the label of the item shown in the list.
     */
    this.labelProperty = 'label';
  }
  /**
   * Retrieves the menu element.
   */
  getMenuElement() {
    return Promise.resolve(this.menu);
  }
  handleSelection(ev) {
    ev.stopPropagation();
    this.xnSelect.emit(ev.detail);
  }
  resolveId(entry) {
    return entry[this.idProperty];
  }
  resolveListLabel(entry) {
    if (typeof this.labelProperty === 'function') {
      return this.labelProperty(entry);
    }
    else {
      return entry[this.labelProperty];
    }
  }
  resolveIcon(entry) {
    if (typeof this.iconProperty === 'function') {
      return this.iconProperty(entry);
    }
    else {
      return entry[this.iconProperty];
    }
  }
  componentDidRender() {
    if (this.defaultActiveIndex !== undefined) {
      const items = this.hostElement.querySelectorAll('xena-menu-item');
      items.forEach((item, index) => item.setActive(index === this.defaultActiveIndex));
    }
  }
  render() {
    return (h("xena-menu", { onXnSelect: ev => this.handleSelection(ev), ref: el => (this.menu = el), tabindex: "-1" },
      this.entries.length === 0 ? h("xena-menu-item", { disabled: true }, this.noResultText) : null,
      this.entries.map(entry => (h("xena-menu-item", { value: this.resolveId(entry) },
        this.resolveListLabel(entry),
        this.iconProperty != null ? h("xena-icon", { slot: "suffix", name: this.resolveIcon(entry) }) : null)))));
  }
  static get is() { return "xena-autocomplete-list"; }
  static get originalStyleUrls() { return {
    "$": ["list.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["list.css"]
  }; }
  static get properties() { return {
    "noResultText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The text to show when no results are in the list."
      },
      "attribute": "no-result-text",
      "reflect": false,
      "defaultValue": "'No results'"
    },
    "entries": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "any[]",
        "resolved": "any[]",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The entries to show in the list."
      }
    },
    "idProperty": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The property name for the id of the item."
      },
      "attribute": "id-property",
      "reflect": false,
      "defaultValue": "'id'"
    },
    "labelProperty": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | ((e: any) => string)",
        "resolved": "((e: any) => string) | string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The property name for the label of the item shown in the list."
      },
      "attribute": "label-property",
      "reflect": false,
      "defaultValue": "'label'"
    },
    "iconProperty": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | ((e: any) => string)",
        "resolved": "((e: any) => string) | string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The property name for the label of the item shown in the list."
      },
      "attribute": "icon-property",
      "reflect": false
    },
    "defaultActiveIndex": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The optional index of the entry that is active by default."
      },
      "attribute": "default-active-index",
      "reflect": false
    }
  }; }
  static get events() { return [{
      "method": "xnSelect",
      "name": "xnSelect",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when a menu item is selected."
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "getMenuElement": {
      "complexType": {
        "signature": "() => Promise<HTMLXenaMenuElement>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          },
          "HTMLXenaMenuElement": {
            "location": "global"
          }
        },
        "return": "Promise<HTMLXenaMenuElement>"
      },
      "docs": {
        "text": "Retrieves the menu element.",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "hostElement"; }
}
