import { Component, Element, State, h } from '@stencil/core';
import { hasSlot } from '../../utils/slot';
/**
 * @since 1.9
 * @status experimental
 *
 * @slot title - Header of the card.
 * @slot description - Subheader of the card.
 * @slot actions - The actions area of the header.
 */
export class CardHeader {
  constructor() {
    this.hasImage = false;
  }
  handleSlotChange() {
    this.hasImage = hasSlot(this.host, 'image');
  }
  render() {
    return (h("div", { class: "card-header" },
      h("div", { class: "image", hidden: !this.hasImage },
        h("slot", { name: "image", onSlotchange: _ => this.handleSlotChange() })),
      h("div", { class: "title" },
        h("slot", { name: "title" })),
      h("div", { class: "description" },
        h("small", null,
          h("slot", { name: "description" }))),
      h("div", { class: "actions" },
        h("slot", { name: "actions" }))));
  }
  static get is() { return "xena-card-header"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["card-header.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["card-header.css"]
  }; }
  static get states() { return {
    "hasImage": {}
  }; }
  static get elementRef() { return "host"; }
}
