import { Component, Event, h, Prop, Watch } from '@stencil/core';
const DEFAULT_SIZES = [10, 30, 50, 100];
/**
 * @since 1.0
 * @status experimental
 *
 * @part base - The component's base wrapper.
 *
 */
export class PageSize {
  constructor() {
    this._sizes = DEFAULT_SIZES;
    /** The selectable page sizes. */
    this.sizes = DEFAULT_SIZES;
    /** The current page size. */
    this.size = 10;
    /** Label added just before the size selector. */
    this.label = 'Items per page';
  }
  validateSize() {
    if (this._sizes.indexOf(this.size) < 0) {
      this.size = this._sizes[0];
    }
  }
  sizesUpdated() {
    this.parseSizes();
  }
  componentWillLoad() {
    this.parseSizes();
  }
  parseSizes() {
    if (typeof this.sizes === 'string') {
      this._sizes = JSON.parse(this.sizes);
    }
    else {
      this._sizes = this.sizes;
    }
  }
  onSelection(_ev) {
    this.setPageSize(parseInt(this.nativeSelect.value));
  }
  setPageSize(pageSize) {
    this.size = pageSize;
    this.sizeChange.emit(pageSize);
  }
  get pageSizeList() {
    const sizes = [];
    for (let i = 0; i < this._sizes.length; i++) {
      sizes.push(this._sizes[i]);
    }
    return sizes;
  }
  render() {
    return (h("span", null,
      h("label", null,
        this.label,
        ":"),
      h("select", { ref: el => (this.nativeSelect = el), class: "paging-select", onChange: ev => this.onSelection(ev) }, this.pageSizeList.map(pageSize => (h("option", { value: pageSize, selected: pageSize === this.size }, pageSize))))));
  }
  static get is() { return "xena-page-size"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["page-size.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["page-size.css"]
  }; }
  static get properties() { return {
    "sizes": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "number[] | string",
        "resolved": "number[] | string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The selectable page sizes."
      },
      "attribute": "sizes",
      "reflect": false,
      "defaultValue": "DEFAULT_SIZES"
    },
    "size": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The current page size."
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "10"
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label added just before the size selector."
      },
      "attribute": "label",
      "reflect": false,
      "defaultValue": "'Items per page'"
    }
  }; }
  static get events() { return [{
      "method": "sizeChange",
      "name": "sizeChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the selected size changes."
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "size",
      "methodName": "validateSize"
    }, {
      "propName": "sizes",
      "methodName": "sizesUpdated"
    }]; }
}
