import { Component, Prop, h } from '@stencil/core';
/**
 * @since 1.8
 * @status experimental
 *
 * @part base - The base wrapper
 */
export class TableColumn {
  constructor() {
    /**
     * Adjust the alignment of the content
     */
    this.alignment = 'left';
  }
  render() {
    return (h("th", { part: "base", class: {
        'text-left': this.alignment === 'left',
        'text-right': this.alignment === 'right',
        'text-center': this.alignment === 'center'
      }, style: {
        width: this.width
      }, colSpan: this.colspan },
      h("slot", null)));
  }
  static get is() { return "xena-column"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["table-column.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["table-column.css"]
  }; }
  static get properties() { return {
    "alignment": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Alignments",
        "resolved": "\"center\" | \"left\" | \"right\"",
        "references": {
          "Alignments": {
            "location": "import",
            "path": "../../utils/types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Adjust the alignment of the content"
      },
      "attribute": "alignment",
      "reflect": true,
      "defaultValue": "'left'"
    },
    "width": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Adjust the width of the column"
      },
      "attribute": "width",
      "reflect": true
    },
    "colspan": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Adjust the colspan of the column"
      },
      "attribute": "colspan",
      "reflect": true
    }
  }; }
}
