import { format, parse } from 'date-fns';
import { enUS, da, nb, pl } from 'date-fns/locale';
import { Platform } from './platform';
const locales = { en: enUS, da, nb, pl };
const msInOneDay = 24 * 60 * 60 * 1000;
export class Dates {
  static getDefaultDateFormat() {
    const locale = this.getLocale();
    return locale.formatLong.date({ width: 'short' });
  }
  static dateToFiscalDate(date) {
    return !!date ? Date.UTC(date.getFullYear(), date.getMonth(), date.getDate()) / msInOneDay : null;
  }
  static fiscalDateToDate(value) {
    return !!value ? new Date(1970, 0, 1 + value) : null;
  }
  static stringToFiscalDate(value, systemDate) {
    var match = /^d([\+\-]\d+)?$/g.exec(value);
    if (match) {
      return systemDate + (parseInt(match[1]) || 0);
    }
    let dateFormat = Dates.getDefaultDateFormat();
    // Hack: Some date-fns formats specifies 'y' as a match for many types of years.
    // We will change that to 'yyyy' instead.
    if ((dateFormat.match(/y/g) || []).length === 1) {
      dateFormat = dateFormat.replace('y', 'yyyy');
    }
    let dateFormatNoSeps = dateFormat.replace(/[^a-zA-Z]/g, '');
    if (value.length < dateFormat.length) {
      dateFormat = dateFormat.substr(0, value.length);
    }
    if (value.length < dateFormatNoSeps.length) {
      dateFormatNoSeps = dateFormatNoSeps.substr(0, value.length);
    }
    var date = value == '' ? new Date() : parse(value, dateFormat, new Date());
    if (!Dates.isValid(date)) {
      date = value == '' ? new Date() : parse(value, dateFormatNoSeps, new Date());
    }
    if (!Dates.isValid(date)) {
      date = null;
    }
    return Dates.dateToFiscalDate(date);
  }
  static isValid(date) {
    return date instanceof Date && !isNaN(date.getTime());
  }
  static format(date, formatStr = 'P') {
    return format(date, formatStr, {
      locale: Dates.getLocale()
    });
  }
  static formatWeekDay(weekDayNumber, width = 'full') {
    const localeObj = Dates.getLocale();
    return localeObj.localize.day(weekDayNumber, { width: width });
  }
  static formatMonth(monthNumber, width = 'full') {
    const localeObj = Dates.getLocale();
    return localeObj.localize.month(monthNumber, { width: width });
  }
  static getLocale() {
    var localeObj = locales[Platform.getLanguage()];
    if (!localeObj) {
      localeObj = locales['en'];
    }
    return localeObj;
  }
}
