import { h as hasClass } from './elements-aa87c064.js';
import { i as i18n } from './i18n-50ab32ba.js';
import { C as Colors } from './colors-36f77779.js';

const repeat = (func, wait = 0, times = 3) => {
  let timer;
  let count;
  return (...args) => {
    return new Promise(resolve => {
      count = 0;
      timer = setInterval(() => {
        count++;
        let success = false;
        try {
          success = func(...args);
        }
        catch (error) {
          success = false;
        }
        if (success || count >= times) {
          clearInterval(timer);
          resolve(success);
        }
      }, wait);
    });
  };
};

function appGlobalScript () {
  // or export default async function()
  if (!window.XenaDS) {
    window.XenaDS = {};
  }
  window.XenaDS.colors = Colors;
  const getXenaIcon = (type) => {
    let iconName;
    switch (type) {
      case 'primary':
        iconName = 'fas-info-circle';
        break;
      case 'success':
        iconName = 'fas-check-circle';
        break;
      case 'info':
        iconName = 'fas-cog';
        break;
      case 'warning':
        iconName = 'fas-exclamation-circle';
        break;
      case 'danger':
        iconName = 'fas-exclamation-circle';
        break;
      default:
        iconName = 'fas-info-circle';
        break;
    }
    return Object.assign(document.createElement('xena-icon'), {
      slot: 'icon',
      name: iconName
    });
  };
  const getPrimaryActionButtonType = (alertType) => {
    switch (alertType) {
      case 'default':
        return 'default';
      case 'danger':
        return 'danger';
      default:
        return 'primary';
    }
  };
  var modalQueue = [];
  var modalShowing = null;
  function openModal(modal) {
    modalShowing = modal;
    document.body.append(modal);
    repeat(hasClass, 20, 5)(modal, 'hydrated').then(_ => (modal.open = true));
  }
  function handleModalInit(modal) {
    if (modalQueue.length == 0 && modalShowing == null) {
      openModal(modal);
    }
    else {
      modalQueue.push(modal);
    }
  }
  function handleModalResolve() {
    modalShowing = null;
    if (modalQueue.length == 0)
      return;
    const tempModal = modalQueue.splice(0, 1)[0];
    openModal(tempModal);
  }
  window.XenaDS.alert = (message, type = 'primary', header, buttonText) => {
    return new Promise(resolve => {
      const modal = Object.assign(document.createElement('xena-modal'), {
        noHeader: true,
        noBodyPadding: true
      });
      const alert = Object.assign(document.createElement('xena-alert'), {
        type: type,
        header: header,
        removeBorders: true,
        open: true
      });
      alert.innerHTML = message;
      alert.append(getXenaIcon(type));
      const closeBtn = Object.assign(document.createElement('xena-button'), {
        slot: 'footer',
        type: getPrimaryActionButtonType(type),
        textContent: buttonText || i18n('OK'),
        onclick: () => {
          modal.hide();
          modal.parentNode.removeChild(modal);
          resolve();
          handleModalResolve();
        }
      });
      modal.append(alert);
      modal.append(closeBtn);
      handleModalInit(modal);
    });
  };
  window.XenaDS.confirm = (message, type = 'primary', header, confirmText, cancelText) => {
    return new Promise(resolve => {
      const modal = Object.assign(document.createElement('xena-modal'), {
        noHeader: true,
        noBodyPadding: true
      });
      const alert = Object.assign(document.createElement('xena-alert'), {
        type: type,
        header: header,
        removeBorders: true,
        open: true
      });
      alert.innerHTML = message;
      alert.prepend(getXenaIcon(type));
      const callback = response => {
        modal.hide();
        modal.parentNode.removeChild(modal);
        resolve(response);
        handleModalResolve();
      };
      const cancelBtn = Object.assign(document.createElement('xena-button'), {
        type: 'default',
        textContent: cancelText || i18n('CANCEL'),
        onclick: () => callback(false),
        slot: 'footer'
      });
      const confirmBtn = Object.assign(document.createElement('xena-button'), {
        type: getPrimaryActionButtonType(type),
        textContent: confirmText || i18n('CONFIRM'),
        onclick: () => callback(true),
        slot: 'footer'
      });
      modal.append(alert);
      modal.append(cancelBtn);
      modal.append(confirmBtn);
      handleModalInit(modal);
    });
  };
}

const globalScripts = appGlobalScript;

export { globalScripts as g };
