import { r as registerInstance, c as createEvent, h, g as getElement } from './index-9032f50f.js';

const listCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:block}xena-menu{min-width:170px}";

let AutocompleteList = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.xnSelect = createEvent(this, "xnSelect", 7);
    /**
     * The text to show when no results are in the list.
     */
    this.noResultText = 'No results';
    /**
     * The property name for the id of the item.
     */
    this.idProperty = 'id';
    /**
     * The property name for the label of the item shown in the list.
     */
    this.labelProperty = 'label';
  }
  /**
   * Retrieves the menu element.
   */
  getMenuElement() {
    return Promise.resolve(this.menu);
  }
  handleSelection(ev) {
    ev.stopPropagation();
    this.xnSelect.emit(ev.detail);
  }
  resolveId(entry) {
    return entry[this.idProperty];
  }
  resolveListLabel(entry) {
    if (typeof this.labelProperty === 'function') {
      return this.labelProperty(entry);
    }
    else {
      return entry[this.labelProperty];
    }
  }
  resolveIcon(entry) {
    if (typeof this.iconProperty === 'function') {
      return this.iconProperty(entry);
    }
    else {
      return entry[this.iconProperty];
    }
  }
  componentDidRender() {
    if (this.defaultActiveIndex !== undefined) {
      const items = this.hostElement.querySelectorAll('xena-menu-item');
      items.forEach((item, index) => item.setActive(index === this.defaultActiveIndex));
    }
  }
  render() {
    return (h("xena-menu", { onXnSelect: ev => this.handleSelection(ev), ref: el => (this.menu = el), tabindex: "-1" }, this.entries.length === 0 ? h("xena-menu-item", { disabled: true }, this.noResultText) : null, this.entries.map(entry => (h("xena-menu-item", { value: this.resolveId(entry) }, this.resolveListLabel(entry), this.iconProperty != null ? h("xena-icon", { slot: "suffix", name: this.resolveIcon(entry) }) : null)))));
  }
  get hostElement() { return getElement(this); }
};
AutocompleteList.style = listCss;

export { AutocompleteList as xena_autocomplete_list };
