import { r as registerInstance, c as createEvent, h } from './index-9032f50f.js';
import { C as Colors } from './colors-36f77779.js';

const colorCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}";

let Color = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.valueChange = createEvent(this, "valueChange", 7);
    this.checkedChange = createEvent(this, "checkedChange", 7);
    /** Set to true to disable the component. */
    this.disabled = false;
    /** Set to true to make the component selectable. */
    this.selectable = false;
    /** Set to true to draw the component in a checked state. */
    this.checked = false;
    /**
     * The color value of this component.
     */
    this.value = 'white';
  }
  handleCheckedChange() {
    this.radio.checked = this.checked;
  }
  /** Sets focus on the radio. */
  async setFocus(options) {
    this.radio.setFocus(options);
  }
  /** Removes focus from the radio. */
  async removeFocus() {
    this.radio.removeFocus();
  }
  onCheckedChange(ev) {
    ev.stopPropagation();
    this.checked = this.radio.checked;
    this.checkedChange.emit(this.checked);
  }
  componentDidRender() {
    let backgroundColor;
    let backgroundColorHover;
    let backgroundColorFocus;
    let backgroundColorSelected;
    let backgroundColorSelectedHover;
    let backgroundColorSelectedFocus;
    let borderColor = 'var(--xena-input-border-color)';
    let borderColorFocus = 'var(--xena-input-border-color-hover)';
    let borderColorHover = 'var(--xena-input-border-color-hover)';
    let borderColorSelected = `var(${Colors.getColorShade('blue', 500)})`;
    let borderColorSelectedFocus = `var(${Colors.getColorShade('blue', 500)})`;
    let borderColorSelectedHover = `var(${Colors.getColorShade('blue', 500)})`;
    let dotColor = 'var(--xena-color-white)';
    if (this.value === 'white') {
      dotColor = `var(${Colors.getColorShade('blue', 500)})`;
      backgroundColor = `var(--xena-color-white)`;
      backgroundColorFocus = backgroundColor;
      backgroundColorHover = backgroundColor;
      backgroundColorSelected = backgroundColor;
      backgroundColorSelectedFocus = backgroundColor;
      backgroundColorSelectedHover = backgroundColor;
    }
    else if (Colors.colors.indexOf(this.value) >= 0) {
      backgroundColor = `var(${Colors.getColorShade(this.value, 500)})`;
      backgroundColorHover = `var(${Colors.getColorShade(this.value, 400)})`;
      backgroundColorFocus = `var(${Colors.getColorShade(this.value, 400)})`;
      backgroundColorSelected = `var(${Colors.getColorShade(this.value, 500)})`;
      backgroundColorSelectedHover = `var(${Colors.getColorShade(this.value, 400)})`;
      backgroundColorSelectedFocus = `var(${Colors.getColorShade(this.value, 400)})`;
      borderColor = `var(${Colors.getColorShade(this.value, 500)})`;
      borderColorHover = `var(${Colors.getColorShade(this.value, 500)})`;
      borderColorFocus = `var(${Colors.getColorShade(this.value, 500)})`;
      borderColorSelected = `var(${Colors.getColorShade(this.value, 500)})`;
      borderColorSelectedHover = `var(${Colors.getColorShade(this.value, 500)})`;
      borderColorSelectedFocus = `var(${Colors.getColorShade(this.value, 500)})`;
    }
    else {
      backgroundColor = this.value;
      backgroundColorHover = this.value;
      backgroundColorFocus = this.value;
      backgroundColorSelected = this.value;
      backgroundColorSelectedHover = this.value;
      backgroundColorSelectedFocus = this.value;
    }
    this.radio.setAttribute('style', `
            --dot: ${dotColor};
            --background-color: ${backgroundColor};
            --background-color--hover: ${backgroundColorHover};
            --background-color--focus: ${backgroundColorFocus};
            --background-color--selected: ${backgroundColorSelected};
            --background-color--selected-hover: ${backgroundColorSelectedHover};
            --background-color--selected-focus: ${backgroundColorSelectedFocus};
            --border-color: ${borderColor};
            --border-color--hover: ${borderColorHover};
            --border-color--focus: ${borderColorFocus};
            --border-color--selected: ${borderColorSelected};
            --border-color--selected-hover: ${borderColorSelectedHover};
            --border-color--selected-focus: ${borderColorSelectedFocus};
        `);
  }
  render() {
    return (h("xena-radio", { class: "color", ref: el => (this.radio = el), part: "base", disabled: this.disabled, readonly: !this.selectable, checked: this.checked, onCheckedChange: ev => this.onCheckedChange(ev) }));
  }
  static get watchers() { return {
    "checked": ["handleCheckedChange"]
  }; }
};
Color.style = colorCss;

export { Color as xena_color };
