import { r as registerInstance, c as createEvent, h, g as getElement } from './index-9032f50f.js';

const radioGroupCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}::slotted(:not(xena-radio)){display:none}::slotted(xena-radio){display:block}";

let ColorPicker = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.valueChange = createEvent(this, "valueChange", 7);
    /** Set to true to disable the component. */
    this.disabled = false;
  }
  onValueChanged() {
    this.valueChange.emit(this.value);
    this.syncItemsFromValue();
  }
  componentDidLoad() {
    this.radioGroup.addEventListener('checkedChange', ev => this.handleCheckedChange(ev));
    this.syncItemsFromValue();
  }
  syncItemsFromValue() {
    const items = this.getItems();
    const value = this.value;
    // Sync checked states
    items.map(item => (item.checked = item.value === value));
  }
  getItems() {
    if (this.radioGroup == null)
      return [];
    const slot = this.radioGroup.querySelector('slot');
    const otherThanSlot = this.radioGroup.children;
    return [...otherThanSlot, ...slot.assignedElements({ flatten: true })].filter((el) => el.tagName.toLowerCase() === 'xena-radio' && !el.disabled);
  }
  handleCheckedChange(ev) {
    const target = ev.target;
    if (target.checked) {
      this.value = target.value;
    }
  }
  handleSlotChange() {
    this.syncItemsFromValue();
    this.reportDuplicateItemValues();
  }
  reportDuplicateItemValues() {
    const items = this.getItems();
    // Report duplicate values
    const duplicateValues = items.map(item => item.value).filter((e, i, a) => a.indexOf(e) !== i);
    if (duplicateValues.length) {
      throw new Error('Duplicate value found on <xena-radio> in <xena-radio-group>: "' + duplicateValues.join('", "') + '"');
    }
  }
  render() {
    return (h("div", { class: "radio-group", ref: el => (this.radioGroup = el) }, h("slot", { onSlotchange: _ => this.handleSlotChange() })));
  }
  get host() { return getElement(this); }
  static get watchers() { return {
    "value": ["onValueChanged"]
  }; }
};
ColorPicker.style = radioGroupCss;

export { ColorPicker as xena_radio_group };
