import { r as registerInstance, c as createEvent, h } from './index-9032f50f.js';

const switchCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{--height:var(--xena-toggle-size);--thumb-size:calc(var(--xena-toggle-size) + 4px);--width:calc(var(--height) * 2);display:inline-block}.switch{display:inline-flex;align-items:center;font-family:var(--xena-input-font-family);font-size:var(--xena-input-font-size-medium);font-weight:var(--xena-input-font-weight);color:var(--xena-input-color);vertical-align:middle;cursor:pointer}.switch__control{position:relative;display:inline-flex;align-items:center;justify-content:center;width:var(--width);height:var(--height);background-color:var(--xena-color-gray-300);border:solid var(--xena-input-border-width) var(--xena-color-gray-300);border-radius:var(--height);transition:var(--xena-transition-fast) border-color, var(--xena-transition-fast) background-color}.switch__control .switch__thumb{width:var(--thumb-size);height:var(--thumb-size);background-color:var(--xena-color-white);border-radius:50%;border:solid var(--xena-input-border-width) var(--xena-color-gray-300);outline:solid 0 var(--xena-focus-ring-color-blue);transform:translateX(calc(var(--width) / -2 + var(--thumb-size) / 2 - (var(--thumb-size) - var(--height)) / 2));transition:var(--xena-transition-fast) transform ease, var(--xena-transition-fast) background-color, var(--xena-transition-fast) border-color, outline var(--xena-transition-x-fast) ease-in-out}.switch__control input[type=checkbox]{position:absolute;opacity:0;padding:0;margin:0;pointer-events:none}.switch:not(.switch--checked):not(.switch--disabled) .switch__control:hover{background-color:var(--xena-color-gray-200);border-color:var(--xena-color-gray-200)}.switch:not(.switch--checked):not(.switch--disabled) .switch__control:hover .switch__thumb{background-color:var(--xena-color-white);border-color:var(--xena-input-border-color)}.switch.switch--focused:not(.switch--checked):not(.switch--disabled) .switch__control{background-color:var(--xena-color-gray-200);border-color:var(--xena-color-gray-200)}.switch.switch--focused:not(.switch--checked):not(.switch--disabled) .switch__control .switch__thumb{background-color:var(--xena-color-white);border-color:var(--xena-color-blue-500);outline-width:var(--xena-focus-ring-width)}.switch--checked .switch__control{background-color:var(--xena-color-blue-500);border-color:var(--xena-color-blue-500)}.switch--checked .switch__control .switch__thumb{background-color:var(--xena-color-white);border-color:var(--xena-color-blue-500);transform:translateX(calc(var(--width) / 2 - var(--thumb-size) / 2 + (var(--thumb-size) - var(--height)) / 2))}.switch.switch--checked:not(.switch--disabled) .switch__control:hover{background-color:var(--xena-color-blue-400);border-color:var(--xena-color-blue-400)}.switch.switch--checked:not(.switch--disabled) .switch__control:hover .switch__thumb{background-color:var(--xena-color-white);border-color:var(--xena-color-blue-500)}.switch.switch--checked:not(.switch--disabled).switch--focused .switch__control{background-color:var(--xena-color-blue-400);border-color:var(--xena-color-blue-400)}.switch.switch--checked:not(.switch--disabled).switch--focused .switch__control .switch__thumb{background-color:var(--xena-color-white);border-color:var(--xena-color-blue-500);outline-width:var(--xena-focus-ring-width)}.switch--disabled{opacity:0.5;cursor:not-allowed}.switch__label{line-height:var(--height);margin-left:0.5em;user-select:none}.switch--label-margin{margin-top:32px}";

let id = 0;
let Switch = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.xnBlur = createEvent(this, "xnBlur", 7);
    this.checkedChange = createEvent(this, "checkedChange", 7);
    this.xnFocus = createEvent(this, "xnFocus", 7);
    this.switchId = `switch-${++id}`;
    this.labelId = `switch-label-${id}`;
    this.hasFocus = false;
    /** Set to true to disable the switch. */
    this.disabled = false;
    /** Set to true to make the switch a required field. */
    this.required = false;
    /** Set to true to draw the switch in a checked state. */
    this.checked = false;
    /** This will be true when the control is in an invalid state. Validity is determined by the `required` prop. */
    this.invalid = false;
    /** Set to true if margin matching other input's label space should be added. */
    this.labelMargin = false;
  }
  handleCheckedChange() {
    this.checkedChange.emit(this.checked);
  }
  connectedCallback() {
    this.handleClick = this.handleClick.bind(this);
    this.handleBlur = this.handleBlur.bind(this);
    this.handleFocus = this.handleFocus.bind(this);
    this.handleKeyDown = this.handleKeyDown.bind(this);
    this.handleMouseDown = this.handleMouseDown.bind(this);
  }
  /** Sets focus on the switch. */
  async setFocus(options) {
    this.input.focus(options);
  }
  /** Removes focus from the switch. */
  async removeFocus() {
    this.input.blur();
  }
  /** Checks for validity and shows the browser's validation message if the control is invalid. */
  async reportValidity() {
    return this.input.reportValidity();
  }
  /** Sets a custom validation message. If `message` is not empty, the field will be considered invalid. */
  async setCustomValidity(message) {
    this.input.setCustomValidity(message);
    this.invalid = !this.input.checkValidity();
  }
  handleClick() {
    this.checked = this.input.checked;
  }
  handleBlur() {
    this.hasFocus = false;
    this.xnBlur.emit();
  }
  handleFocus() {
    this.hasFocus = true;
    this.xnFocus.emit();
  }
  handleKeyDown(event) {
    if (event.key === 'ArrowLeft') {
      event.preventDefault();
      this.checked = false;
    }
    if (event.key === 'ArrowRight') {
      event.preventDefault();
      this.checked = true;
    }
  }
  handleMouseDown(event) {
    // Prevent clicks on the label from briefly blurring the input
    event.preventDefault();
    this.input.focus();
  }
  render() {
    return (h("label", { part: "base", htmlFor: this.switchId, class: {
        switch: true,
        'switch--checked': this.checked,
        'switch--disabled': this.disabled,
        'switch--focused': this.hasFocus,
        'switch--label-margin': this.labelMargin
      }, onMouseDown: this.handleMouseDown }, h("span", { part: "control", class: "switch__control" }, h("span", { part: "thumb", class: "switch__thumb" }), h("input", { ref: el => (this.input = el), id: this.switchId, type: "checkbox", name: this.name, value: this.value, checked: this.checked, disabled: this.disabled, required: this.required, role: "switch", "aria-checked": this.checked ? 'true' : 'false', "aria-labelledby": this.labelId, onClick: this.handleClick, onBlur: this.handleBlur, onFocus: this.handleFocus, onKeyDown: this.handleKeyDown })), h("span", { part: "label", id: this.labelId, class: "switch__label" }, h("slot", null))));
  }
  static get watchers() { return {
    "checked": ["handleCheckedChange"]
  }; }
};
Switch.style = switchCss;

export { Switch as xena_switch };
