import { EventEmitter } from '../../stencil-public-runtime';
import { ShapeTypes, SizeTypes } from '../../utils/types';
/**
 * @since 1.0
 * @status experimental
 *
 * @slot prefix - Used to prepend an icon or text element to the autocompletes input field.
 * @slot suffix - Used to append an icon or text element to the autocompletes input field.
 *
 * @part input - The component's input field
 * @part calendar - The calendar popup.
 * @part prefix - The prefix container.
 * @part suffix - The suffix container.
 */
export declare class FiscalDatepicker {
  el: HTMLXenaFiscalDatepickerElement;
  dropdown: HTMLXenaDropdownElement;
  private textInput?;
  private calendar?;
  private isFocused;
  private text;
  private hasPrefixSlot;
  private hasSuffixSlot;
  /** Emitted when selected date changes. */
  dateChange: EventEmitter;
  /**
   * Defines the currently selected date. If not set, the current date date will be used.
   */
  date: number;
  /**
   * Defines the systemDate as a fiscalDate. If not set, the current date will automatically be selected.
   */
  systemDate: number;
  /**
   * If `true`, the user cannot interact with the input.
   */
  disabled: boolean;
  /** The datepicker's label. */
  label: string;
  /** The datepicker's help text. */
  helpText: string;
  /** Indicates whether or not the dropdown is open. You can use this in lieu of the show/hide methods. */
  open: boolean;
  /**
   * Defines the shape of the input field.
   */
  shape: ShapeTypes;
  /**
   * Defines the size of the input field.
   */
  size: SizeTypes;
  /**
   * Retrieves the native input element.
   */
  getInputElement(): Promise<HTMLInputElement>;
  /**
   * Set focus on the native input element.
   */
  setFocus(): Promise<void>;
  /**
   * Closes the calendar popup if open.
   */
  hide(): Promise<void>;
  /**
   * Opens the calendar popup if closed.
   */
  show(): Promise<void>;
  handleTextChange(): void;
  componentWillLoad(): void;
  private handleDropdownShow;
  private handleDropdownAfterHide;
  private handleInputChange;
  private updateValues;
  private dateSelected;
  private handleFocus;
  private handleBlur;
  get formattedDate(): string;
  render(): any;
}
