import { EventEmitter } from '../../stencil-public-runtime';
/**
 * @since 1.0
 * @status stable
 *
 * @slot - The menu's content, including menu items, menu dividers, and menu labels.
 *
 * @part base - The component's base wrapper.
 */
export declare class Menu {
  host: HTMLXenaMenuElement;
  menu: HTMLElement;
  typeToSelectString: string;
  typeToSelectTimeout: any;
  hostIsScrollable: boolean;
  hasFocus: boolean;
  /** Emitted when the menu gains focus. */
  xnFocus: EventEmitter;
  /** Emitted when the menu loses focus. */
  xnBlur: EventEmitter;
  /** Emitted when a menu item is selected. */
  xnSelect: EventEmitter;
  connectedCallback(): void;
  componentDidRender(): void;
  /** Sets focus on the menu. */
  setFocus(): Promise<void>;
  /** Removes focus from the menu. */
  removeFocus(): Promise<void>;
  /**
   * Select the active menu element.
   */
  selectActiveMenuElement(): Promise<void>;
  /**
   * Initiates type-to-select logic, which automatically selects an option based on what the user is currently typing.
   * The key passed will be appended to the internal query and the selection will be updated. After a brief period, the
   * internal query is cleared automatically. This method is intended to be used with the keydown event. Useful for
   * enabling type-to-select when the menu doesn't have focus.
   */
  typeToSelect(key: string): Promise<void>;
  getItems(): [HTMLXenaMenuItemElement];
  getActiveItem(): HTMLXenaMenuItemElement;
  setActiveItem(item?: HTMLXenaMenuItemElement): void;
  handleFocus(): void;
  handleBlur(): void;
  handleClick(event: MouseEvent): void;
  handleKeyDown(event: KeyboardEvent): void;
  handleMouseOver(event: MouseEvent): void;
  handleMouseOut(): void;
  render(): any;
}
