import { EventEmitter } from '../../stencil-public-runtime';
/**
 * @since 1.8
 * @status experimental
 *
 * @part base - The component's base wrapper.
 * @part container - The slider's container.
 * @part handler - The slider's handler.
 */
export declare class Slider {
  private element;
  /** The components value is split into 'x' and 'y'. Default values are 0. */
  value: string | number | {
    x: number;
    y: number;
  };
  /** The property for setting the slider's minimum value. Default is 0. */
  min: string | number | {
    x: number;
    y: number;
  };
  /** The property for setting the slider's maximum value. Default is 100. */
  max: string | number | {
    x: number;
    y: number;
  };
  /** The slider type. Default is horizontal. */
  type: 'horizontal' | 'vertical' | 'both';
  /** Container height is set with the height-property. It is set with pixels or percentage of containing element. */
  height: string;
  /** Container width is set with the width-property. It is set with pixels or percentage of containing element. */
  width: string;
  /** Value is emitted when the handler is moved via mousedown or mousemove events. */
  valueChange: EventEmitter<{
    x: number;
    y: number;
  }>;
  private _value;
  private _min;
  private _max;
  valueUpdated(): void;
  minUpdated(): void;
  maxUpdated(): void;
  parseInput(value: string | number | {
    x: number;
    y: number;
  }): {
    x: number;
    y: number;
  };
  private isDragging;
  private handler;
  private container;
  componentWillLoad(): void;
  componentDidLoad(): void;
  private handleMouseDown;
  private handleMouseMove;
  private handleMouseUp;
  private handleSelectStart;
  private setHandlerPosition;
  setWidth(): string;
  setHeight(): string;
  render(): any;
}
