import { EventEmitter } from '../../stencil-public-runtime';
/**
 * @since 1.8
 * @status experimental
 *
 * @slot nav - Used for grouping tabs in the tab group.
 * @slot - Used for grouping tab panels in the tab group.
 *
 * @part base - The component's base wrapper.
 * @part nav - The tab group navigation container.
 * @part tabs - The container that wraps the slotted tabs.
 * @part active-tab-indicator - An element that displays the currently selected tab. This is a child of the tabs container.
 * @part body - The tab group body where tab panels are slotted in.
 * @part scroll-button - The previous and next scroll buttons that appear when tabs are scrollable.
 */
export declare class TabGroup {
  activeTab: HTMLXenaTabElement;
  activeTabIndicator: HTMLElement;
  body: HTMLElement;
  mutationObserver: MutationObserver;
  nav: HTMLElement;
  resizeObserver: ResizeObserver;
  tabGroup: HTMLElement;
  tabs: HTMLElement;
  host: HTMLXenaTabGroupElement;
  hasScrollControls: boolean;
  /** The placement of the tabs. */
  placement: 'top' | 'bottom' | 'left' | 'right';
  /** Disables the scroll arrows that appear when tabs overflow. */
  noScrollControls: boolean;
  /** Name of the selected tab */
  value: string;
  handlePlacementChange(): void;
  handleNoScrollControlsChange(): void;
  handleValueChange(): void;
  /** Emitted when value changes */
  valueChange: EventEmitter;
  /** Emitted when a tab is shown. */
  xnTabShow: EventEmitter<{
    name: string;
  }>;
  /** Emitted when a tab is hidden. */
  xnTabHide: EventEmitter<{
    name: string;
  }>;
  connectedCallback(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  /** Shows the specified tab panel. */
  show(panel: string): Promise<void>;
  getAllTabs(includeDisabled?: boolean): [HTMLXenaTabElement];
  getAllPanels(): [HTMLXenaTabPanelElement];
  getActiveTab(): HTMLXenaTabElement;
  handleClick(event: MouseEvent): boolean;
  handleKeyDown(event: KeyboardEvent): boolean;
  handleScrollLeft(): void;
  handleScrollRight(): void;
  updateScrollControls(): void;
  setActiveTab(tab: HTMLXenaTabElement, emitEvents?: boolean): void;
  setAriaLabels(): void;
  syncActiveTabIndicator(): void;
  render(): any;
}
