# Avatar

[component-header:xena-avatar]

Avatars are used to represent a person or object.

```html preview
<xena-avatar></xena-avatar>
```

## Examples

### Images

To use an image for the avatar, set the `image` and `alt` attributes. This will take priority and be shown over initials and icons.

```html preview
<xena-avatar
  image="https://images.unsplash.com/photo-1529778873920-4da4926a72c2?ixlib=rb-1.2.1&auto=format&fit=crop&w=300&q=80"
  alt="Gray tabby kitten looking down"
></xena-avatar>
```

### Initials

When you don't have an image to use, you can set the `initials` attribute to show something more personalized than an icon.

```html preview
<xena-avatar initials="UN"></xena-avatar> User name<br /><br />
<xena-avatar initials="Co" shape="square"></xena-avatar> Company name
```

### Custom Icons

When no image or initials are set, an icon will be shown. The default avatar shows a generic "user" icon, but you can customize this with the `icon` slot.

```html preview
<xena-avatar>
  <xena-icon slot="icon" name="image"></xena-icon>
</xena-avatar>

<xena-avatar>
  <xena-icon slot="icon" name="fas-allergies"></xena-icon>
</xena-avatar>

<xena-avatar>
  <xena-icon slot="icon" name="fas-bus"></xena-icon>
</xena-avatar>
```

### Shapes

Avatars can be shaped using the `shape` attribute.

```html preview
<xena-avatar shape="square"></xena-avatar>

<xena-avatar shape="rounded"></xena-avatar>

<xena-avatar shape="circle"></xena-avatar>
```

### Avatar Groups

You can group avatars with a few lines of CSS.

```html preview
<div class="avatar-group">
  <xena-avatar
    image="https://images.unsplash.com/photo-1490150028299-bf57d78394e0?ixid=MXwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHw%3D&ixlib=rb-1.2.1&auto=format&fit=crop&w=256&h=256&q=80&crop=right"
  ></xena-avatar>
  <xena-avatar
    image="https://images.unsplash.com/photo-1503454537195-1dcabb73ffb9?ixid=MXwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHw%3D&ixlib=rb-1.2.1&auto=format&fit=crop&w=256&h=256&crop=left&q=80"
  ></xena-avatar>
  <xena-avatar
    image="https://images.unsplash.com/photo-1456439663599-95b042d50252?ixid=MXwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHw%3D&ixlib=rb-1.2.1&auto=format&fit=crop&w=256&h=256&crop=left&q=80"
  ></xena-avatar>
  <xena-avatar
    image="https://images.unsplash.com/flagged/photo-1554078875-e37cb8b0e27d?ixid=MXwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHw%3D&ixlib=rb-1.2.1&auto=format&fit=crop&w=256&h=256&crop=top&q=80"
  ></xena-avatar>
</div>

<style>
  .avatar-group xena-avatar:not(:first-of-type) {
    margin-left: -1rem;
  }

  .avatar-group xena-avatar::part(base) {
    border: solid 2px white;
  }
</style>
```

[component-metadata:xena-avatar]
