# Button Group

[component-header:xena-button-group]

Button groups can be used to group related buttons into sections.

```html preview
<xena-button-group>
  <xena-button>Left</xena-button>
  <xena-button>Center</xena-button>
  <xena-button>Right</xena-button>
</xena-button-group>
```

## Examples

### Button Sizes

All button sizes are supported, but avoid mixing sizes within the same button group.

```html preview
<xena-button-group>
  <xena-button size="small">Left</xena-button>
  <xena-button size="small">Center</xena-button>
  <xena-button size="small">Right</xena-button>
</xena-button-group>

<br /><br />

<xena-button-group>
  <xena-button size="medium">Left</xena-button>
  <xena-button size="medium">Center</xena-button>
  <xena-button size="medium">Right</xena-button>
</xena-button-group>

<br /><br />

<xena-button-group>
  <xena-button size="large">Left</xena-button>
  <xena-button size="large">Center</xena-button>
  <xena-button size="large">Right</xena-button>
</xena-button-group>
```

### Theme Buttons

Theme buttons are supported through the button's `type` attribute.

```html preview
<xena-button-group>
  <xena-button type="primary">Left</xena-button>
  <xena-button type="primary">Center</xena-button>
  <xena-button type="primary">Right</xena-button>
</xena-button-group>

<br /><br />

<xena-button-group>
  <xena-button type="danger">Left</xena-button>
  <xena-button type="danger">Center</xena-button>
  <xena-button type="danger">Right</xena-button>
</xena-button-group>
```

### Dropdowns in Button Groups

Dropdowns can be placed inside button groups as long as the trigger is a `<xena-button>` element.

```html preview
<xena-button-group>
  <xena-button>Button</xena-button>
  <xena-button>Button</xena-button>
  <xena-dropdown>
    <xena-button slot="trigger" caret>Dropdown</xena-button>
    <xena-menu>
      <xena-menu-item>Item 1</xena-menu-item>
      <xena-menu-item>Item 2</xena-menu-item>
      <xena-menu-item>Item 3</xena-menu-item>
    </xena-menu>
  </xena-dropdown>
</xena-button-group>
```

### Split Buttons

Create a split button using a button and a dropdown.

```html preview
<xena-button-group>
  <xena-button type="primary">Save</xena-button>
  <xena-dropdown placement="bottom-end">
    <xena-button slot="trigger" type="primary">
      <xena-icon name="fas-angle-down"></xena-icon>
    </xena-button>
    <xena-menu>
      <xena-menu-item>Save</xena-menu-item>
      <xena-menu-item>Save as&hellip;</xena-menu-item>
      <xena-menu-item>Save all</xena-menu-item>
    </xena-menu>
  </xena-dropdown>
</xena-button-group>
```

### Tooltips in Button Groups

Buttons can be wrapped in tooltips to provide more detail when the user interacts with them.

```html preview
<xena-button-group>
  <xena-tooltip content="I'm on the left">
    <xena-button>Left</xena-button>
  </xena-tooltip>

  <xena-tooltip content="I'm in the middle">
    <xena-button>Center</xena-button>
  </xena-tooltip>

  <xena-tooltip content="I'm on the right">
    <xena-button>Right</xena-button>
  </xena-tooltip>
</xena-button-group>
```

### Toolbar Example

Create interactive toolbars with button groups.

```html preview
<div class="button-group-toolbar">
  <xena-button-group label="Formatting">
    <xena-tooltip content="Bold">
      <xena-button><xena-icon name="fas-bold"></xena-icon></xena-button>
    </xena-tooltip>
    <xena-tooltip content="Italic">
      <xena-button><xena-icon name="fas-italic"></xena-icon></xena-button>
    </xena-tooltip>
    <xena-tooltip content="Underline">
      <xena-button><xena-icon name="fas-underline"></xena-icon></xena-button>
    </xena-tooltip>
  </xena-button-group>

  <xena-button-group label="Alignment">
    <xena-tooltip content="Align Left">
      <xena-button><xena-icon name="fas-align-left"></xena-icon></xena-button>
    </xena-tooltip>
    <xena-tooltip content="Align Center">
      <xena-button><xena-icon name="fas-align-justify"></xena-icon></xena-button>
    </xena-tooltip>
    <xena-tooltip content="Align Right">
      <xena-button><xena-icon name="fas-align-right"></xena-icon></xena-button>
    </xena-tooltip>
  </xena-button-group>
</div>

<style>
  .button-group-toolbar xena-button-group:not(:last-of-type) {
    margin-right: var(--xena-spacing-x-small);
  }
</style>
```

[component-metadata:xena-button-group]
