# Button

[component-header:xena-button]

Buttons represent actions that are available to the user.

```html preview
<xena-button>Button</xena-button>
```

## Examples

### Types

Use the `type` attribute to set the button's type.

```html preview
<xena-button type="default">Default</xena-button>
<xena-button type="primary">Primary</xena-button>
<xena-button type="danger">Danger</xena-button>
```

### Modes

Use the `mode` attribute to alter the button's visual style.

#### Ghost button

```html preview
<xena-button type="default" mode="ghost">Default ghost</xena-button>
<xena-button type="primary" mode="ghost">Primary ghost</xena-button>
<xena-button type="danger" mode="ghost">Danger ghost</xena-button>
```

#### Text button

```html preview
<xena-button type="default" mode="text">Default text</xena-button>
<xena-button type="primary" mode="text">Primary text</xena-button>
<xena-button type="danger" mode="text">Danger text</xena-button>
```

### Sizes

Use the `size` prop to change a button's size.

```html preview
<xena-button size="small">Small</xena-button>
<xena-button size="medium">Medium</xena-button>
<xena-button size="large">Large</xena-button>
```

### Link Buttons

It's often helpful to have a button that works like a link. This is possible by setting the `href` attribute, which will make the component render an `<a>` under the hood. This gives you all the default link behavior the browser provides (e.g. <kbd>CMD/CTRL/SHIFT + CLICK</kbd>) and exposes the `target` and `download` attributes.

```html preview
<xena-button href="https://example.com/">Link</xena-button>
<xena-button href="https://example.com/" target="_blank">New Window</xena-button>
<xena-button href="/assets/images/logo.png" download="xena.png">Download</xena-button>
<xena-button href="https://example.com/" disabled>Disabled</xena-button>
```

?> When a `target` is set, the link will receive `rel="noreferrer noopener"` for [security reasons](https://mathiasbynens.github.io/rel-noopener/).

<!--
### Setting a Custom Width

As expected, buttons can be given a custom width by setting its `width`. This is useful for making buttons span the full width of their container on smaller screens.

```html preview
<xena-button
  type="default"
  size="small"
  style="width: 100%; margin-bottom: 1rem;"
  >Small</xena-button
>
<xena-button
  type="default"
  size="medium"
  style="width: 100%; margin-bottom: 1rem;"
  >Medium</xena-button
>
<xena-button type="default" size="large" style="width: 100%;"
  >Large</xena-button
>
```
-->

### Prefix and Suffix Icons

Use the `prefix` and `suffix` slots to add icons.

```html preview
<xena-button type="default">
  <xena-icon slot="prefix" name="fas-cog"></xena-icon>
  Settings
</xena-button>

<xena-button type="default">
  <xena-icon slot="prefix" name="fas-redo"></xena-icon>
  Refresh
</xena-button>

<xena-button type="default">
  <xena-icon slot="prefix" name="fas-link"></xena-icon>
  <xena-icon slot="suffix" name="fas-external-link-square-alt"></xena-icon>
  Open
</xena-button>
```

### Disabled

Use the `disabled` prop to disable a button. Clicks will be suppressed until the disabled state is removed.

```html preview
<xena-button type="default" disabled>Default</xena-button>
<xena-button type="primary" disabled>Primary</xena-button>
<xena-button type="danger" disabled>Danger</xena-button>
```

### Loading

Use the `loading` prop to activate a loading state. This will also apply `disabled` attribute.

```html preview
<xena-button type="default" loading>Default</xena-button>
<xena-button type="primary" loading>Primary</xena-button>
<xena-button type="danger" loading>Danger</xena-button>
```

### Caret

Use the `caret` prop to show a caret at the end of the button.

```html preview
<xena-button mode="standard" type="primary" caret>Standard</xena-button>
<xena-button mode="ghost" caret>Ghost</xena-button>
<xena-button mode="text" caret>Text</xena-button>
```

[component-metadata:xena-button]
