# Empty state

[component-header:xena-empty]

Empty states are moments where there is no data to display. They are mostly seen the first time a user interacts with a feature, but can be used when data has been deleted or is unavailable.

## Example looks

**Default look:** The minimum version of the empty state.

```html preview
<xena-empty></xena-empty>
```

### Custom text

With just enough contextual guidance, empty states ensure a smoothness of experience. Explain clearly the next action to populate the space. Or explain why the space is empty. Tell the benefit of taking next steps.

```html preview
<xena-empty>No pending vouchers</xena-empty>
```

A short and concise explanation as the headline. Where possible, this should be a positive statement.

That first example below, is using an empty icon slot to hide the default icon.

```html preview
<xena-empty header="You don't have access to this module" class="mb-5">
  <span slot="icon"></span>
  Please contact your administrator</xena-empty
>

<xena-empty header="No results found">
  <xena-icon slot="icon" name="fas-search"></xena-icon>
  Try adjusting your search or filters to find what you're looking for</xena-empty
>
```

### Actions

**Primary actions:** Direct the user to a primary action button that help populate the view.

```html preview
<xena-empty header="Orders">
  Create orders to start sell something
  <xena-button type="primary" slot="actions">Create order</xena-button>
</xena-empty>
```

**Secondary actions:** If there is a secondary action, such as reference to documentation, include it as a link below the copy.

```html preview
<xena-empty header="You don't have access to this module">
  Please contact your administrator
  <xena-button type="primary" mode="text" slot="secondary-actions" href="">Learn more</xena-button>
</xena-empty>
```

### Custom illustrations

An image or icon that relates to the situation (optional).

```html preview
<xena-empty header="Contacts">
  <img slot="icon" src="/assets/images/xena-collaboration-platform2.png" style="width: 400px;" />
  This is your customers and suppliers
  <xena-button type="default" slot="actions">View settings</xena-button>
  <xena-button type="primary" slot="actions">Create partner</xena-button>
  <xena-button type="primary" mode="text" slot="secondary-actions">Learn more</xena-button>
</xena-empty>
```

## Example use

### No data empty states

Dropdowns

```html preview
<xena-dropdown>
  <xena-button slot="trigger" caret>Dropdown</xena-button>
  <xena-menu>
    <xena-empty></xena-empty>
  </xena-menu>
</xena-dropdown>
```

Tables

```html preview
<table>
  <tr>
    <th>Column 1</th>
    <th>Column 2</th>
    <th>Column 3</th>
  </tr>
  <tr>
    <td colspan="3"><xena-empty></xena-empty></td>
  </tr>
</table>
```

Tabs/panels

```html preview
<xena-panel header="Calculation">
  <xena-empty></xena-empty>
</xena-panel>
```

### Error management

```html preview
<xena-empty header="Something went wrong">
  <xena-icon slot="icon" name="fas-exclamation-circle"></xena-icon>
  Please try again in a few minutes
</xena-empty>
```

[component-metadata:xena-empty]
