# Icon Button

[component-header:xena-icon-button]

Icons buttons are simple, icon-only buttons that can be used for actions and in toolbars.

For a full list of icons that come bundled with XenaDS, refer to the [icon component](/components/icon).

```html preview
<xena-icon-button name="fas-cog" label="Settings"></xena-icon-button>
<xena-icon-button name="fas-sliders-h" label="Options"></xena-icon-button>
<xena-icon-button name="far-window-close" label="Close"></xena-icon-button>
```

?> Please be aware that when using `Icon Button` in conjunction with **KnockoutJS** DOM manipulative bindings (foreach etc.) event listeners for focus visible functionality can't be unsubscribed. This has no effect if your application refreshes the page once in a while but can lead to performance issues within a Single Page Application (SPA).

## Examples

### Sizes

Icon buttons inherit their parent element's `font-size`.

```html preview
<xena-icon-button name="fas-pencil-alt" label="Edit" style="font-size: 1.5rem;"></xena-icon-button>
<xena-icon-button name="fas-pencil-alt" label="Edit" style="font-size: 2rem;"></xena-icon-button>
<xena-icon-button name="fas-pencil-alt" label="Edit" style="font-size: 2.5rem;"></xena-icon-button>
```

### Link icon button

It's often helpful to have a button that works like a link. This is possible by setting the `href` attribute, which will make the component render an `<a>` under the hood. This gives you all the default link behavior the browser provides (e.g. `CMD/CTRL/SHIFT + CLICK`) and exposes the `target` and `download` attributes.

```html preview
<xena-icon-button name="fas-arrow-right" label="Next page" href="https://xena.biz/"></xena-icon-button>
<xena-icon-button
  name="fas-download"
  label="Download"
  download="Logo file"
  href="/assets/images/logo.png"
></xena-icon-button>
<xena-icon-button
  name="fas-external-link-alt"
  label="Pop out"
  href="https://example.com/"
  target="_blank"
></xena-icon-button>
```

### Colors

Icon buttons are designed to have a uniform appearance, so their color is not inherited. However, you can still customize them by styling the `base` part.

```html preview
<div class="icon-button-color">
  <xena-icon-button name="fas-bold" label="Bold"></xena-icon-button>
  <xena-icon-button name="fas-italic" label="Italic"></xena-icon-button>
  <xena-icon-button name="fas-underline" label="Underline"></xena-icon-button>
</div>

<style>
  .icon-button-color xena-icon-button::part(base) {
    color: #ff0000;
  }

  .icon-button-color xena-icon-button::part(base):hover,
  .icon-button-color xena-icon-button::part(base):focus {
    color: #00ff00;
  }

  .icon-button-color xena-icon-button::part(base):active {
    color: #0000ff;
  }
</style>
```

### Icon Button with Tooltip

Wrap a tooltip around an icon button to provide contextual information to the user.

```html preview
<xena-tooltip content="Settings">
  <xena-icon-button name="fas-cog" label="Settings"></xena-icon-button>
</xena-tooltip>
```

### Disabled

```html preview
<xena-icon-button name="fas-cog" label="Settings" disabled></xena-icon-button>
```

[component-metadata:xena-icon-button]
