# Icon

[component-header:xena-icon]

Icons are symbols that can be used to represent various options within an application.

XenaDS comes bundled with all of the free [Fontawesome Icons](https://fontawesome.com/) project served from the jsDelivr CDN. If you prefer, you can also register [custom icon libraries](/components/icon-library.md).

Click or tap on an icon below to copy its name and use it like this.

```html
<xena-icon name="far-bell"></xena-icon>
```

<div class="icon-search">
  <div class="icon-search-controls">
    <xena-input placeholder="Search Icons"></xena-input>
  </div>
  <div class="icon-list"></div>
  <input type="text" class="icon-copy-input">
</div>

## Examples

### Sizing

Icons are sized relative to the current font size. To change their size, set the `font-size` property on the icon itself or on a parent element as shown below.

```html preview
<div style="font-size: 32px;">
  <xena-icon name="bell"></xena-icon>
  <xena-icon name="clock"></xena-icon>
  <xena-icon name="flag"></xena-icon>
  <xena-icon name="heart"></xena-icon>
  <xena-icon name="image"></xena-icon>
  <xena-icon name="star"></xena-icon>
</div>
```

### Custom Icons

Custom icons can be loaded individually with the `src` attribute. Only SVGs on a local or CORS-enabled endpoint are supported. If you're using more than one custom icon, it might make sense to register a [custom icon library](/components/icon-library.md).

```html preview
<xena-icon src="/assets/images/tiger.svg" style="font-size: 8rem;" label="Tiger"></xena-icon>
```

<!-- Supporting scripts and styles for the search utility -->
<script>
  fetch('/components/icons.json')
    .then(res => res.json())  
    .then(icons => {
      const container = document.querySelector('.icon-search');
      const input = container.querySelector('xena-input');
      const select = container.querySelector('xena-select');
      const copyInput = container.querySelector('.icon-copy-input');
      const loader = container.querySelector('.icon-loader');
      const list = container.querySelector('.icon-list');
      const queue = [];
        
      // Generate icons
      icons.map(i => {
        const item = document.createElement('div');
        item.classList.add('icon-list-item');
        item.setAttribute('data-name', i.name);
        item.setAttribute('data-terms', [i.name, i.title].join(' '));
        item.innerHTML = `<xena-icon name="${i.name}"></xena-icon>`;

        const tooltip = document.createElement('xena-tooltip');
        tooltip.content = i.name;
        
        list.appendChild(tooltip);
        tooltip.appendChild(item);
        
        item.addEventListener('click', () => {
          copyInput.value = i.name;
          copyInput.select();
          document.execCommand('copy');
          tooltip.content = 'Copied!';
          setTimeout(() => tooltip.content = i.name, 1000);
        });
      });

      // Filter as the user types
      input.addEventListener('xnInput', () => {
        [...list.querySelectorAll('.icon-list-item')].map(item => {
          const filter = input.value.toLowerCase();
          if (filter === '') {
            item.style.display = '';
          } else {
            const terms = item.getAttribute('data-terms').toLowerCase();
            const match = terms.indexOf(filter) >= 0
            item.style.display = match ? '' : 'none';
          }
        });
      });
    });
</script>

<style>
  .icon-search {
    border: solid 1px var(--xena-panel-border-color);
    border-radius: var(--xena-border-radius-medium);
    padding: var(--xena-spacing-medium);
  }

  .icon-search-controls {
    display: flex;
  }

  .icon-search-controls xena-input {
    flex: 1 1 auto;
  }

  .icon-search-controls xena-select {
    width: 10rem;
    flex: 0 0 auto;
    margin-left: 1rem;
  }

  .icon-loader {
    display: flex;
    align-items: center;
    justify-content: center;
    min-height: 30vh;
  }

  .icon-list {
    display: grid;
    grid-template-columns: repeat(12, 1fr);
    position: relative;
    margin-top: 1rem;
  }

  .icon-loader[hidden],
  .icon-list[hidden] {
    display: none;
  }

  .icon-list-item {
    display: inline-flex;
    align-items: center;
    justify-content: center;
    border-radius: var(--xena-border-radius-circle);
    font-size: 24px;
    width: 2em;
    height: 2em;
    margin: 0 auto;
    cursor: copy;
    transition: var(--xena-transition-medium) all;
  }

  .icon-list-item:hover {
    background-color: var(--xena-color-blue-500);
    color: var(--xena-color-blue-500);
  }

  .xena-theme-dark .icon-list-item:hover {
    background-color: var(--xena-color-blue-900);
  }

  .icon-list[data-type="outline"] .icon-list-item[data-name$="-fill"] {
    display: none;
  }

  .icon-list[data-type="fill"] .icon-list-item:not([data-name$="-fill"]) {
    display: none;
  }

  .icon-copy-input {
    position: absolute;
    opacity: 0;
    pointer-events: none;
  }

  @media screen and (max-width: 1000px) {
    .icon-list {
      grid-template-columns: repeat(8, 1fr);
    }

    .icon-list-item {
      font-size: 20px;
    }

    .icon-search-controls {
      display: block;
    }

    .icon-search-controls xena-select {
      width: auto;
      margin: 1rem 0 0 0;
    }
  }

  @media screen and (max-width: 500px) {
    .icon-list {
      grid-template-columns: repeat(4, 1fr);
    }    
  }
</style>

[component-metadata:xena-icon]
