# Input

[component-header:xena-input]

Input is a component for getting user input as text, numbers, date etc.

```html preview
<xena-input id="inputf"></xena-input>
<script>
  var el = document.getElementById('inputf');
  el.addEventListener('valueChange', ev => {
    console.log(ev.detail);
  });
</script>
```

### Sizes

Use the `size` prop to change an input's size.

```html preview
<xena-input size="small" class="mb-5"></xena-input>
<xena-input size="medium" class="mb-5"></xena-input>
<xena-input size="large"></xena-input>
```

### Alignments

Use the `alignment` prop to change an input's alignment (only left and right is supported).

```html preview
<xena-input placeholder="I'm to the left" class="mb-5"></xena-input>
<xena-input alignment="right" placeholder="And I'm to the right"></xena-input>
```

### Shapes

Use the `shape` prop to change an input's shape.

```html preview
<xena-input shape="round" class="mb-5"></xena-input>
<xena-input class="mb-5"></xena-input>
<xena-input shape="edged"></xena-input>
```

### Disabled

Use the `disabled` prop to disable an input.

```html preview
<xena-input disabled value="Disabled" />
```

### Prefix and Suffix

Use the `prefix` and `suffix` slots to add icons and text.

```html preview
<xena-input class="mb-5">
  <span slot="prefix">EUR</span>
</xena-input>

<xena-input class="mb-5">
  <xena-icon slot="suffix" name="fas-search"></xena-icon>
</xena-input>

<xena-input>
  <span slot="prefix">EUR</span>
  <xena-icon slot="suffix" name="fas-search"></xena-icon>
</xena-input>
```

### Labels

Use the `label` attribute to give the input an accessible label. For labels that contain HTML, use the `label` slot instead.

```html preview
<xena-input label="Select one"></xena-input>
```

### Labels and required

When using the `required` prop with the `label` attribute an asterisk will show that the input is required

```html preview
<xena-input label="See here" required value="Required" />
```

### Help Text

Add descriptive help text to an input with the `help-text` attribute. For help texts that contain HTML, use the `help-text` slot instead.

```html preview
<xena-input label="Experience" help-text="Please tell us your skill level."></xena-input>
```

### Error Text

Add descriptive error text to an input with the `error-text`-attribute. For error texts that contain HTML, use the `error-text`-slot instead. When an error text is supplied the help text will be hidden.

```html preview
<div id="error-example">
  <xena-input
    label="Enter text"
    help-text="When error is switch off, this help text is shown."
    error-text="The entered value is invalid"
  ></xena-input>
  <xena-switch class="mt-4" checked>Error enabled</xena-switch>
</div>

<script>
  let example = document.getElementById('error-example');
  let input = example.querySelector('xena-input');
  let switchEl = example.querySelector('xena-switch');

  switchEl.addEventListener('checkedChange', evt => {
    console.log(evt);
    const checked = evt.detail;
    input.errorText = checked ? 'The entered value is still invalid' : null;
  });
</script>
```

If you are using `error-text`-slot then it will look like this

```html preview
<xena-input label="Enter text">
  <span slot="error-text">The entered value is invalid</span>
</xena-input>
```

[component-metadata:xena-input]
