# Modal

[component-header:xena-modal]

Modals appear above the page and require the user's immediate attention.

```html preview
<xena-modal label="Modal" class="modal-overview">
  Lorem ipsum dolor sit amet, consectetur adipiscing elit.
  <xena-select id="select-1" label="Select with hoist" hoist>
    <xena-menu-item value="option-1">Option 1</xena-menu-item>
    <xena-menu-item value="option-2">Option 2</xena-menu-item>
    <xena-menu-item value="option-3">Option 3</xena-menu-item>
    <xena-menu-divider></xena-menu-divider>
    <xena-menu-item value="option-4">Option 4</xena-menu-item>
    <xena-menu-item value="option-5">Option 5</xena-menu-item>
    <xena-menu-item value="option-6">Option 6</xena-menu-item>
  </xena-select>
  <xena-autocomplete placeholder="Type search" label="Autocomplete" id="ac-1"></xena-autocomplete>
  <script>
    const data = [
      { label: 'None' },
      { id: '1', label: 'Anders' },
      { id: '2', label: 'Mickey' },
      { id: '3', label: 'Fedtmule' },
      { id: '4', label: 'Sorteper' }
    ];
    const ac = document.querySelector('#ac-1');
    ac.setDatasource(search => {
      return Promise.resolve(data);
    });
  </script>
  <xena-button slot="footer" type="primary">OK</xena-button>
  <xena-button slot="footer">Close</xena-button>
</xena-modal>

<xena-button>Open Modal</xena-button>

<script>
  (() => {
    const modal = document.querySelector('.modal-overview');
    const openButton = modal.nextElementSibling;
    const closeButton = modal.querySelector('xena-button[slot="footer"]');

    openButton.addEventListener('click', () => modal.show());
    closeButton.addEventListener('click', () => modal.hide());
  })();
</script>
```

## UX Tips

- Use a modal when you immediately require the user's attention, e.g. confirming a destructive action
- Always provide an obvious way for the user to dismiss the modal
- First button in the footer, should be the primary action
- Do not nest modals. It almost always leads to a poor experience for the user

[Read more UX guidelines](/ux-guide/communication.md)

## Examples

### Custom Width

Use the `--width` custom property to set the modal's width.

```html preview
<xena-modal label="Modal" class="modal-width" style="--width: 50vw;">
  Lorem ipsum dolor sit amet, consectetur adipiscing elit.
  <xena-button slot="footer" type="primary">Close</xena-button>
</xena-modal>

<xena-button>Open Modal</xena-button>

<script>
  (() => {
    const modal = document.querySelector('.modal-width');
    const openButton = modal.nextElementSibling;
    const closeButton = modal.querySelector('xena-button[slot="footer"]');

    openButton.addEventListener('click', () => modal.show());
    closeButton.addEventListener('click', () => modal.hide());
  })();
</script>
```

### Scrolling

By design, a modal's height will never exceed that of the viewport. As such, modals will not scroll with the page ensuring the header and footer are always accessible to the user.

```html preview
<xena-modal label="Modal" class="modal-scrolling">
  <div style="height: 150vh; border: dashed 2px var(--xena-color-gray-200); padding: 0 1rem;">
    <p>Scroll down and give it a try! 👇</p>
  </div>
  <xena-button slot="footer" type="primary">Close</xena-button>
</xena-modal>

<xena-button>Open Modal</xena-button>

<script>
  (() => {
    const modal = document.querySelector('.modal-scrolling');
    const openButton = modal.nextElementSibling;
    const closeButton = modal.querySelector('xena-button[slot="footer"]');

    openButton.addEventListener('click', () => modal.show());
    closeButton.addEventListener('click', () => modal.hide());
  })();
</script>
```

### Closing by clicks on Overlay

By default, modals are not closed when the user clicks or taps on the overlay. To change this behavior add a `closableOverlay` attribute.

```html preview
<xena-modal label="Modal" closable-overlay class="modal-no-overlay-dismiss">
  This modal will be closed when you click outside of it.
  <xena-button slot="footer" type="primary">Close</xena-button>
</xena-modal>

<xena-button>Open Modal</xena-button>

<script>
  (() => {
    const modal = document.querySelector('.modal-no-overlay-dismiss');
    const openButton = modal.nextElementSibling;
    const closeButton = modal.querySelector('xena-button[slot="footer"]');

    openButton.addEventListener('click', () => modal.show());
    closeButton.addEventListener('click', () => modal.hide());
  })();
</script>
```

[component-metadata:xena-modal]
