# Progress Bar

[component-header:xena-progress-bar]

Progress bars are used to show the status of an ongoing operation.

```html preview
<xena-progress-bar percentage="50"></xena-progress-bar>
```

## Examples

### Custom Height

Use the `--height` custom property to set the progress bar's height.

```html preview
<xena-progress-bar percentage="50" style="--height: 6px;"></xena-progress-bar>
```

### Labels

Use the default slot to show a label.

```html preview
<xena-progress-bar percentage="50" class="progress-bar-labels">50%</xena-progress-bar>

<br />

<xena-icon-button name="fas-minus"></xena-icon-button>
<xena-icon-button name="fas-plus"></xena-icon-button>

<script>
  const progressBar = document.querySelector('.progress-bar-labels');
  const subtractButton = progressBar.nextElementSibling.nextElementSibling;
  const addButton = subtractButton.nextElementSibling;

  addButton.addEventListener('click', () => {
    const percentage = Math.min(100, progressBar.percentage + 10);
    progressBar.percentage = percentage;
    progressBar.textContent = `${percentage}%`;
  });

  subtractButton.addEventListener('click', () => {
    const percentage = Math.max(0, progressBar.percentage - 10);
    progressBar.percentage = percentage;
    progressBar.textContent = `${percentage}%`;
  });
</script>
```

### Indeterminate

The `indeterminate` attribute can be used to inform the user that the operation is pending, but its status cannot currently be determined. In this state, `percentage` is ignored and the label, if present, will not be shown.

```html preview
<xena-progress-bar indeterminate></xena-progress-bar>
```

[component-metadata:xena-progress-bar]
