# Select

[component-header:xena-select]

Selects allow you to choose one or more items from a dropdown menu. Notice that the options container min-width is the width of the parent element.

```html preview
<xena-select id="select-1">
  <xena-menu-item value="option-1">Option 1 also has extra text in order to make it appear extra long</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
  <xena-menu-divider></xena-menu-divider>
  <xena-menu-item value="option-4">Option 4</xena-menu-item>
  <xena-menu-item value="option-5">Option 5</xena-menu-item>
  <xena-menu-item value="option-6">Option 6</xena-menu-item>
</xena-select>

<script>
  const select = document.querySelector('#select-1');
  select.addEventListener('valueChange', ev => {
    console.log('Change: ', ev.detail);
  });
</script>
```

## Examples

### Placeholders

Use the `placeholder` attribute to add a placeholder.

```html preview
<xena-select placeholder="Select one">
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
</xena-select>
```

### Clearable

Use the `clearable` attribute to make the control clearable.

```html preview
<xena-select placeholder="Clearable" clearable>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
</xena-select>
```

### Pill

Use the `pill` prop to give selects rounded edges.

```html preview
<xena-select pill>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
</xena-select>
```

### Disabled

Use the `disabled` prop to disable a select.

```html preview
<xena-select placeholder="Disabled" disabled>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
</xena-select>
```

### Multiple

To allow multiple options to be selected, use the `multiple` attribute. It's a good practice to use `clearable` when this option is enabled. When using this option, `value` will be an array instead of a string.

```html preview
<xena-select placeholder="Select a few" multiple clearable>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
  <xena-menu-divider></xena-menu-divider>
  <xena-menu-item value="option-4">Option 4</xena-menu-item>
  <xena-menu-item value="option-5">Option 5</xena-menu-item>
  <xena-menu-item value="option-6">Option 6</xena-menu-item>
</xena-select>
```

To remove the clear function for each tag add `remove-tag-clearable` which removes the clearable property on the `<xena-tag>`.

```html preview
<xena-select placeholder="Select a few" multiple clearable remove-tag-clearable>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
  <xena-menu-divider></xena-menu-divider>
  <xena-menu-item value="option-4">Option 4</xena-menu-item>
  <xena-menu-item value="option-5">Option 5</xena-menu-item>
  <xena-menu-item value="option-6">Option 6</xena-menu-item>
</xena-select>
```

### Grouping Options

Options can be grouped visually using menu labels and menu dividers.

```html preview
<xena-select placeholder="Select one">
  <xena-menu-label>Group 1</xena-menu-label>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
  <xena-menu-divider></xena-menu-divider>
  <xena-menu-label>Group 2</xena-menu-label>
  <xena-menu-item value="option-4">Option 4</xena-menu-item>
  <xena-menu-item value="option-5">Option 5</xena-menu-item>
  <xena-menu-item value="option-6">Option 6</xena-menu-item>
</xena-select>
```

### Sizes

Use the `size` attribute to change a select's size.

```html preview
<xena-select placeholder="Small" size="small" multiple>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
</xena-select>

<br />

<xena-select placeholder="Medium" size="medium" multiple>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
</xena-select>

<br />

<xena-select placeholder="Large" size="large" multiple>
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
</xena-select>
```

### Selecting Options Programmatically

The `value` prop is bound to the current selection. As the selection changes, so will the value. To programmatically manage the selection, update the `value` property.

```html preview
<div class="selecting-example">
  <xena-select placeholder="">
    <xena-menu-item value="option-1">Option 1</xena-menu-item>
    <xena-menu-item value="option-2">Option 2</xena-menu-item>
    <xena-menu-item value="option-3">Option 3</xena-menu-item>
  </xena-select>

  <br />

  <xena-button data-option="option-1">Set 1</xena-button>
  <xena-button data-option="option-2">Set 2</xena-button>
  <xena-button data-option="option-3">Set 3</xena-button>
</div>

<script>
  const container = document.querySelector('.selecting-example');
  const select = container.querySelector('xena-select');

  [...container.querySelectorAll('xena-button')].map(button => {
    button.addEventListener('click', () => {
      select.value = button.dataset.option;
    });
  });
</script>
```

### Labels

Use the `label` attribute to give the select an accessible label. For labels that contain HTML, use the `label` slot instead.

```html preview
<xena-select label="Select one">
  <xena-menu-item value="option-1">Option 1</xena-menu-item>
  <xena-menu-item value="option-2">Option 2</xena-menu-item>
  <xena-menu-item value="option-3">Option 3</xena-menu-item>
</xena-select>
```

### Help Text

Add descriptive help text to a select with the `help-text` attribute. For help texts that contain HTML, use the `help-text` slot instead.

```html preview
<xena-select label="Experience" help-text="Please tell us your skill level.">
  <xena-menu-item value="option-1">Novice</xena-menu-item>
  <xena-menu-item value="option-2">Intermediate</xena-menu-item>
  <xena-menu-item value="option-3">Advanced</xena-menu-item>
</xena-select>
```

### Error Text

Add descriptive error text to a select with the `error-text` attribute. For error texts that contain HTML, use the `error-text` slot instead. When an error text is supplied the help text will be hidden.

```html preview
<div id="error-example">
  <xena-select
    label="Select one"
    help-text="When error is switch off, this help text is shown."
    error-text="The selected value is invalid!"
  >
    <xena-menu-item value="option-1">Novice</xena-menu-item>
    <xena-menu-item value="option-2">Intermediate</xena-menu-item>
    <xena-menu-item value="option-3">Advanced</xena-menu-item>
  </xena-select>

  <xena-switch class="mt-4" checked>Error enabled</xena-switch>
</div>

<script>
  let example = document.getElementById('error-example');
  let input = example.querySelector('xena-select');
  let switchEl = example.querySelector('xena-switch');

  switchEl.addEventListener('checkedChange', evt => {
    console.log(evt);
    const checked = evt.detail;
    input.errorText = checked ? 'The selected value is still invalid' : null;
  });
</script>
```

[component-metadata:xena-select]
