# Slider

[component-header:xena-slider]

Sliders are used to interactively select a value.

```html preview
<xena-slider id="mySlider" min="0" max="100" value="0"></xena-slider>

<p>The value is: <span id="myValue"></span></p>

<script>
  const slider = document.getElementById('mySlider');
  const output = document.getElementById('myValue');

  function updateValue(event) {
    const value = Math.floor(event.detail.x);
    output.textContent = value;
  }

  slider.addEventListener('valueChange', updateValue);
  output.textContent = slider.value;
</script>
```

## Types

There are three types of the component:

- `type="horizontal"`
- `type="vertical"`
- `type="both"`

### Horizontal

```html preview
<xena-slider type="horizontal" min="0" max="100"></xena-slider>
```

### Vertical

```html preview
<xena-slider type="vertical" min="0" max="200" value="50"></xena-slider>
```

### Both (two-dimensional)

```html preview
<xena-slider id="bothSlider" value="50,65" type="both" min="0" max="100"></xena-slider>

<p>The value is: <span id="bothValue"></span></p>

<script>
  const slider = document.getElementById('bothSlider');
  const output = document.getElementById('bothValue');

  function updateValue(event) {
    const valueX = Math.floor(event.detail.x);
    const valueY = Math.floor(event.detail.y);
    const value = valueX + ',' + valueY;
    output.textContent = value;
  }

  slider.addEventListener('valueChange', updateValue);
  output.textContent = slider.value;
</script>
```

## Settings

The slider has a minimum value and a maximum value.

## Sizing

Set the sliders width for `type="horizontal"` and height for `type="vertical"` and both for `type="both"` in either `%` or `px` with the width and height attribute.

```html preview
<xena-slider type="horizontal" width="50%" min="0" max="100"></xena-slider>
```

## Examples

Using the sliders can benefit from labels to enhance the user experience. Some examples of how that can be achieved are illustrated below.

### Labels

```html preview
<div style="display:flex; gap:1rem; align-items: center;">
  <span style="font-weight: var(--xena-font-weight-semibold)">0</span>
  <xena-slider style="flex-grow: 1;" type="horizontal" min="0" max="100"></xena-slider>
  <span style="font-weight: var(--xena-font-weight-semibold)">100</span>
</div>
```

### Icons

```html preview
<div style="display:flex; gap:1rem; align-items: center;">
  <xena-icon name="fas-volume-down"></xena-icon>
  <xena-slider style="flex-grow: 1;" type="horizontal" min="0" max="100"></xena-slider>
  <xena-icon name="fas-volume-up"></xena-icon>
</div>
```

[component-metadata:xena-slider]
