# Tab Group

[component-header:xena-tab-group]

Tab groups organize content into a container that shows one section at a time.

Tab groups make use of [tabs](/components/tab.md) and [tab panels](/components/tab-panel.md). Each tab must be slotted into the `nav` slot and its `panel` must refer to a tab panel of the same name.

```html preview
<xena-tab-group>
  <xena-tab slot="nav" panel="general">General</xena-tab>
  <xena-tab slot="nav" panel="custom">Custom</xena-tab>
  <xena-tab slot="nav" panel="advanced">Advanced</xena-tab>
  <xena-tab slot="nav" panel="disabled" disabled>Disabled</xena-tab>

  <xena-tab-panel name="general">This is the general tab panel.</xena-tab-panel>
  <xena-tab-panel name="custom">This is the custom tab panel.</xena-tab-panel>
  <xena-tab-panel name="advanced">This is the advanced tab panel.</xena-tab-panel>
  <xena-tab-panel name="disabled">This is a disabled tab panel.</xena-tab-panel>
</xena-tab-group>
```

?> Please be aware that when using `Tab Group` in conjunction with **KnockoutJS** DOM manipulative bindings (foreach etc.) event listeners for focus visible functionality can't be unsubscribed. This has no effect if your application refreshes the page once in a while but can lead to performance issues within a Single Page Application (SPA).

## Examples

### Tabs on Bottom

Tabs can be shown on the bottom by setting `placement` to `bottom`.

```html preview
<xena-tab-group placement="bottom">
  <xena-tab slot="nav" panel="general">General</xena-tab>
  <xena-tab slot="nav" panel="custom">Custom</xena-tab>
  <xena-tab slot="nav" panel="advanced">Advanced</xena-tab>
  <xena-tab slot="nav" panel="disabled" disabled>Disabled</xena-tab>

  <xena-tab-panel name="general">This is the general tab panel.</xena-tab-panel>
  <xena-tab-panel name="custom">This is the custom tab panel.</xena-tab-panel>
  <xena-tab-panel name="advanced">This is the advanced tab panel.</xena-tab-panel>
  <xena-tab-panel name="disabled">This is a disabled tab panel.</xena-tab-panel>
</xena-tab-group>
```

### Tabs on Left

Tabs can be shown on the left by setting `placement` to `left`.

```html preview
<xena-tab-group placement="left">
  <xena-tab slot="nav" panel="general">General</xena-tab>
  <xena-tab slot="nav" panel="custom">Custom</xena-tab>
  <xena-tab slot="nav" panel="advanced">Advanced</xena-tab>
  <xena-tab slot="nav" panel="disabled" disabled>Disabled</xena-tab>

  <xena-tab-panel name="general">This is the general tab panel.</xena-tab-panel>
  <xena-tab-panel name="custom">This is the custom tab panel.</xena-tab-panel>
  <xena-tab-panel name="advanced">This is the advanced tab panel.</xena-tab-panel>
  <xena-tab-panel name="disabled">This is a disabled tab panel.</xena-tab-panel>
</xena-tab-group>
```

### Tabs on Right

Tabs can be shown on the right by setting `placement` to `right`.

```html preview
<xena-tab-group placement="right">
  <xena-tab slot="nav" panel="general">General</xena-tab>
  <xena-tab slot="nav" panel="custom">Custom</xena-tab>
  <xena-tab slot="nav" panel="advanced">Advanced</xena-tab>
  <xena-tab slot="nav" panel="disabled" disabled>Disabled</xena-tab>

  <xena-tab-panel name="general">This is the general tab panel.</xena-tab-panel>
  <xena-tab-panel name="custom">This is the custom tab panel.</xena-tab-panel>
  <xena-tab-panel name="advanced">This is the advanced tab panel.</xena-tab-panel>
  <xena-tab-panel name="disabled">This is a disabled tab panel.</xena-tab-panel>
</xena-tab-group>
```

### Closable Tabs

Add the `closable` prop to a tab to show a close button. This example shows how you can dynamically remove tabs from the DOM when the close button is activated.

```html preview
<xena-tab-group class="tabs-closable">
  <xena-tab slot="nav" panel="general">General</xena-tab>
  <xena-tab slot="nav" panel="closable-1" closable>Closable 1</xena-tab>
  <xena-tab slot="nav" panel="closable-2" closable>Closable 2</xena-tab>
  <xena-tab slot="nav" panel="closable-3" closable>Closable 3</xena-tab>

  <xena-tab-panel name="general">This is the general tab panel.</xena-tab-panel>
  <xena-tab-panel name="closable-1">This is the first closable tab panel.</xena-tab-panel>
  <xena-tab-panel name="closable-2">This is the second closable tab panel.</xena-tab-panel>
  <xena-tab-panel name="closable-3">This is the third closable tab panel.</xena-tab-panel>
</xena-tab-group>

<script>
  const tabGroup = document.querySelector('.tabs-closable');

  tabGroup.addEventListener('slClose', async event => {
    const tab = event.target;
    const panel = tabGroup.querySelector(`xena-tab-panel[name="${tab.panel}"]`);

    // Show the previous tab if the tab is currently active
    if (tab.active) {
      tabGroup.show(tab.previousElementSibling.panel);
    }

    // Remove the tab + panel
    tab.remove();
    panel.remove();
  });
</script>
```

### Scrolling Tabs

When there are more tabs than horizontal space allows, the nav will be scrollable.

```html preview
<xena-tab-group>
  <xena-tab slot="nav" panel="tab-1">Tab 1</xena-tab>
  <xena-tab slot="nav" panel="tab-2">Tab 2</xena-tab>
  <xena-tab slot="nav" panel="tab-3">Tab 3</xena-tab>
  <xena-tab slot="nav" panel="tab-4">Tab 4</xena-tab>
  <xena-tab slot="nav" panel="tab-5">Tab 5</xena-tab>
  <xena-tab slot="nav" panel="tab-6">Tab 6</xena-tab>
  <xena-tab slot="nav" panel="tab-7">Tab 7</xena-tab>
  <xena-tab slot="nav" panel="tab-8">Tab 8</xena-tab>
  <xena-tab slot="nav" panel="tab-9">Tab 9</xena-tab>
  <xena-tab slot="nav" panel="tab-10">Tab 10</xena-tab>
  <xena-tab slot="nav" panel="tab-11">Tab 11</xena-tab>
  <xena-tab slot="nav" panel="tab-12">Tab 12</xena-tab>
  <xena-tab slot="nav" panel="tab-13">Tab 13</xena-tab>
  <xena-tab slot="nav" panel="tab-14">Tab 14</xena-tab>
  <xena-tab slot="nav" panel="tab-15">Tab 15</xena-tab>
  <xena-tab slot="nav" panel="tab-16">Tab 16</xena-tab>
  <xena-tab slot="nav" panel="tab-17">Tab 17</xena-tab>
  <xena-tab slot="nav" panel="tab-18">Tab 18</xena-tab>
  <xena-tab slot="nav" panel="tab-19">Tab 19</xena-tab>
  <xena-tab slot="nav" panel="tab-20">Tab 20</xena-tab>

  <xena-tab-panel name="tab-1">Tab panel 1</xena-tab-panel>
  <xena-tab-panel name="tab-2">Tab panel 2</xena-tab-panel>
  <xena-tab-panel name="tab-3">Tab panel 3</xena-tab-panel>
  <xena-tab-panel name="tab-4">Tab panel 4</xena-tab-panel>
  <xena-tab-panel name="tab-5">Tab panel 5</xena-tab-panel>
  <xena-tab-panel name="tab-6">Tab panel 6</xena-tab-panel>
  <xena-tab-panel name="tab-7">Tab panel 7</xena-tab-panel>
  <xena-tab-panel name="tab-8">Tab panel 8</xena-tab-panel>
  <xena-tab-panel name="tab-9">Tab panel 9</xena-tab-panel>
  <xena-tab-panel name="tab-10">Tab panel 10</xena-tab-panel>
  <xena-tab-panel name="tab-11">Tab panel 11</xena-tab-panel>
  <xena-tab-panel name="tab-12">Tab panel 12</xena-tab-panel>
  <xena-tab-panel name="tab-13">Tab panel 13</xena-tab-panel>
  <xena-tab-panel name="tab-14">Tab panel 14</xena-tab-panel>
  <xena-tab-panel name="tab-15">Tab panel 15</xena-tab-panel>
  <xena-tab-panel name="tab-16">Tab panel 16</xena-tab-panel>
  <xena-tab-panel name="tab-17">Tab panel 17</xena-tab-panel>
  <xena-tab-panel name="tab-18">Tab panel 18</xena-tab-panel>
  <xena-tab-panel name="tab-19">Tab panel 19</xena-tab-panel>
  <xena-tab-panel name="tab-20">Tab panel 20</xena-tab-panel>
</xena-tab-group>
```

[component-metadata:xena-tab-group]
