# Table

[component-header:xena-table]

To make a table using Xena Design System you have this `table` component, [`xena-column`](/components/table-column.md), `xena-row` and [`xena-cell`](/components/table-cell.md).
These different components closely mimics the native `table` HTML element. You can read further about these components in their respective documentation pages.

?> Review our [tables UX guideline](/ux-guide/tables.md) to learn more about best practices

```html preview
<xena-table>
  <xena-column>Column 1</xena-column>
  <xena-column>Column 2</xena-column>
  <xena-column>Column 3</xena-column>
  <xena-row>
    <xena-cell>(0) Data 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Data 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Data 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
</xena-table>
```

?> All `xena-column` elements in the root of `xena-table` will automatically be assigned to the `columns` slot.

## Example

This approch enables you to very precisely build the table you want, with the elements you want inside each cell.

```html preview
<xena-table>
  <xena-column>User</xena-column>
  <xena-column alignment="right">Earnings (<abbr title="Year to date">YTD</abbr>)</xena-column>
  <xena-column alignment="right">Actions</xena-column>
  <xena-row>
    <xena-cell>
      <xena-popover>
        <span slot="trigger">Anders</span>
        <span slot="header">Quick info</span>
        <dl>
          <dt>Job title</dt>
          <dd>Developer</dd>
        </dl>
      </xena-popover>
      <xena-label type="success">Online</xena-label>
    </xena-cell>
    <xena-cell alignment="right">38.383,00 DKK</xena-cell>
    <xena-cell alignment="right">
      <xena-dropdown>
        <xena-icon-button name="fas-ellipsis-h" slot="trigger"></xena-icon-button>
        <xena-menu>
          <xena-menu-item><xena-icon slot="prefix" name="fas-comment"></xena-icon>Chat</xena-menu-item>
          <xena-menu-item><xena-icon slot="prefix" name="fas-trash"></xena-icon>Delete</xena-menu-item>
        </xena-menu>
      </xena-dropdown>
    </xena-cell>
  </xena-row>
</xena-table>
```

### Group headers

You can use `xena-column` inside `xena-row` to make sub group headings

```html preview
<xena-table>
  <xena-column>Employee</xena-column>
  <xena-column>Role</xena-column>
  <xena-row>
    <xena-column colspan="2">A</xena-column>
  </xena-row>
  <xena-row>
    <xena-cell>Anders</xena-cell>
    <xena-cell>Developer</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>Andy</xena-cell>
    <xena-cell>Bookkeeper</xena-cell>
  </xena-row>
  <xena-row>
    <xena-column colspan="2">B</xena-column>
  </xena-row>
  <xena-row>
    <xena-cell>Benny</xena-cell>
    <xena-cell>Admin</xena-cell>
  </xena-row>
</xena-table>
```

## Modifiers

### Hoverable

Highlight the hovered row with the attribute `hoverable`.

```html preview
<xena-table hoverable>
  <xena-column>Column 1</xena-column>
  <xena-column>Column 2</xena-column>
  <xena-column>Column 3</xena-column>
  <xena-row>
    <xena-cell>(0) Data 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Data 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Data 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
</xena-table>
```

### Sticky column header

When scrolling the table headers will stick to the top of the screen. You can
activate this by adding the `sticky-header` attribute to the table.

```html preview
<xena-table sticky-header>
  <xena-column>Column 1</xena-column>
  <xena-column>Column 2</xena-column>
  <xena-column>Column 3</xena-column>
  <xena-row>
    <xena-cell>(0) Data 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Data 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Data 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(3) Data 1</xena-cell>
    <xena-cell>(3) Data 2</xena-cell>
    <xena-cell>(3) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(4) Data 1</xena-cell>
    <xena-cell>(4) Data 2</xena-cell>
    <xena-cell>(4) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(5) Data 1</xena-cell>
    <xena-cell>(5) Data 2</xena-cell>
    <xena-cell>(5) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(6) Data 1</xena-cell>
    <xena-cell>(6) Data 2</xena-cell>
    <xena-cell>(6) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(7) Data 1</xena-cell>
    <xena-cell>(7) Data 2</xena-cell>
    <xena-cell>(7) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(8) Data 1</xena-cell>
    <xena-cell>(8) Data 2</xena-cell>
    <xena-cell>(8) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(9) Data 1</xena-cell>
    <xena-cell>(9) Data 2</xena-cell>
    <xena-cell>(9) Data 3</xena-cell>
  </xena-row>
</xena-table>
```

### Change table header

The default header type is set with `type="default"`. It is also set by default.

```html preview
<xena-table type="default">
  <xena-column>Column 1</xena-column>
  <xena-column>Column 2</xena-column>
  <xena-column>Column 3</xena-column>
  <xena-row>
    <xena-cell>(0) Data 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Data 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Data 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
  <xena-table></xena-table
></xena-table>
```

Change the table header to a lightweight style using `type="light"` which sets a white background color.

```html preview
<xena-table type="light">
  <xena-column>Column 1</xena-column>
  <xena-column>Column 2</xena-column>
  <xena-column>Column 3</xena-column>
  <xena-row>
    <xena-cell>(0) Data 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Data 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Data 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
  <xena-table></xena-table
></xena-table>
```

Hide the table header using `type="hidden"`. `type="hidden"` requires empty `<xena-column>`.

```html preview
<xena-table type="hidden">
  <xena-column></xena-column>
  <xena-column></xena-column>
  <xena-column></xena-column>
  <xena-row>
    <xena-cell>(0) Data 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Data 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Data 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
  <xena-table></xena-table
></xena-table>
```

### Vertical header on left column

Use the first column as a vertical header with the attribute `vertical-header`.

```html preview
<xena-table vertical-header>
  <xena-column>Column 1</xena-column>
  <xena-column>Column 2</xena-column>
  <xena-column>Column 3</xena-column>
  <xena-row>
    <xena-cell>(0) Header 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Header 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Header 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
</xena-table>
```

### Size

Set the `size` attribute to adjust the cell padding.

```html preview
<xena-table size="small">
  <xena-column>Column 1</xena-column>
  <xena-column>Column 2</xena-column>
  <xena-column>Column 3</xena-column>
  <xena-row>
    <xena-cell>(0) Data 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Data 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Data 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
</xena-table>
```

```html preview
<xena-table size="large">
  <xena-column>Column 1</xena-column>
  <xena-column>Column 2</xena-column>
  <xena-column>Column 3</xena-column>
  <xena-row>
    <xena-cell>(0) Data 1</xena-cell>
    <xena-cell>(0) Data 2</xena-cell>
    <xena-cell>(0) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(1) Data 1</xena-cell>
    <xena-cell>(1) Data 2</xena-cell>
    <xena-cell>(1) Data 3</xena-cell>
  </xena-row>
  <xena-row>
    <xena-cell>(2) Data 1</xena-cell>
    <xena-cell>(2) Data 2</xena-cell>
    <xena-cell>(2) Data 3</xena-cell>
  </xena-row>
</xena-table>
```

[component-metadata:xena-table]
