# Tooltip

[component-header:xena-tooltip]

Tooltips display additional information based on a specific action.

A tooltip's target is its _first child element_, so you should only wrap one element inside of the tooltip. If you need the tooltip to show up for multiple elements, nest them inside a container first.

Tooltips use `display: contents` so they won't interfere with how elements are positioned in a flex or grid layout.

```html preview
<xena-tooltip content="This is a tooltip">
  <xena-button>Hover Me</xena-button>
</xena-tooltip>
```

## Examples

### Placement

Use the `placement` attribute to set the preferred placement of the tooltip.

```html preview
<div class="tooltip-placement-example">
  <div class="tooltip-placement-example-row">
    <xena-tooltip content="top-start" placement="top-start">
      <xena-button></xena-button>
    </xena-tooltip>

    <xena-tooltip content="top" placement="top">
      <xena-button></xena-button>
    </xena-tooltip>

    <xena-tooltip content="top-end" placement="top-end">
      <xena-button></xena-button>
    </xena-tooltip>
  </div>

  <div class="tooltip-placement-example-row">
    <xena-tooltip content="left-start" placement="left-start">
      <xena-button></xena-button>
    </xena-tooltip>

    <xena-tooltip content="right-start" placement="right-start" style="margin-left: 400px;">
      <xena-button></xena-button>
    </xena-tooltip>
  </div>

  <div class="tooltip-placement-example-row">
    <xena-tooltip content="left" placement="left">
      <xena-button></xena-button>
    </xena-tooltip>

    <xena-tooltip content="right" placement="right">
      <xena-button></xena-button>
    </xena-tooltip>
  </div>

  <div class="tooltip-placement-example-row">
    <xena-tooltip content="left-end" placement="left-end">
      <xena-button></xena-button>
    </xena-tooltip>

    <xena-tooltip content="right-end" placement="right-end">
      <xena-button></xena-button>
    </xena-tooltip>
  </div>

  <div class="tooltip-placement-example-row">
    <xena-tooltip content="bottom-start" placement="bottom-start">
      <xena-button></xena-button>
    </xena-tooltip>

    <xena-tooltip content="bottom" placement="bottom">
      <xena-button></xena-button>
    </xena-tooltip>

    <xena-tooltip content="bottom-end" placement="bottom-end">
      <xena-button></xena-button>
    </xena-tooltip>
  </div>
</div>

<style>
  .tooltip-placement-example {
    width: 250px;
  }

  .tooltip-placement-example-row::after {
    content: '';
    display: table;
    clear: both;
  }

  .tooltip-placement-example xena-button {
    float: left;
    width: 2.5rem;
    margin-right: 0.25rem;
    margin-bottom: 0.25rem;
  }

  .tooltip-placement-example [placement='top-start'] xena-button,
  .tooltip-placement-example [placement='bottom-start'] xena-button {
    margin-left: calc(40px + 0.25rem);
  }

  .tooltip-placement-example [placement^='right'] xena-button {
    margin-left: calc((40px * 3) + (0.25rem * 3));
  }
</style>
```

### Click Trigger

Set the `trigger` attribute to `click` to toggle the tooltip on click instead of hover.

```html preview
<xena-tooltip content="Click again to dismiss" trigger="click">
  <xena-button>Click to Toggle</xena-button>
</xena-tooltip>
```

### Manual Trigger

Tooltips can be controller programmatically by setting the `trigger` attribute to `manual`. Use the `open` prop to control when the tooltip is shown.

```html preview
<xena-button style="margin-right: 4rem;">Toggle Manually</xena-button>

<xena-tooltip content="This is a bell" trigger="manual" class="manual-tooltip">
  <xena-icon name="bell"></xena-icon>
</xena-tooltip>

<script>
  const tooltip = document.querySelector('.manual-tooltip');
  const toggle = tooltip.previousElementSibling;

  toggle.addEventListener('click', () => (tooltip.open = !tooltip.open));
</script>
```

### Disabled

```html preview
<xena-button style="margin-right: 4rem;">Toggle disabled</xena-button>

<xena-tooltip content="Tooltip is not disabled" class="disabled-tooltip">
  <xena-icon name="bell"></xena-icon>
</xena-tooltip>

<script>
  const tooltip = document.querySelector('.disabled-tooltip');
  const toggle = tooltip.previousElementSibling;

  toggle.addEventListener('click', () => {
    tooltip.disabled = !tooltip.disabled;
  });
</script>
```

### No content

```html preview
<xena-tooltip content="There is content" class="disabled-tooltip">
  <xena-button style="margin-right: 4rem;">Content</xena-button>
</xena-tooltip>

<xena-tooltip content="" class="disabled-tooltip">
  <xena-button style="margin-right: 4rem;">No content</xena-button>
</xena-tooltip>
```

### Remove Arrows

You can control the size of tooltip arrows by overriding the `--xena-tooltip-arrow-size` design token.

```html preview
<div style="--xena-tooltip-arrow-size: 0;">
  <xena-tooltip content="This is a tooltip">
    <xena-button>Above</xena-button>
  </xena-tooltip>

  <xena-tooltip content="This is a tooltip" placement="bottom">
    <xena-button>Below</xena-button>
  </xena-tooltip>
</div>
```

To override it globally, set it in a root block in your stylesheet after `xena.css` is loaded.

```css
:root {
  --xena-tooltip-arrow-size: 0;
}
```

[component-metadata:xena-tooltip]
