'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d0e7980b.js');
const slot = require('./slot-0257c52f.js');

const menuCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:block;overflow-y:auto}.menu{padding:var(--xena-spacing-x-small) 0}.menu:focus{outline:none}";

let Menu = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.xnFocus = index.createEvent(this, "xnFocus", 7);
    this.xnBlur = index.createEvent(this, "xnBlur", 7);
    this.xnSelect = index.createEvent(this, "xnSelect", 7);
    this.typeToSelectString = '';
    this.hostIsScrollable = false;
    this.hasFocus = false;
  }
  connectedCallback() {
    this.handleBlur = this.handleBlur.bind(this);
    this.handleClick = this.handleClick.bind(this);
    this.handleFocus = this.handleFocus.bind(this);
    this.handleKeyDown = this.handleKeyDown.bind(this);
    this.handleMouseOver = this.handleMouseOver.bind(this);
    this.handleMouseOut = this.handleMouseOut.bind(this);
  }
  componentDidRender() {
    this.hostIsScrollable = this.host.scrollHeight > this.host.clientHeight;
  }
  /** Sets focus on the menu. */
  async setFocus() {
    this.hasFocus = true;
    this.menu.focus();
  }
  /** Removes focus from the menu. */
  async removeFocus() {
    this.hasFocus = false;
    this.menu.blur();
  }
  /**
   * Select the active menu element.
   */
  async selectActiveMenuElement() {
    const item = this.getActiveItem();
    if (item) {
      this.xnSelect.emit({ item });
    }
  }
  /**
   * Initiates type-to-select logic, which automatically selects an option based on what the user is currently typing.
   * The key passed will be appended to the internal query and the selection will be updated. After a brief period, the
   * internal query is cleared automatically. This method is intended to be used with the keydown event. Useful for
   * enabling type-to-select when the menu doesn't have focus.
   */
  async typeToSelect(key) {
    clearTimeout(this.typeToSelectTimeout);
    this.typeToSelectTimeout = setTimeout(() => (this.typeToSelectString = ''), 750);
    this.typeToSelectString += key.toLowerCase();
    const items = this.getItems();
    for (const item of items) {
      const slot$1 = item.shadowRoot.querySelector('slot:not([name])');
      const label = slot.getTextContent(slot$1).toLowerCase().trim();
      if (label.substring(0, this.typeToSelectString.length) === this.typeToSelectString) {
        items.map(i => (i.active = i === item));
        break;
      }
    }
  }
  getItems() {
    const slot = this.menu.querySelector('slot');
    return [...slot.assignedElements({ flatten: true })].filter((el) => el.tagName.toLowerCase() === 'xena-menu-item' && !el.disabled);
  }
  getActiveItem() {
    return this.getItems().find(i => i.active);
  }
  setActiveItem(item) {
    this.getItems().map(i => (i.active = i === item));
    if (this.hostIsScrollable) {
      let activeItem = this.getActiveItem();
      if (!activeItem)
        return;
      const viewHeight = this.host.clientHeight;
      const boundTop = this.host.scrollTop;
      const boundBottom = this.host.scrollTop + viewHeight;
      const elTop = activeItem.offsetTop;
      const elBottom = elTop + activeItem.offsetHeight;
      const behavior = 'smooth';
      if (elTop < boundTop) {
        this.host.scrollTo({ top: elTop, behavior });
      }
      else if (elBottom > boundBottom) {
        this.host.scrollTo({ top: elBottom - viewHeight, behavior });
      }
    }
  }
  handleFocus() {
    this.xnFocus.emit();
    // Activate the first item if no other item is active
    const activeItem = this.getActiveItem();
    if (!activeItem) {
      const items = this.getItems();
      this.setActiveItem(items[0]);
    }
  }
  handleBlur() {
    this.setActiveItem();
    this.xnBlur.emit();
  }
  handleClick(event) {
    const target = event.target;
    const item = target.closest('xena-menu-item');
    if (item && !item.disabled) {
      this.xnSelect.emit({ item });
    }
  }
  handleKeyDown(event) {
    // Make a selection when pressing enter
    if (['Enter', 'Tab'].includes(event.key)) {
      const item = this.getActiveItem();
      event.preventDefault();
      if (item) {
        this.xnSelect.emit({ item });
      }
    }
    // Prevent scrolling when space is pressed
    if (event.key === ' ') {
      event.preventDefault();
    }
    // Move the selection when pressing down or up
    if (['ArrowDown', 'ArrowUp', 'Home', 'End'].includes(event.key)) {
      const items = this.getItems();
      const selectedItem = this.getActiveItem();
      let index = items.indexOf(selectedItem);
      if (items.length) {
        event.preventDefault();
        event.stopPropagation();
        if (event.key === 'ArrowDown') {
          index++;
        }
        else if (event.key === 'ArrowUp') {
          index--;
        }
        else if (event.key === 'Home') {
          index = 0;
        }
        else if (event.key === 'End') {
          index = items.length - 1;
        }
        if (index < 0)
          index = 0;
        if (index > items.length - 1)
          index = items.length - 1;
        this.setActiveItem(items[index]);
        return;
      }
    }
    this.typeToSelect(event.key);
  }
  handleMouseOver(event) {
    const target = event.target;
    const item = target.closest('xena-menu-item');
    this.setActiveItem(item);
  }
  handleMouseOut() {
    this.setActiveItem(null);
  }
  render() {
    return (index.h("div", { ref: el => (this.menu = el), part: "base", class: {
        menu: true,
        'menu--has-focus': this.hasFocus
      }, tabIndex: 0, role: "menu", onClick: this.handleClick, onFocus: this.handleFocus, onBlur: this.handleBlur, onKeyDown: this.handleKeyDown, onMouseOver: this.handleMouseOver, onMouseOut: this.handleMouseOut }, index.h("slot", null)));
  }
  get host() { return index.getElement(this); }
};
Menu.style = menuCss;

const menuItemCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:block}.menu-item{position:relative;display:flex;align-items:stretch;font-family:var(--xena-font-sans);font-size:var(--xena-font-size-medium);font-weight:var(--xena-font-weight-normal);line-height:var(--xena-line-height-normal);letter-spacing:var(--xena-letter-spacing-normal);text-align:left;color:var(--xena-input-color);padding:var(--xena-spacing-2x-small) var(--xena-spacing-medium);transition:var(--xena-transition-fast) fill;user-select:none;white-space:nowrap;cursor:pointer;text-decoration:none;gap:var(--xena-spacing-x-small)}.menu-item.menu-item--active:not(.menu-item--disabled),.menu-item.menu-item--hover:not(.menu-item--disabled){background-color:var(--xena-color-gray-100);color:var(--xena-input-color)}.menu-item.menu-item--checked:not(.menu-item--disabled){background-color:var(--xena-color-blue-500);color:var(--xena-color-white)}.menu-item.menu-item--disabled{color:var(--xena-color-gray-300);cursor:default}.menu-item .menu-item__label{flex:1 1 auto;overflow:hidden;text-overflow:ellipsis}.menu-item .menu-item__prefix{flex:0 0 auto;display:flex;align-items:center}.menu-item:not(.menu-item--has-prefix) .menu-item__prefix{display:none}.menu-item .menu-item__suffix{flex:0 0 auto;display:flex;align-items:center}.menu-item .menu-item__check{display:flex;position:absolute;left:0.5em;top:calc(50% - 0.5em);visibility:hidden;align-items:center;font-size:inherit}";

let MenuItem = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.xnActivate = index.createEvent(this, "xnActivate", 7);
    this.xnDeactivate = index.createEvent(this, "xnDeactivate", 7);
    /** Set to true to draw the item in a checked state. */
    this.checked = false;
    /**
     * Draws the menu in an active (i.e. or hover/focus), state to indicate the current menu selection. This is used in
     * lieu of standard :hover and :focus states to prevent concurrent interactions from different devices, such as
     * focusing with the keyboard and hovering with the mouse.
     */
    this.active = false;
    /** A unique value to store in the menu item. */
    this.value = '';
    /** Set to true to draw the menu item in a disabled state. */
    this.disabled = false;
    this.hasPrefix = false;
  }
  handleSlotChange() {
    this.hasPrefix = slot.hasSlot(this.host, 'prefix');
  }
  handleActiveChange() {
    this.active ? this.xnActivate.emit() : this.xnDeactivate.emit();
  }
  /** Sets this menu item active */
  async setActive(value) {
    this.active = value;
  }
  render() {
    const isLink = this.href && !this.disabled ? true : false;
    const MenuItemElement = isLink ? 'a' : 'div';
    return (index.h(MenuItemElement, { part: "base", class: {
        'menu-item': true,
        'menu-item--checked': this.checked,
        'menu-item--active': this.active,
        'menu-item--disabled': this.disabled,
        'menu-item--has-prefix': this.hasPrefix
      }, role: "menuitem", "aria-disabled": this.disabled, "aria-selected": this.checked, href: isLink && this.href }, index.h("span", { part: "prefix", class: "menu-item__prefix" }, index.h("slot", { name: "prefix", onSlotchange: _ => this.handleSlotChange() })), index.h("span", { part: "label", class: "menu-item__label" }, index.h("slot", null)), index.h("span", { part: "suffix", class: "menu-item__suffix" }, index.h("slot", { name: "suffix" }))));
  }
  get host() { return index.getElement(this); }
  static get watchers() { return {
    "active": ["handleActiveChange"]
  }; }
};
MenuItem.style = menuItemCss;

exports.xena_menu = Menu;
exports.xena_menu_item = MenuItem;
