import { Component, h, Prop, State, Element } from '@stencil/core';
import { hasSlot } from '../../utils/slot';
/**
 * @since 1.6
 * @status experimental
 *
 * @slot - The empty placeholder's content.
 * @slot icon - Illustration for the empty element.
 * @slot actions - Space for actions.
 * @slot secondary-actions - Space for additional actions.
 *
 * @part base - The base wrapper
 * @part header - The header
 * @part illustration - The illustration wrapper
 * @part text - The text wrapper
 */
export class Empty {
  constructor() {
    this.hasActions = false;
    this.hasSecondaryActions = false;
  }
  handleSlotChange() {
    this.hasActions = hasSlot(this.host, 'actions');
    this.hasSecondaryActions = hasSlot(this.host, 'secondary-actions');
  }
  render() {
    return (h("div", { class: {
        empty: true,
        'empty--has-actions': this.hasActions,
        'empty--has-secondary-actions': this.hasSecondaryActions
      }, part: "base" },
      h("div", { class: "empty-illustration", part: "illustration" },
        h("slot", { name: "icon" },
          h("xena-icon", { name: "fas-inbox" }))),
      h("div", { class: "empty-text", part: "text" },
        this.header ? (h("h3", { class: "empty-headline", part: "header" }, this.header)) : null,
        h("slot", null, "No data")),
      h("slot", { name: "actions", onSlotchange: _ => this.handleSlotChange() }),
      h("slot", { name: "secondary-actions", onSlotchange: _ => this.handleSlotChange() })));
  }
  static get is() { return "xena-empty"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["empty.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["empty.css"]
  }; }
  static get properties() { return {
    "header": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The empty headline"
      },
      "attribute": "header",
      "reflect": false
    }
  }; }
  static get states() { return {
    "hasActions": {},
    "hasSecondaryActions": {}
  }; }
  static get elementRef() { return "host"; }
}
