import { Component, Element, h, Prop, State } from '@stencil/core';
import { hasSlot } from '../../utils/slot';
/**
 * @since 1.3
 * @status experimental
 *
 * @part base - The component's base wrapper.
 *
 * @slot prefix - Space for icons, avatars or other features
 * @slot - The main content
 * @slot suffix - Space for icons, menus and other actions
 */
export class ListItem {
  constructor() {
    this.hasPrefix = false;
    this.hasSuffix = false;
  }
  handleSlotChange() {
    this.hasPrefix = hasSlot(this.host, 'prefix');
    this.hasSuffix = hasSlot(this.host, 'suffix');
  }
  render() {
    const isLink = this.href ? true : false;
    return isLink ? (h("a", { part: "base", class: {
        'list-item': true,
        'list-item--has-prefix': this.hasPrefix,
        'list-item--has-suffix': this.hasSuffix
      }, href: this.href },
      h("slot", { name: "prefix", onSlotchange: _ => this.handleSlotChange() }),
      h("div", { class: "list-item-content" },
        h("slot", null)),
      h("slot", { name: "suffix", onSlotchange: _ => this.handleSlotChange() }),
      h("xena-icon", { name: "fas-chevron-right" }))) : (h("div", { part: "base", class: {
        'list-item': true,
        'list-item--has-prefix': this.hasPrefix,
        'list-item--has-suffix': this.hasSuffix
      } },
      h("slot", { name: "prefix", onSlotchange: _ => this.handleSlotChange() }),
      h("div", { class: "list-item-content" },
        h("slot", null)),
      h("slot", { name: "suffix", onSlotchange: _ => this.handleSlotChange() })));
  }
  static get is() { return "xena-list-item"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["list-item.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["list-item.css"]
  }; }
  static get properties() { return {
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "When set, the list item will be rendered as an `<a>` with this `href` instead of a `<div>`."
      },
      "attribute": "href",
      "reflect": false
    }
  }; }
  static get states() { return {
    "hasPrefix": {},
    "hasSuffix": {}
  }; }
  static get elementRef() { return "host"; }
}
