import { Component, Event, h, Prop, Watch } from '@stencil/core';
/**
 * @since 1.0
 * @status experimental
 *
 * @part base - The component's base wrapper.
 *
 */
export class Pagination {
  constructor() {
    /** The tooltip for button the changes paginator to the first page. */
    this.firstPageTooltip = 'First Page';
    /** The tooltip for button the changes paginator to the previous page. */
    this.previousPageTooltip = 'Previous Page';
    /** The tooltip for button the changes paginator to the next page. */
    this.nextPageTooltip = 'Next Page';
    /** The tooltip for button the changes paginator to the last page. */
    this.lastPageTooltip = 'Last Page';
    /** The total pages available. */
    this.totalPages = 1;
    /** The current page. */
    this.page = 0;
    /** Label added just before the page selector. */
    this.pageLabel = 'Page';
    /** Label added just before the total number of pages. */
    this.totalPagesLabel = 'of';
  }
  validatePage() {
    if (this.page < 0) {
      this.page = 0;
    }
    if (this.page > this.totalPages - 1) {
      this.page = this.totalPages - 1;
    }
  }
  goToFirst(_ev) {
    this.setPage(0);
  }
  goToPrevious(_ev) {
    this.setPage(Math.max(0, this.page - 1));
  }
  goToNext(_ev) {
    this.setPage(Math.min(this.totalPages - 1, this.page + 1));
  }
  goToLast(_ev) {
    this.setPage(this.totalPages - 1);
  }
  onSelection(_ev) {
    this.setPage(parseInt(this.nativeSelect.value));
  }
  setPage(page) {
    this.page = page;
    this.pageChange.emit(page);
  }
  get pageList() {
    const pages = [];
    for (let i = 0; i < this.totalPages; i++) {
      pages.push(i);
    }
    return pages;
  }
  render() {
    return (h("nav", { class: "pagination", part: "base" },
      h("span", null,
        h("xena-tooltip", { content: this.firstPageTooltip },
          h("button", { onClick: ev => this.goToFirst(ev) },
            h("xena-icon", { name: "fas-angle-double-left" })))),
      h("span", null,
        h("xena-tooltip", { content: this.previousPageTooltip },
          h("button", { onClick: ev => this.goToPrevious(ev) },
            h("xena-icon", { name: "fas-angle-left" })))),
      h("span", null,
        h("div", { class: "pagination-select" },
          this.pageLabel,
          "\u00A0",
          h("select", { ref: el => (this.nativeSelect = el), class: "paging-select", onChange: ev => this.onSelection(ev) }, this.pageList.map(page => (h("option", { value: page, selected: page === this.page }, page + 1)))),
          "\u00A0",
          this.totalPagesLabel,
          "\u00A0",
          this.totalPages)),
      h("span", null,
        h("xena-tooltip", { content: this.nextPageTooltip },
          h("button", { id: "test", onClick: ev => this.goToNext(ev) },
            h("xena-icon", { name: "fas-angle-right" })))),
      h("span", null,
        h("xena-tooltip", { content: this.lastPageTooltip },
          h("button", { onClick: ev => this.goToLast(ev) },
            h("xena-icon", { name: "fas-angle-double-right" }))))));
  }
  static get is() { return "xena-pagination"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["pagination.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["pagination.css"]
  }; }
  static get properties() { return {
    "firstPageTooltip": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The tooltip for button the changes paginator to the first page."
      },
      "attribute": "first-page-tooltip",
      "reflect": false,
      "defaultValue": "'First Page'"
    },
    "previousPageTooltip": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The tooltip for button the changes paginator to the previous page."
      },
      "attribute": "previous-page-tooltip",
      "reflect": false,
      "defaultValue": "'Previous Page'"
    },
    "nextPageTooltip": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The tooltip for button the changes paginator to the next page."
      },
      "attribute": "next-page-tooltip",
      "reflect": false,
      "defaultValue": "'Next Page'"
    },
    "lastPageTooltip": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The tooltip for button the changes paginator to the last page."
      },
      "attribute": "last-page-tooltip",
      "reflect": false,
      "defaultValue": "'Last Page'"
    },
    "totalPages": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The total pages available."
      },
      "attribute": "total-pages",
      "reflect": false,
      "defaultValue": "1"
    },
    "page": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The current page."
      },
      "attribute": "page",
      "reflect": false,
      "defaultValue": "0"
    },
    "pageLabel": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label added just before the page selector."
      },
      "attribute": "page-label",
      "reflect": false,
      "defaultValue": "'Page'"
    },
    "totalPagesLabel": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label added just before the total number of pages."
      },
      "attribute": "total-pages-label",
      "reflect": false,
      "defaultValue": "'of'"
    }
  }; }
  static get events() { return [{
      "method": "pageChange",
      "name": "pageChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when the page changes."
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "page",
      "methodName": "validatePage"
    }]; }
}
