import { Component, h, Prop } from '@stencil/core';
/**
 * @since 1.0
 * @status stable
 *
 * @slot - The popover body text.
 * @slot header - The popover header text.
 * @slot trigger - The element that triggeres the popup.
 *
 * @part base - The component's base wrapper.
 * @part header - The popover header.
 * @part body - The popover body.
 *
 */
export class Popover {
  constructor() {
    /** Show arrow on the popover pointing to the trigger. */
    this.arrow = false;
    /** Indicates whether or not the popover is open. */
    this.open = false;
    /** The distance in pixels from which to offset the panel away from its trigger. */
    this.distance = 2;
  }
  render() {
    return (h("xena-dropdown", { placement: "bottom", arrow: this.arrow, open: this.open, distance: this.distance },
      h("div", { slot: "trigger" },
        h("slot", { name: "trigger" })),
      h("div", { class: "popover", part: "base" },
        h("div", { class: "popover-inner", role: "tooltip" },
          h("div", { class: "popover-title", part: "header" },
            h("slot", { name: "header" })),
          h("div", { class: "popover-body", part: "body" },
            h("slot", null))))));
  }
  static get is() { return "xena-popover"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["popover.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["popover.css"]
  }; }
  static get properties() { return {
    "arrow": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Show arrow on the popover pointing to the trigger."
      },
      "attribute": "arrow",
      "reflect": false,
      "defaultValue": "false"
    },
    "open": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Indicates whether or not the popover is open."
      },
      "attribute": "open",
      "reflect": false,
      "defaultValue": "false"
    },
    "distance": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The distance in pixels from which to offset the panel away from its trigger."
      },
      "attribute": "distance",
      "reflect": false,
      "defaultValue": "2"
    }
  }; }
}
