import { Component, h, Prop, Host } from '@stencil/core';
/**
 * @since 1.0
 * @status stable
 *
 * @part base - The component's base wrapper.
 */
export class Spinner {
  constructor() {
    /** Spinner style */
    this.mode = 'circle';
    /** Spinner label */
    this.label = '';
  }
  render() {
    return (h(Host, { class: this.mode },
      h("span", { class: {
          spinner: true,
          circle: this.mode === 'circle',
          squares: this.mode === 'squares'
        }, part: "base", "aria-busy": "true", "aria-live": "polite" }),
      this.label.length > 0 ? h("span", { class: "spinner-text" }, this.label) : ''));
  }
  static get is() { return "xena-spinner"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["spinner.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["spinner.css"]
  }; }
  static get properties() { return {
    "mode": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'circle' | 'squares'",
        "resolved": "\"circle\" | \"squares\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Spinner style"
      },
      "attribute": "mode",
      "reflect": false,
      "defaultValue": "'circle'"
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Spinner label"
      },
      "attribute": "label",
      "reflect": false,
      "defaultValue": "''"
    }
  }; }
}
