import { Component, Element, Prop, h, State } from '@stencil/core';
import { hasSlot } from '../../utils/slot';
/**
 * @since 1.5
 * @status experimental
 *
 * @slot - The value
 * @slot prefix - Optional prefix slot for icon
 * @slot suffix - Optional suffix slot for icon
 *
 * @part base - The component's base wrapper
 * @part label - The label
 * @part value - The statistic value
 */
export class Statistic {
  constructor() {
    this.hasPrefix = false;
    this.hasSuffix = false;
  }
  handleSlotChange() {
    this.hasPrefix = hasSlot(this.host, 'prefix');
    this.hasSuffix = hasSlot(this.host, 'suffix');
  }
  render() {
    return (h("div", { class: {
        statistic: true,
        'statistic--has-prefix': this.hasPrefix,
        'statistic--has-suffix': this.hasSuffix,
        'statistic--success': this.type === 'success',
        'statistic--danger': this.type === 'danger'
      }, part: "base" },
      h("div", { class: "statistic-title", part: "label" }, this.label),
      h("div", { class: "statistic-content" },
        h("div", { class: "statistic-content-prefix", part: "prefix" },
          h("slot", { name: "prefix", onSlotchange: _ => this.handleSlotChange() })),
        h("div", { class: "statistic-content-value", part: "value" },
          h("slot", null)),
        h("div", { class: "statistic-content-suffix", part: "suffix" },
          h("slot", { name: "suffix", onSlotchange: _ => this.handleSlotChange() })))));
  }
  static get is() { return "xena-statistic"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["statistic.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["statistic.css"]
  }; }
  static get properties() { return {
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label of the statistic"
      },
      "attribute": "label",
      "reflect": false
    },
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'success' | 'danger'",
        "resolved": "\"danger\" | \"success\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Optional theming"
      },
      "attribute": "type",
      "reflect": false
    }
  }; }
  static get states() { return {
    "hasPrefix": {},
    "hasSuffix": {}
  }; }
  static get elementRef() { return "host"; }
}
