import { Component, h, Prop } from '@stencil/core';
import { i18n } from '../../utils/i18n';
/**
 * @since 1.7
 * @status experimental
 *
 * @part base - The component's base wrapper.
 */
export class Step {
  constructor() {
    /** The active step. */
    this.step = 1;
  }
  getAllSteps() {
    const slot = this.stepList.querySelector('slot');
    return [...slot.assignedElements()].filter((el) => {
      return el.tagName.toLowerCase() === 'xena-step-item';
    });
  }
  componentDidRender() {
    const steps = this.getAllSteps();
    steps.forEach((step, index) => {
      step.active = index < this.step;
      step.header = `${i18n('STEP')} ${index + 1}`;
    });
  }
  render() {
    return (h("div", { class: {
        step: true
      } },
      h("div", { class: "step__list", ref: el => (this.stepList = el) },
        h("slot", null))));
  }
  static get is() { return "xena-step"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["step.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["step.css"]
  }; }
  static get properties() { return {
    "step": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The active step."
      },
      "attribute": "step",
      "reflect": false,
      "defaultValue": "1"
    }
  }; }
}
