import { Component, Prop, h, Element, Host } from '@stencil/core';
/**
 * @since 1.8
 * @status experimental
 *
 * @part base - The base wrapper
 */
export class Table {
  constructor() {
    /**
     * When hover the rows whith the mouse the row coler will change
     */
    this.hoverable = false;
    /**
     * Adjust the cell padding
     */
    this.size = 'medium';
    /**
     * When scrolling the table the table headers will stick to the top of the screen
     */
    this.stickyHeader = false;
    /**
     * Set header styling or hide the header
     */
    this.type = 'default';
    /**
     * Make first column a vertical header
     */
    this.verticalHeader = false;
  }
  connectedCallback() {
    // Listen for changes
    if ('MutationObserver' in window) {
      this.mutationObserver = new MutationObserver(() => this.updateElements());
      this.mutationObserver.observe(this.host, { attributes: false, childList: true, subtree: false });
    }
    this.updateElements();
  }
  disconnectedCallback() {
    var _a;
    (_a = this.mutationObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
  }
  updateElements() {
    const columns = this.getColumns();
    // Ensure all columns are slotted correctly
    [...columns]
      .filter((el) => el.getAttribute('slot') !== 'columns')
      .forEach((el) => {
      el.setAttribute('slot', 'columns');
    });
  }
  getColumns() {
    return [...this.host.children].filter((el) => el.tagName.toLowerCase() === 'xena-column');
  }
  render() {
    return (h(Host, { class: {
        'vertical-header': this.verticalHeader,
        // Types
        'table--default': this.type === 'default',
        'table--light': this.type === 'light',
        'table--hidden': this.type === 'hidden'
      } },
      h("div", null,
        h("table", { ref: el => (this.table = el), class: {
            hoverable: this.hoverable,
            'sticky-header': this.stickyHeader,
            large: this.size === 'large',
            medium: this.size === 'medium',
            small: this.size === 'small'
          } },
          h("thead", null,
            h("tr", null,
              h("slot", { name: "columns" }))),
          h("tbody", null,
            h("slot", null))))));
  }
  static get is() { return "xena-table"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["table.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["table.css"]
  }; }
  static get properties() { return {
    "hoverable": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "When hover the rows whith the mouse the row coler will change"
      },
      "attribute": "hoverable",
      "reflect": true,
      "defaultValue": "false"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "SizeTypes",
        "resolved": "\"large\" | \"medium\" | \"small\"",
        "references": {
          "SizeTypes": {
            "location": "import",
            "path": "../../utils/types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Adjust the cell padding"
      },
      "attribute": "size",
      "reflect": true,
      "defaultValue": "'medium'"
    },
    "stickyHeader": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "When scrolling the table the table headers will stick to the top of the screen"
      },
      "attribute": "sticky-header",
      "reflect": true,
      "defaultValue": "false"
    },
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'default' | 'light' | 'hidden'",
        "resolved": "\"default\" | \"hidden\" | \"light\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set header styling or hide the header"
      },
      "attribute": "type",
      "reflect": true,
      "defaultValue": "'default'"
    },
    "verticalHeader": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Make first column a vertical header"
      },
      "attribute": "vertical-header",
      "reflect": true,
      "defaultValue": "false"
    }
  }; }
  static get elementRef() { return "host"; }
}
