import { Component, h, Prop } from '@stencil/core';
/**
 * @since 1.5
 * @status experimental
 *
 * @slot default - Body text
 * @slot icon - Icon for the timeline item
 * @slot author - The origin of this timeline event
 * @slot status - Optional slot for showing status
 * @slot timestamp - Slot for when the timeline event happened
 * @slot header - The headline for this event
 * @slot actions - Slot for dropdown menu
 *
 * @part base - The component's base wrapper
 * @part prefix - Icon and line area
 * @part content - Content area
 * @part info - Basic information area
 * @part body - Body area
 * @part suffix - Menu area
 *
 */
export class TimelineItem {
  constructor() {
    /** Set if event has attachments. */
    this.hasAttachments = false;
  }
  render() {
    return (h("li", { class: "timeline-item", part: "base" },
      h("div", { class: "timeline-item-prefix", part: "prefix" },
        h("slot", { name: "icon" })),
      h("div", { class: "timeline-item-content", part: "content" },
        h("div", { class: "timeline-item-info", part: "info" },
          h("slot", { name: "author" }),
          h("slot", { name: "status" }),
          h("slot", { name: "timestamp" })),
        h("div", { class: "timeline-item-body", part: "body" },
          h("div", { class: "timeline-item-header" },
            h("slot", { name: "header" }),
            this.hasAttachments ? h("xena-icon", { name: "fas-paperclip" }) : ''),
          h("slot", null))),
      h("div", { class: "timeline-item-menu", part: "suffix" },
        h("slot", { name: "actions" }))));
  }
  static get is() { return "xena-timeline-item"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["timeline-item.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["timeline-item.css"]
  }; }
  static get properties() { return {
    "hasAttachments": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Set if event has attachments."
      },
      "attribute": "has-attachments",
      "reflect": true,
      "defaultValue": "false"
    }
  }; }
}
