/**
 * Elements inside of web components sometimes need to inherit global attributes
 * set on the host. For example, the inner input in `ion-input` should inherit
 * the `title` attribute that developers set directly on `ion-input`. This
 * helper function should be called in componentWillLoad and assigned to a variable
 * that is later used in the render function.
 *
 * This does not need to be reactive as changing attributes on the host element
 * does not trigger a re-render.
 */
export const inheritAttributes = (el, attributes = []) => {
  const attributeObject = {};
  attributes.forEach(attr => {
    if (el.hasAttribute(attr)) {
      const value = el.getAttribute(attr);
      if (value !== null) {
        attributeObject[attr] = el.getAttribute(attr);
      }
      el.removeAttribute(attr);
    }
  });
  return attributeObject;
};
/**
 *
 * @param element Detects whether element has css class specified.
 * @param cssClass
 */
export const hasClass = (element, cssClass) => {
  let classList = element.classList;
  for (let i = 0; i < classList.length; i++) {
    if (cssClass === classList[i]) {
      return true;
    }
  }
  return false;
};
/**
 * Retrioeves whether element has parent specified with cssquery in dom tree.
 * @param element
 * @param cssQueries
 */
export const hasParent = (element, ...cssQueries) => {
  let currentTarget = element;
  while (currentTarget !== null) {
    if (!(currentTarget instanceof HTMLElement)) {
      return false;
    }
    for (let i = 0; i < cssQueries.length; i++) {
      const query = cssQueries[i];
      if (query.startsWith('.') && hasClass(currentTarget, query.substr(1))) {
        return true;
      }
      if (currentTarget.tagName.toLowerCase() === query.toLowerCase()) {
        return true;
      }
    }
    currentTarget = currentTarget.parentElement;
  }
};
