class Colors {
  /**
   * Retrieves the available shade.
   */
  static get shades() {
    return [...Colors._shades];
  }
  /**
   * Retrieves the available colors.
   */
  static get colors() {
    return [...Colors._colors];
  }
  /**
   * Retrieves a color shade based on the color name and shade value.
   * @param color The name of the color.
   * @param shade The shade number.
   * @returns The CSS variable matching the requested color shade.
   */
  static getColorShade(color, shade) {
    color = color.toLowerCase();
    if (this._colors.indexOf(color) < 0) {
      throw `The color "${color}" is not a valid color."`;
    }
    // Adjust shade value
    let adjustedShade = this._shades.reduce((prev, curr) => Math.abs(curr - shade) <= Math.abs(prev - shade) ? curr : prev);
    // Return color shade variable name
    return `--xena-color-${color}-${adjustedShade}`;
  }
  static hslToRgb(h, s, l) {
    h /= 360;
    s /= 100;
    l /= 100;
    let r, g, b;
    if (s === 0) {
      r = g = b = l;
    }
    else {
      const hue2rgb = (p, q, t) => {
        if (t < 0)
          t += 1;
        if (t > 1)
          t -= 1;
        if (t < 1 / 6)
          return p + (q - p) * 6 * t;
        if (t < 1 / 2)
          return q;
        if (t < 2 / 3)
          return p + (q - p) * (2 / 3 - t) * 6;
        return p;
      };
      const q = l < 0.5 ? l * (1 + s) : l + s - l * s;
      const p = 2 * l - q;
      r = hue2rgb(p, q, h + 1 / 3);
      g = hue2rgb(p, q, h);
      b = hue2rgb(p, q, h - 1 / 3);
    }
    r = Math.round(r * 255);
    g = Math.round(g * 255);
    b = Math.round(b * 255);
    return { r, g, b };
  }
  static rgbToHex(r, g, b) {
    return `#${((1 << 24) | (r << 16) | (g << 8) | b).toString(16).slice(1)}`;
  }
  static hexToRgb(hexValue) {
    const r = parseInt(hexValue.slice(1, 3), 16);
    const g = parseInt(hexValue.slice(3, 5), 16);
    const b = parseInt(hexValue.slice(5, 7), 16);
    return { r, g, b };
  }
  static rgbToHsl(r, g, b) {
    r /= 255;
    g /= 255;
    b /= 255;
    const max = Math.max(r, g, b);
    const min = Math.min(r, g, b);
    let h, s, l;
    if (max === min) {
      h = 0;
    }
    else if (max === r) {
      h = Math.round(((g - b) / (max - min)) * 60);
      if (h < 0)
        h += 360;
    }
    else if (max === g) {
      h = Math.round((2 + (b - r) / (max - min)) * 60);
    }
    else {
      h = Math.round((4 + (r - g) / (max - min)) * 60);
    }
    s = max === 0 || max - min === 0 ? 0 : Math.round(((max - min) / (1 - Math.abs(max + min - 1))) * 100);
    l = Math.round(((max + min) / 2) * 100);
    return { h, s, l };
  }
}
Colors._colors = ['gray', 'cool', 'red', 'orange', 'yellow', 'green', 'mint', 'marine', 'blue', 'purple'];
Colors._shades = [50, 100, 200, 300, 400, 500, 600, 700, 800, 900, 950];

export { Colors as C };
