import { h } from './index-9032f50f.js';

const FormControl = (props, children) => {
  const hasLabel = props.label ? true : props.hasLabelSlot;
  const hasHelpText = props.helpText ? true : props.hasHelpTextSlot;
  const hasErrorText = props.errorText ? true : props.hasErrorTextSlot;
  const isRequired = !!props.required || false;
  return (h("div", { part: "form-control", class: {
      'form-control': true,
      'form-control--small': props.size === 'small',
      'form-control--medium': props.size === 'medium',
      'form-control--large': props.size === 'large',
      'form-control--has-label': hasLabel,
      'form-control--has-help-text': hasHelpText,
      'form-control--has-error-text': hasErrorText
    } },
    h("label", { part: "label", id: props.labelId, class: "form-control__label", htmlFor: props.inputId, "aria-hidden": hasLabel ? 'false' : 'true', onClick: props.onLabelClick },
      h("slot", { name: "label" }, props.label),
      isRequired && h("span", { class: "form-control__label-required" }, "*")),
    h("div", { class: "form-control__input" }, children),
    h("div", { part: "help-text", id: props.helpTextId, class: "form-control__help-text", "aria-hidden": hasHelpText && !hasErrorText ? 'false' : 'true' },
      h("slot", { name: "help-text" }, props.helpText)),
    h("div", { part: "error-text", id: props.errorTextId, class: "form-control__error-text", "aria-hidden": hasErrorText ? 'false' : 'true' },
      h("slot", { name: "error-text" }, props.errorText))));
};

export { FormControl as F };
