import { r as registerInstance, c as createEvent, h } from './index-9032f50f.js';

const paginationCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block}.pagination{display:inline-flex;list-style:none;border-radius:var(--xena-input-border-radius-medium);height:var(--xena-input-height-medium);line-height:var(--xena-line-height-dense)}.pagination>span button{position:relative;height:var(--xena-input-height-medium);margin:0 0 0 -1px;padding:var(--xena-spacing-x-small) var(--xena-spacing-small);text-decoration:none;background-color:var(--xena-input-background-color);border:1px solid var(--xena-input-border-color);color:var(--xena-input-color);display:block;font-size:var(--xena-button-font-size-dense)}.pagination>span button>xena-icon{vertical-align:middle}.pagination>span:first-child button{margin-left:0;border-bottom-left-radius:4px;border-top-left-radius:4px}.pagination>span:last-child button{border-bottom-right-radius:4px;border-top-right-radius:4px}.pagination-select{padding:var(--xena-spacing-x-small) var(--xena-spacing-small);border:1px solid var(--xena-input-border-color);margin-left:-1px;background-color:var(--xena-color-white);display:inline-flex;align-items:center;height:var(--xena-input-height-medium)}.pagination-select>.paging-select{border:1px solid var(--xena-input-border-color)}.pagination>span button:hover,.pagination>span button:focus{color:var(--xena-input-color-hover);background-color:var(--xena-color-gray-50);border-color:var(--xena-input-border-color-hover)}";

let Pagination = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.pageChange = createEvent(this, "pageChange", 7);
    /** The tooltip for button the changes paginator to the first page. */
    this.firstPageTooltip = 'First Page';
    /** The tooltip for button the changes paginator to the previous page. */
    this.previousPageTooltip = 'Previous Page';
    /** The tooltip for button the changes paginator to the next page. */
    this.nextPageTooltip = 'Next Page';
    /** The tooltip for button the changes paginator to the last page. */
    this.lastPageTooltip = 'Last Page';
    /** The total pages available. */
    this.totalPages = 1;
    /** The current page. */
    this.page = 0;
    /** Label added just before the page selector. */
    this.pageLabel = 'Page';
    /** Label added just before the total number of pages. */
    this.totalPagesLabel = 'of';
  }
  validatePage() {
    if (this.page < 0) {
      this.page = 0;
    }
    if (this.page > this.totalPages - 1) {
      this.page = this.totalPages - 1;
    }
  }
  goToFirst(_ev) {
    this.setPage(0);
  }
  goToPrevious(_ev) {
    this.setPage(Math.max(0, this.page - 1));
  }
  goToNext(_ev) {
    this.setPage(Math.min(this.totalPages - 1, this.page + 1));
  }
  goToLast(_ev) {
    this.setPage(this.totalPages - 1);
  }
  onSelection(_ev) {
    this.setPage(parseInt(this.nativeSelect.value));
  }
  setPage(page) {
    this.page = page;
    this.pageChange.emit(page);
  }
  get pageList() {
    const pages = [];
    for (let i = 0; i < this.totalPages; i++) {
      pages.push(i);
    }
    return pages;
  }
  render() {
    return (h("nav", { class: "pagination", part: "base" }, h("span", null, h("xena-tooltip", { content: this.firstPageTooltip }, h("button", { onClick: ev => this.goToFirst(ev) }, h("xena-icon", { name: "fas-angle-double-left" })))), h("span", null, h("xena-tooltip", { content: this.previousPageTooltip }, h("button", { onClick: ev => this.goToPrevious(ev) }, h("xena-icon", { name: "fas-angle-left" })))), h("span", null, h("div", { class: "pagination-select" }, this.pageLabel, "\u00A0", h("select", { ref: el => (this.nativeSelect = el), class: "paging-select", onChange: ev => this.onSelection(ev) }, this.pageList.map(page => (h("option", { value: page, selected: page === this.page }, page + 1)))), "\u00A0", this.totalPagesLabel, "\u00A0", this.totalPages)), h("span", null, h("xena-tooltip", { content: this.nextPageTooltip }, h("button", { id: "test", onClick: ev => this.goToNext(ev) }, h("xena-icon", { name: "fas-angle-right" })))), h("span", null, h("xena-tooltip", { content: this.lastPageTooltip }, h("button", { onClick: ev => this.goToLast(ev) }, h("xena-icon", { name: "fas-angle-double-right" }))))));
  }
  static get watchers() { return {
    "page": ["validatePage"]
  }; }
};
Pagination.style = paginationCss;

export { Pagination as xena_pagination };
