import { r as registerInstance, c as createEvent, h, g as getElement } from './index-9032f50f.js';

const radioCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{display:inline-block;--background-color:var(--xena-input-background-color);--background-color--hover:var(--xena-input-background-color-hover);--background-color--focus:var(--xena-input-background-color-focus);--background-color--selected:var(--xena-color-blue-500);--background-color--selected-hover:var(--xena-color-blue-400);--background-color--selected-focus:var(--xena-color-blue-400);--border-color:var(--xena-input-border-color);--border-color--hover:var(--xena-input-border-color-hover);--border-color--focus:var(--xena-input-border-color-focus);--border-color--selected:var(--xena-color-blue-500);--border-color--selected-hover:var(--xena-color-blue-400);--border-color--selected-focus:var(--xena-color-blue-400);--dot:var(--xena-color-white)}.radio{display:inline-flex;font-family:var(--xena-input-font-family);font-size:var(--xena-input-font-size-medium);font-weight:var(--xena-input-font-weight);color:var(--xena-input-color);vertical-align:middle;cursor:pointer}.radio__icon{display:inline-flex;width:var(--xena-toggle-size);height:var(--xena-toggle-size);opacity:0}.radio__icon svg{width:100%;height:100%}.radio--checked .radio__icon{opacity:1}.radio__control{position:relative;display:inline-flex;align-items:center;justify-content:center;width:var(--xena-toggle-size);height:var(--xena-toggle-size);border:solid var(--xena-input-border-width) var(--border-color);outline:solid 0 var(--xena-focus-ring-color-blue);border-radius:50%;background-color:var(--background-color);color:transparent;transition:var(--xena-transition-fast) border-color, var(--xena-transition-fast) background-color, var(--xena-transition-fast) color, outline var(--xena-transition-x-fast) ease-in-out}.radio__control input[type=radio]{position:absolute;opacity:0;padding:0;margin:0;pointer-events:none}.radio:not(.radio--checked):not(.radio--disabled) .radio__control:hover{border-color:var(--border-color--hover);background-color:var(--background-color--hover)}.radio.radio--focused:not(.radio--checked):not(.radio--disabled) .radio__control{border-color:var(--border-color--focus);background-color:var(--background-color--focus);outline-width:var(--xena-focus-ring-width)}.radio--checked .radio__control{color:var(--dot);border-color:var(--border-color--selected);background-color:var(--background-color--selected)}.radio.radio--checked:not(.radio--disabled) .radio__control:hover{border-color:var(--border-color--selected-hover);background-color:var(--background-color--selected-hover)}.radio.radio--checked:not(.radio--disabled).radio--focused .radio__control{border-color:var(--border-color--selected-focus);background-color:var(--background-color--selected-focus);outline-width:var(--xena-focus-ring-width)}.radio--disabled{opacity:0.5;cursor:not-allowed}.radio--readonly{cursor:default}.radio__label{line-height:var(--xena-toggle-size);margin-left:0.5em;user-select:none}";

let id = 0;
let Radio = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.xnBlur = createEvent(this, "xnBlur", 7);
    this.checkedChange = createEvent(this, "checkedChange", 7);
    this.xnFocus = createEvent(this, "xnFocus", 7);
    this.inputId = `radio-${++id}`;
    this.labelId = `radio-label-${id}`;
    this.hasFocus = false;
    /** Set to true to disable the radio. */
    this.disabled = false;
    /** Set to true to make the radio readonly. */
    this.readonly = false;
    /** Set to true to draw the radio in a checked state. */
    this.checked = false;
    /**
     * This will be true when the control is in an invalid state. Validity in range inputs is determined by the message
     * provided by the `setCustomValidity` method.
     */
    this.invalid = false;
  }
  handleCheckedChange() {
    this.input.checked = this.checked;
    this.checkedChange.emit(this.checked);
  }
  connectedCallback() {
    this.handleClick = this.handleClick.bind(this);
    this.handleBlur = this.handleBlur.bind(this);
    this.handleFocus = this.handleFocus.bind(this);
    this.handleKeyDown = this.handleKeyDown.bind(this);
    this.handleMouseDown = this.handleMouseDown.bind(this);
  }
  /** Sets focus on the radio. */
  async setFocus(options) {
    this.input.focus(options);
  }
  /** Removes focus from the radio. */
  async removeFocus() {
    this.input.blur();
  }
  /** Checks for validity and shows the browser's validation message if the control is invalid. */
  async reportValidity() {
    return this.input.reportValidity();
  }
  /** Sets a custom validation message. If `message` is not empty, the field will be considered invalid. */
  async setCustomValidity(message) {
    this.input.setCustomValidity(message);
    this.invalid = !this.input.checkValidity();
  }
  getAllRadios() {
    const form = this.host.closest('xena-form, form') || document.body;
    if (!this.name)
      return [];
    return [...form.querySelectorAll('xena-radio')].filter((radio) => radio.name === this.name);
  }
  handleClick() {
    if (!this.readonly) {
      this.checked = this.input.checked;
    }
  }
  handleBlur() {
    this.hasFocus = false;
    this.xnBlur.emit();
  }
  handleFocus() {
    this.hasFocus = true;
    this.xnFocus.emit();
  }
  handleKeyDown(event) {
    if (['ArrowUp', 'ArrowDown', 'ArrowLeft', 'ArrowRight'].includes(event.key)) {
      const radios = this.getAllRadios().filter(radio => !radio.disabled);
      const incr = ['ArrowUp', 'ArrowLeft'].includes(event.key) ? -1 : 1;
      let index = radios.indexOf(this.host) + incr;
      if (index < 0)
        index = radios.length - 1;
      if (index > radios.length - 1)
        index = 0;
      this.getAllRadios().map(radio => (radio.checked = false));
      radios[index].setFocus();
      if (!this.readonly) {
        radios[index].checked = true;
      }
      event.preventDefault();
    }
  }
  handleMouseDown(event) {
    // Prevent clicks on the label from briefly blurring the input
    event.preventDefault();
    this.input.focus();
  }
  render() {
    return (h("label", { part: "base", class: {
        radio: true,
        'radio--checked': this.checked,
        'radio--disabled': this.disabled,
        'radio--focused': this.hasFocus,
        'radio--readonly': this.readonly
      }, htmlFor: this.inputId, onKeyDown: this.handleKeyDown, onMouseDown: this.handleMouseDown }, h("span", { part: "control", class: "radio__control" }, h("span", { part: "checked-icon", class: "radio__icon" }, h("svg", { viewBox: "0 0 16 16" }, h("g", { stroke: "none", "stroke-width": "1", fill: "none", "fill-rule": "evenodd" }, h("g", { fill: "currentColor" }, h("circle", { cx: "8", cy: "8", r: "3.42857143" }))))), h("input", { ref: el => (this.input = el), id: this.inputId, type: "radio", name: this.name, value: this.value, checked: this.checked, disabled: this.disabled, readOnly: this.readonly, role: "radio", "aria-checked": this.checked ? 'true' : 'false', "aria-labelledby": this.labelId, onClick: this.handleClick, onBlur: this.handleBlur, onFocus: this.handleFocus })), h("span", { part: "label", id: this.labelId, class: "radio__label" }, h("slot", null))));
  }
  get host() { return getElement(this); }
  static get watchers() { return {
    "checked": ["handleCheckedChange"]
  }; }
};
Radio.style = radioCss;

export { Radio as xena_radio };
