import { r as registerInstance, c as createEvent, h, H as Host, g as getElement } from './index-9032f50f.js';

const tabCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{--focus-ring:inset 0 0 0 var(--xena-focus-ring-width) var(--xena-focus-ring-color-blue);display:inline-block}.tab{display:inline-flex;align-items:center;font-family:var(--xena-font-sans);font-size:var(--xena-font-size-medium);font-weight:var(--xena-font-weight-semibold);border-radius:var(--xena-border-radius-medium);color:var(--xena-color-gray-600);padding:var(--xena-spacing-x-small) var(--xena-spacing-small);outline:solid 0 var(--xena-focus-ring-color-gray);white-space:nowrap;user-select:none;cursor:pointer;transition:var(--transition-speed) box-shadow, var(--transition-speed) color, outline var(--xena-transition-x-fast) ease-in-out}.tab:hover:not(.tab--disabled){color:var(--xena-color-blue-600)}.tab:focus:not(.tab--disabled){color:var(--xena-color-blue-600);outline-width:var(--xena-focus-ring-width)}.tab.tab--active:not(.tab--disabled){color:var(--xena-color-blue-600)}.tab.tab--closable{padding-right:var(--xena-spacing-small)}.tab.tab--disabled{opacity:0.5;cursor:default}.tab__close-button{font-size:var(--xena-font-size-large);margin-left:var(--xena-spacing-2x-small)}.tab__close-button::part(base){padding:var(--xena-spacing-3x-small)}";

let id = 0;
let Tab = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.xnClose = createEvent(this, "xnClose", 7);
    this.componentId = `tab-${++id}`;
    /** The name of the tab panel the tab will control. The panel must be located in the same tab group. */
    this.panel = '';
    /** Set to true to draw the tab in an active state. */
    this.active = false;
    /** When true, the tab will be rendered with a close icon. */
    this.closable = false;
    /** Set to true to draw the tab in a disabled state. */
    this.disabled = false;
  }
  connectedCallback() {
    this.handleCloseClick = this.handleCloseClick.bind(this);
  }
  /** Sets focus to the tab. */
  async setFocus(options) {
    this.tab.focus(options);
  }
  /** Removes focus from the tab. */
  async removeFocus() {
    this.tab.blur();
  }
  handleCloseClick() {
    this.xnClose.emit();
  }
  render() {
    return (
    // If the user didn't provide an ID, we'll set one so we can link tabs and tab panels with aria labels
    h(Host, { id: this.host.id || this.componentId }, h("div", { part: "base", ref: el => (this.tab = el), class: {
        tab: true,
        // States
        'tab--active': this.active,
        'tab--closable': this.closable,
        'tab--disabled': this.disabled
      }, role: "tab", "aria-disabled": this.disabled ? 'true' : 'false', "aria-selected": this.active ? 'true' : 'false', tabindex: this.disabled ? '-1' : '0' }, h("slot", null), this.closable && (h("xena-icon-button", { name: "fas-times", exportparts: "base:close-button", class: "tab__close-button", onClick: this.handleCloseClick, tabIndex: -1, "aria-hidden": "true" })))));
  }
  get host() { return getElement(this); }
};
Tab.style = tabCss;

export { Tab as xena_tab };
