import { r as registerInstance, h, H as Host, g as getElement } from './index-9032f50f.js';

const tableCss = ":host{position:relative;box-sizing:border-box}:host *,:host *:before,:host *:after{box-sizing:inherit}:host{--th-position:static;--cell-padding:var(--xena-spacing-x-small)}table{border-collapse:collapse;width:100%}.hoverable{--row-hover:var(--xena-color-gray-50)}.sticky-header{--th-position:sticky}.large{--cell-padding:var(--xena-spacing-medium)}.small{--cell-padding:var(--xena-spacing-2x-small)}";

let Table = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * When hover the rows whith the mouse the row coler will change
     */
    this.hoverable = false;
    /**
     * Adjust the cell padding
     */
    this.size = 'medium';
    /**
     * When scrolling the table the table headers will stick to the top of the screen
     */
    this.stickyHeader = false;
    /**
     * Set header styling or hide the header
     */
    this.type = 'default';
    /**
     * Make first column a vertical header
     */
    this.verticalHeader = false;
  }
  connectedCallback() {
    // Listen for changes
    if ('MutationObserver' in window) {
      this.mutationObserver = new MutationObserver(() => this.updateElements());
      this.mutationObserver.observe(this.host, { attributes: false, childList: true, subtree: false });
    }
    this.updateElements();
  }
  disconnectedCallback() {
    var _a;
    (_a = this.mutationObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
  }
  updateElements() {
    const columns = this.getColumns();
    // Ensure all columns are slotted correctly
    [...columns]
      .filter((el) => el.getAttribute('slot') !== 'columns')
      .forEach((el) => {
      el.setAttribute('slot', 'columns');
    });
  }
  getColumns() {
    return [...this.host.children].filter((el) => el.tagName.toLowerCase() === 'xena-column');
  }
  render() {
    return (h(Host, { class: {
        'vertical-header': this.verticalHeader,
        // Types
        'table--default': this.type === 'default',
        'table--light': this.type === 'light',
        'table--hidden': this.type === 'hidden'
      } }, h("div", null, h("table", { ref: el => (this.table = el), class: {
        hoverable: this.hoverable,
        'sticky-header': this.stickyHeader,
        large: this.size === 'large',
        medium: this.size === 'medium',
        small: this.size === 'small'
      } }, h("thead", null, h("tr", null, h("slot", { name: "columns" }))), h("tbody", null, h("slot", null))))));
  }
  get host() { return getElement(this); }
};
Table.style = tableCss;

export { Table as xena_table };
