import { EventEmitter } from '../../stencil-public-runtime';
import ModalHandler from '../../utils/modal-handler';
/**
 * @since 1.0
 * @status stable
 *
 * @slot - The modal's content.
 * @slot footer - The modal's footer, usually one or more buttons representing various options.
 *
 * @part base - The component's base wrapper.
 * @part overlay - The overlay.
 * @part panel - The modal panel (where the modal and its is rendered).
 * @part header - The modal header.
 * @part title - The modal title.
 * @part close-button - The close button.
 * @part body - The modal body.
 * @part footer - The modal footer.
 *
 */
export declare class Modal {
  componentId: string;
  modal: HTMLElement;
  modalHandler: ModalHandler;
  isShowing: boolean;
  panel: HTMLElement;
  host: HTMLXenaModalElement;
  hasFooter: boolean;
  /** Indicates whether or not the modal is open. You can use this in lieu of the show/hide methods. */
  open: boolean;
  /**
   * The modal's label as displayed in the header. You should always include a relevant label even when using
   * `no-header`, as it is required for proper accessibility.
   */
  label: string;
  /**
   * Set to true to disable the header. This will also remove the default close button, so please ensure you provide an
   * easy, accessible way for users to dismiss the modal.
   */
  noHeader: boolean;
  /**
   * Set to true to remove the padding in the boddy.
   */
  noBodyPadding: boolean;
  /**
   * Set to true to show a default close button in the header of the dialog.
   */
  closable: boolean;
  /**
   * Set to true to let clicks on the overlay close the dialog.
   */
  closableOverlay: boolean;
  handleOpenChange(): void;
  /** Emitted when the modal opens. Calling `event.preventDefault()` will prevent it from being opened. */
  xnShow: EventEmitter;
  /** Emitted after the modal opens and all transitions are complete. */
  xnAfterShow: EventEmitter;
  /** Emitted when the modal closes. Calling `event.preventDefault()` will prevent it from being closed. */
  xnHide: EventEmitter;
  /** Emitted after the modal closes and all transitions are complete. */
  xnAfterHide: EventEmitter;
  /** Emitted when the overlay is clicked. Calling `event.preventDefault()` will prevent the modal from closing. */
  xnOverlayDismiss: EventEmitter;
  connectedCallback(): void;
  componentWillLoad(): void;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  /** Shows the modal */
  show(): Promise<void>;
  /** Hides the modal */
  hide(): Promise<void>;
  handleCloseClick(): void;
  handleKeyDown(event: KeyboardEvent): void;
  handleOverlayClick(): void;
  handleTransitionEnd(event: TransitionEvent): void;
  updateSlots(): void;
  render(): any;
}
