# Content

XenaDS consists of four main pillars.

- Components
- Design Tokens
- Grid
- Patterns for UX

This page serves as a short description of each pillar to secure correct use of the XenaDS. The goal is to deliver a brief overview so all pillars will be taken into account before you begin developing to improve use of components with patterns that strengthen the user experience.

## Components

Components are a set of ready-to-use functional elements designed and developed with EG Xena standards. Below is an example of a simple button and the code than implements the button.

```html preview
<xena-button>Button</xena-button>
```

## Design Tokens

Design Tokens are pre-defined styles in the XenaDS stylesheet. This is to ensure consistent use of colors, margins, spacing, and typography throughout your app. Below is an example of pre-defined gray colors in XenaDS.

| Token                   | Example                                                                              |
| ----------------------- | ------------------------------------------------------------------------------------ |
| `--xena-color-white`    | <div class="color-demo" style="background-color: var(--xena-color-white);"></div>    |
| `--xena-color-gray-50`  | <div class="color-demo" style="background-color: var(--xena-color-gray-50);"></div>  |
| `--xena-color-gray-100` | <div class="color-demo" style="background-color: var(--xena-color-gray-100);"></div> |
| `--xena-color-gray-200` | <div class="color-demo" style="background-color: var(--xena-color-gray-200);"></div> |
| `--xena-color-gray-300` | <div class="color-demo" style="background-color: var(--xena-color-gray-300);"></div> |
| `--xena-color-gray-400` | <div class="color-demo" style="background-color: var(--xena-color-gray-400);"></div> |
| `--xena-color-gray-500` | <div class="color-demo" style="background-color: var(--xena-color-gray-500);"></div> |
| `--xena-color-gray-600` | <div class="color-demo" style="background-color: var(--xena-color-gray-600);"></div> |
| `--xena-color-gray-700` | <div class="color-demo" style="background-color: var(--xena-color-gray-700);"></div> |
| `--xena-color-gray-800` | <div class="color-demo" style="background-color: var(--xena-color-gray-800);"></div> |
| `--xena-color-gray-900` | <div class="color-demo" style="background-color: var(--xena-color-gray-900);"></div> |
| `--xena-color-gray-950` | <div class="color-demo" style="background-color: var(--xena-color-gray-950);"></div> |
| `--xena-color-black`    | <div class="color-demo" style="background-color: var(--xena-color-black);"></div>    |

## Grid

Though the grid layout is an important part of XenaDS the grid properties are not XenaDS specific. The documentation is included to gather all information needed in one place.

## Patterns for UX

"Patterns" are best practice solutions for how a user achieves a goal. The patterns should be used as a reference for guidelines; it's not a law and should be updated according to new discoveries and own findings to design the best user experience. The patterns will help you using the components in the right way - so keep the patterns in mind.
