# Color Tokens

Color tokens are used to maintain consistent color use throughout your app. Each color in the color scheme is carefully selected.

## Theme Colors

Theme colors are based RGB, ranging from approx. 5% to 95% lightness. There are no 0% or 100% values for theme colors. Use `--xena-color-black` and `--xena-color-white` instead.

Color groups are: Gray, cool gray, red, orange, yellow, green, mint, marine blue, blue and purple. They are used extensively throughout the library to maintain a consistent appearance across components.

### Access colors programatically

It is possible to access the colors in the Design system programmatically via the window.XenaDS.colors object.

```
console.log(XenaDS.colors.colors)
>>> ['gray', 'cool', 'red', 'orange', 'yellow', 'green', 'mint', 'marine', 'blue', 'purple']

console.log(XenaDS.colors.shades)
>>> [50, 100, 200, 300, 400, 500, 600, 700, 800, 900, 950]

console.log(XenaDS.colors.getColorShade('blue', 700));
>>> --xena-color-blue-700
```

The result from the XenaDS.colors.getColorShade method is the CSS variable name that can be used for that color.

```
var el = document.getElementById('my-element');
var color = XenaDS.colors.getColorShade('blue', 700);
el.style.background = `var(${color})`;
```

### Palette

?> Although CSS lets you override custom properties on specific elements, these values _must_ be scoped to the `:root` block for the entire palette to be recalculated. [See this page for details.](https://stackoverflow.com/questions/52015737/css-scoped-custom-property-ignored-when-used-to-calculate-variable-in-outer-scop)

|        | 50                                                                                    | 100                                                                                    | 200                                                                                    | 300                                                                                    | 400                                                                                    | 500                                                                                    | 600                                                                                    | 700                                                                                    | 800                                                                                    | 900                                                                                    | 950                                                                                    |
| ------ | ------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------- |
| gray   | <div class="color-demo" style="background-color: var(--xena-color-gray-50);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-100);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-200);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-300);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-400);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-500);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-600);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-700);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-800);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-900);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-gray-950);"></div>   |
| cool   | <div class="color-demo" style="background-color: var(--xena-color-cool-50);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-100);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-200);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-300);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-400);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-500);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-600);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-700);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-800);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-900);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-cool-950);"></div>   |
| red    | <div class="color-demo" style="background-color: var(--xena-color-red-50);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-100);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-200);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-300);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-400);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-500);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-600);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-700);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-800);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-900);"></div>    | <div class="color-demo" style="background-color: var(--xena-color-red-950);"></div>    |
| orange | <div class="color-demo" style="background-color: var(--xena-color-orange-50);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-100);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-200);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-300);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-400);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-500);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-600);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-700);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-800);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-900);"></div> | <div class="color-demo" style="background-color: var(--xena-color-orange-950);"></div> |
| yellow | <div class="color-demo" style="background-color: var(--xena-color-yellow-50);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-100);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-200);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-300);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-400);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-500);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-600);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-700);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-800);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-900);"></div> | <div class="color-demo" style="background-color: var(--xena-color-yellow-950);"></div> |
| green  | <div class="color-demo" style="background-color: var(--xena-color-green-50);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-100);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-200);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-300);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-400);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-500);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-600);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-700);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-800);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-900);"></div>  | <div class="color-demo" style="background-color: var(--xena-color-green-950);"></div>  |
| mint   | <div class="color-demo" style="background-color: var(--xena-color-mint-50);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-100);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-200);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-300);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-400);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-500);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-600);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-700);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-800);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-900);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-mint-950);"></div>   |
| marine | <div class="color-demo" style="background-color: var(--xena-color-marine-50);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-100);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-200);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-300);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-400);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-500);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-600);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-700);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-800);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-900);"></div> | <div class="color-demo" style="background-color: var(--xena-color-marine-950);"></div> |
| blue   | <div class="color-demo" style="background-color: var(--xena-color-blue-50);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-100);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-200);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-300);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-400);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-500);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-600);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-700);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-800);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-900);"></div>   | <div class="color-demo" style="background-color: var(--xena-color-blue-950);"></div>   |
| purple | <div class="color-demo" style="background-color: var(--xena-color-purple-50);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-100);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-200);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-300);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-400);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-500);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-600);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-700);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-800);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-900);"></div> | <div class="color-demo" style="background-color: var(--xena-color-purple-950);"></div> |

## Gray

| Token                   | Example                                                                              |
| ----------------------- | ------------------------------------------------------------------------------------ |
| `--xena-color-white`    | <div class="color-demo" style="background-color: var(--xena-color-white);"></div>    |
| `--xena-color-gray-50`  | <div class="color-demo" style="background-color: var(--xena-color-gray-50);"></div>  |
| `--xena-color-gray-100` | <div class="color-demo" style="background-color: var(--xena-color-gray-100);"></div> |
| `--xena-color-gray-200` | <div class="color-demo" style="background-color: var(--xena-color-gray-200);"></div> |
| `--xena-color-gray-300` | <div class="color-demo" style="background-color: var(--xena-color-gray-300);"></div> |
| `--xena-color-gray-400` | <div class="color-demo" style="background-color: var(--xena-color-gray-400);"></div> |
| `--xena-color-gray-500` | <div class="color-demo" style="background-color: var(--xena-color-gray-500);"></div> |
| `--xena-color-gray-600` | <div class="color-demo" style="background-color: var(--xena-color-gray-600);"></div> |
| `--xena-color-gray-700` | <div class="color-demo" style="background-color: var(--xena-color-gray-700);"></div> |
| `--xena-color-gray-800` | <div class="color-demo" style="background-color: var(--xena-color-gray-800);"></div> |
| `--xena-color-gray-900` | <div class="color-demo" style="background-color: var(--xena-color-gray-900);"></div> |
| `--xena-color-gray-950` | <div class="color-demo" style="background-color: var(--xena-color-gray-950);"></div> |
| `--xena-color-black`    | <div class="color-demo" style="background-color: var(--xena-color-black);"></div>    |

## Cool gray

| Token                   | Example                                                                              |
| ----------------------- | ------------------------------------------------------------------------------------ |
| `--xena-color-cool-50`  | <div class="color-demo" style="background-color: var(--xena-color-cool-50);"></div>  |
| `--xena-color-cool-100` | <div class="color-demo" style="background-color: var(--xena-color-cool-100);"></div> |
| `--xena-color-cool-200` | <div class="color-demo" style="background-color: var(--xena-color-cool-200);"></div> |
| `--xena-color-cool-300` | <div class="color-demo" style="background-color: var(--xena-color-cool-300);"></div> |
| `--xena-color-cool-400` | <div class="color-demo" style="background-color: var(--xena-color-cool-400);"></div> |
| `--xena-color-cool-500` | <div class="color-demo" style="background-color: var(--xena-color-cool-500);"></div> |
| `--xena-color-cool-600` | <div class="color-demo" style="background-color: var(--xena-color-cool-600);"></div> |
| `--xena-color-cool-700` | <div class="color-demo" style="background-color: var(--xena-color-cool-700);"></div> |
| `--xena-color-cool-800` | <div class="color-demo" style="background-color: var(--xena-color-cool-800);"></div> |
| `--xena-color-cool-900` | <div class="color-demo" style="background-color: var(--xena-color-cool-900);"></div> |
| `--xena-color-cool-950` | <div class="color-demo" style="background-color: var(--xena-color-cool-950);"></div> |

## Red

| Token                  | Example                                                                             |
| ---------------------- | ----------------------------------------------------------------------------------- |
| `--xena-color-red-50`  | <div class="color-demo" style="background-color: var(--xena-color-red-50);"></div>  |
| `--xena-color-red-100` | <div class="color-demo" style="background-color: var(--xena-color-red-100);"></div> |
| `--xena-color-red-200` | <div class="color-demo" style="background-color: var(--xena-color-red-200);"></div> |
| `--xena-color-red-300` | <div class="color-demo" style="background-color: var(--xena-color-red-300);"></div> |
| `--xena-color-red-400` | <div class="color-demo" style="background-color: var(--xena-color-red-400);"></div> |
| `--xena-color-red-500` | <div class="color-demo" style="background-color: var(--xena-color-red-500);"></div> |
| `--xena-color-red-600` | <div class="color-demo" style="background-color: var(--xena-color-red-600);"></div> |
| `--xena-color-red-700` | <div class="color-demo" style="background-color: var(--xena-color-red-700);"></div> |
| `--xena-color-red-800` | <div class="color-demo" style="background-color: var(--xena-color-red-800);"></div> |
| `--xena-color-red-900` | <div class="color-demo" style="background-color: var(--xena-color-red-900);"></div> |
| `--xena-color-red-950` | <div class="color-demo" style="background-color: var(--xena-color-red-950);"></div> |

## Orange

| Token                     | Example                                                                                |
| ------------------------- | -------------------------------------------------------------------------------------- |
| `--xena-color-orange-50`  | <div class="color-demo" style="background-color: var(--xena-color-orange-50);"></div>  |
| `--xena-color-orange-100` | <div class="color-demo" style="background-color: var(--xena-color-orange-100);"></div> |
| `--xena-color-orange-200` | <div class="color-demo" style="background-color: var(--xena-color-orange-200);"></div> |
| `--xena-color-orange-300` | <div class="color-demo" style="background-color: var(--xena-color-orange-300);"></div> |
| `--xena-color-orange-400` | <div class="color-demo" style="background-color: var(--xena-color-orange-400);"></div> |
| `--xena-color-orange-500` | <div class="color-demo" style="background-color: var(--xena-color-orange-500);"></div> |
| `--xena-color-orange-600` | <div class="color-demo" style="background-color: var(--xena-color-orange-600);"></div> |
| `--xena-color-orange-700` | <div class="color-demo" style="background-color: var(--xena-color-orange-700);"></div> |
| `--xena-color-orange-800` | <div class="color-demo" style="background-color: var(--xena-color-orange-800);"></div> |
| `--xena-color-orange-900` | <div class="color-demo" style="background-color: var(--xena-color-orange-900);"></div> |
| `--xena-color-orange-950` | <div class="color-demo" style="background-color: var(--xena-color-orange-950);"></div> |

## Yellow

| Token                     | Example                                                                                |
| ------------------------- | -------------------------------------------------------------------------------------- |
| `--xena-color-yellow-50`  | <div class="color-demo" style="background-color: var(--xena-color-yellow-50);"></div>  |
| `--xena-color-yellow-100` | <div class="color-demo" style="background-color: var(--xena-color-yellow-100);"></div> |
| `--xena-color-yellow-200` | <div class="color-demo" style="background-color: var(--xena-color-yellow-200);"></div> |
| `--xena-color-yellow-300` | <div class="color-demo" style="background-color: var(--xena-color-yellow-300);"></div> |
| `--xena-color-yellow-400` | <div class="color-demo" style="background-color: var(--xena-color-yellow-400);"></div> |
| `--xena-color-yellow-500` | <div class="color-demo" style="background-color: var(--xena-color-yellow-500);"></div> |
| `--xena-color-yellow-600` | <div class="color-demo" style="background-color: var(--xena-color-yellow-600);"></div> |
| `--xena-color-yellow-700` | <div class="color-demo" style="background-color: var(--xena-color-yellow-700);"></div> |
| `--xena-color-yellow-800` | <div class="color-demo" style="background-color: var(--xena-color-yellow-800);"></div> |
| `--xena-color-yellow-900` | <div class="color-demo" style="background-color: var(--xena-color-yellow-900);"></div> |
| `--xena-color-yellow-950` | <div class="color-demo" style="background-color: var(--xena-color-yellow-950);"></div> |

## Green

| Token                    | Example                                                                               |
| ------------------------ | ------------------------------------------------------------------------------------- |
| `--xena-color-green-50`  | <div class="color-demo" style="background-color: var(--xena-color-green-50);"></div>  |
| `--xena-color-green-100` | <div class="color-demo" style="background-color: var(--xena-color-green-100);"></div> |
| `--xena-color-green-200` | <div class="color-demo" style="background-color: var(--xena-color-green-200);"></div> |
| `--xena-color-green-300` | <div class="color-demo" style="background-color: var(--xena-color-green-300);"></div> |
| `--xena-color-green-400` | <div class="color-demo" style="background-color: var(--xena-color-green-400);"></div> |
| `--xena-color-green-500` | <div class="color-demo" style="background-color: var(--xena-color-green-500);"></div> |
| `--xena-color-green-600` | <div class="color-demo" style="background-color: var(--xena-color-green-600);"></div> |
| `--xena-color-green-700` | <div class="color-demo" style="background-color: var(--xena-color-green-700);"></div> |
| `--xena-color-green-800` | <div class="color-demo" style="background-color: var(--xena-color-green-800);"></div> |
| `--xena-color-green-900` | <div class="color-demo" style="background-color: var(--xena-color-green-900);"></div> |
| `--xena-color-green-950` | <div class="color-demo" style="background-color: var(--xena-color-green-950);"></div> |

## Mint green

| Token                   | Example                                                                              |
| ----------------------- | ------------------------------------------------------------------------------------ |
| `--xena-color-mint-50`  | <div class="color-demo" style="background-color: var(--xena-color-mint-50);"></div>  |
| `--xena-color-mint-100` | <div class="color-demo" style="background-color: var(--xena-color-mint-100);"></div> |
| `--xena-color-mint-200` | <div class="color-demo" style="background-color: var(--xena-color-mint-200);"></div> |
| `--xena-color-mint-300` | <div class="color-demo" style="background-color: var(--xena-color-mint-300);"></div> |
| `--xena-color-mint-400` | <div class="color-demo" style="background-color: var(--xena-color-mint-400);"></div> |
| `--xena-color-mint-500` | <div class="color-demo" style="background-color: var(--xena-color-mint-500);"></div> |
| `--xena-color-mint-600` | <div class="color-demo" style="background-color: var(--xena-color-mint-600);"></div> |
| `--xena-color-mint-700` | <div class="color-demo" style="background-color: var(--xena-color-mint-700);"></div> |
| `--xena-color-mint-800` | <div class="color-demo" style="background-color: var(--xena-color-mint-800);"></div> |
| `--xena-color-mint-900` | <div class="color-demo" style="background-color: var(--xena-color-mint-900);"></div> |
| `--xena-color-mint-950` | <div class="color-demo" style="background-color: var(--xena-color-mint-950);"></div> |

## Marine blue

| Token                     | Example                                                                                |
| ------------------------- | -------------------------------------------------------------------------------------- |
| `--xena-color-marine-50`  | <div class="color-demo" style="background-color: var(--xena-color-marine-50);"></div>  |
| `--xena-color-marine-100` | <div class="color-demo" style="background-color: var(--xena-color-marine-100);"></div> |
| `--xena-color-marine-200` | <div class="color-demo" style="background-color: var(--xena-color-marine-200);"></div> |
| `--xena-color-marine-300` | <div class="color-demo" style="background-color: var(--xena-color-marine-300);"></div> |
| `--xena-color-marine-400` | <div class="color-demo" style="background-color: var(--xena-color-marine-400);"></div> |
| `--xena-color-marine-500` | <div class="color-demo" style="background-color: var(--xena-color-marine-500);"></div> |
| `--xena-color-marine-600` | <div class="color-demo" style="background-color: var(--xena-color-marine-600);"></div> |
| `--xena-color-marine-700` | <div class="color-demo" style="background-color: var(--xena-color-marine-700);"></div> |
| `--xena-color-marine-800` | <div class="color-demo" style="background-color: var(--xena-color-marine-800);"></div> |
| `--xena-color-marine-900` | <div class="color-demo" style="background-color: var(--xena-color-marine-900);"></div> |
| `--xena-color-marine-950` | <div class="color-demo" style="background-color: var(--xena-color-marine-950);"></div> |

## Blue

| Token                   | Example                                                                              |
| ----------------------- | ------------------------------------------------------------------------------------ |
| `--xena-color-blue-50`  | <div class="color-demo" style="background-color: var(--xena-color-blue-50);"></div>  |
| `--xena-color-blue-100` | <div class="color-demo" style="background-color: var(--xena-color-blue-100);"></div> |
| `--xena-color-blue-200` | <div class="color-demo" style="background-color: var(--xena-color-blue-200);"></div> |
| `--xena-color-blue-300` | <div class="color-demo" style="background-color: var(--xena-color-blue-300);"></div> |
| `--xena-color-blue-400` | <div class="color-demo" style="background-color: var(--xena-color-blue-400);"></div> |
| `--xena-color-blue-500` | <div class="color-demo" style="background-color: var(--xena-color-blue-500);"></div> |
| `--xena-color-blue-600` | <div class="color-demo" style="background-color: var(--xena-color-blue-600);"></div> |
| `--xena-color-blue-700` | <div class="color-demo" style="background-color: var(--xena-color-blue-700);"></div> |
| `--xena-color-blue-800` | <div class="color-demo" style="background-color: var(--xena-color-blue-800);"></div> |
| `--xena-color-blue-900` | <div class="color-demo" style="background-color: var(--xena-color-blue-900);"></div> |
| `--xena-color-blue-950` | <div class="color-demo" style="background-color: var(--xena-color-blue-950);"></div> |

## Purple

| Token                     | Example                                                                                |
| ------------------------- | -------------------------------------------------------------------------------------- |
| `--xena-color-purple-50`  | <div class="color-demo" style="background-color: var(--xena-color-purple-50);"></div>  |
| `--xena-color-purple-100` | <div class="color-demo" style="background-color: var(--xena-color-purple-100);"></div> |
| `--xena-color-purple-200` | <div class="color-demo" style="background-color: var(--xena-color-purple-200);"></div> |
| `--xena-color-purple-300` | <div class="color-demo" style="background-color: var(--xena-color-purple-300);"></div> |
| `--xena-color-purple-400` | <div class="color-demo" style="background-color: var(--xena-color-purple-400);"></div> |
| `--xena-color-purple-500` | <div class="color-demo" style="background-color: var(--xena-color-purple-500);"></div> |
| `--xena-color-purple-600` | <div class="color-demo" style="background-color: var(--xena-color-purple-600);"></div> |
| `--xena-color-purple-700` | <div class="color-demo" style="background-color: var(--xena-color-purple-700);"></div> |
| `--xena-color-purple-800` | <div class="color-demo" style="background-color: var(--xena-color-purple-800);"></div> |
| `--xena-color-purple-900` | <div class="color-demo" style="background-color: var(--xena-color-purple-900);"></div> |
| `--xena-color-purple-950` | <div class="color-demo" style="background-color: var(--xena-color-purple-950);"></div> |
