# Communication

Text and messages that the user see and read, is considered "communication". Communicate in a clear and easy-to-understand way.

## Text

- Ensure your texts are clear and natural.
- Check your spelling.
- Write in the present tense: "Message sent", not "Message has been sent".
- Avoid using humor or jokes.
- Don't invent new terms for common features. For example, do not say "deactivate" when you mean "delete".
- Consider the context. Avoid extra words, like "Save changes", when "Save" is sufficient. On the other hand, just writing "Create" can be too vague. Be more precise by writing _what_ will be created: "New article".
- Stick to the accepted way of writing common expressions. For example, "OK" is the accepted version, not "Okay" or "Ok".
- Avoid combining first and second person in the same sentence, for example: "Change _your_ preferences in _My_ Account".

### Punctuation

- Avoid using periods on standalone sentences for example in headers, labels, hover text, bulleted lists and body text.
- Don't use colons after labels.

## Colors

Stick to the [colors specified in the design system](tokens/color.md).

- Do not use different colors for the sake of decoration.
- Do use "success" for completed actions.
- Do use "danger" for destructive actions or errors.

## Primary action

There should only be one primary action per view. The primary action is the [button](components/button.md) that takes the user to the next step in the process/the action most people will use. This button is

## Help texts

Give the user the needed information on how to complete the task. A short, single paragraph can be very helpful. To give even more information, use [help texts for inputs](components/input.md?id=help-text). At times, an [inline alert](components/alert.md?id=inline) can give needed attention to a specific instruction.

```html preview
<div class="grid grid-cols-2 gap-5">
  <xena-card appearance="outline">
    <xena-card-header><b slot="title">Good example</b></xena-card-header>
    <p class="my-1">Enable contact via SMS by adding a phone number.</p>
    <xena-input label="Phone number" help-text="The country code must match the partner's country"
      ><span slot="prefix">+45</span></xena-input
    >
    <xena-button slot="footer" type="primary">OK</xena-button>
    <xena-button slot="footer" type="default">Cancel</xena-button>
  </xena-card>
  <xena-card appearance="outline">
    <xena-card-header><b slot="title">Bad example</b></xena-card-header>
    <xena-alert type="warning" class="mb-3" open
      >The phone number must be in the same country as the partner's country.</xena-alert
    >
    <xena-input><span slot="prefix">+45</span></xena-input>
    <xena-button slot="footer" type="primary">OK</xena-button>
    <xena-button slot="footer" type="default">Cancel</xena-button>
  </xena-card>
</div>
```

The good example

- is having a simple sentence explaining the purpose of the form.
- is having proper label and help text for the input.

The bad example

- is missing indication of what the goal is.
- has an unnecessary alert.
- is missing a label for the input.

## Icons, states, and actions

This is a list of states and actions with their appropriate icons. You are not limited to use the examples below, but they will help you find the most fitting terms and icons for buttons and labels. Context will determine if the state and/or action is "danger", "success" or another type.

### Reserved icons

These icons are used for specific features in EG Xena. Please only use these icons for the same purposes.

| Icon                                                                 | Reserved for          |
| -------------------------------------------------------------------- | --------------------- |
| <xena-icon name="fas-home"></xena-icon> `home`                       | Company/fiscal        |
| <xena-icon name="fas-book"></xena-icon> `book`                       | Finance               |
| <xena-icon name="fas-chart-line"></xena-icon> `chart-line`           | Reports               |
| <xena-icon name="fas-money-bill"></xena-icon> `money-bill`           | Sales                 |
| <xena-icon name="fas-shopping-cart"></xena-icon> `shopping-cart`     | Purchase              |
| <xena-icon name="fas-balance-scale"></xena-icon> `balance-scale`     | Auditor               |
| <xena-icon name="fas-puzzle-piece"></xena-icon> `puzzle-piece`       | Apps and integrations |
| <xena-icon name="fas-file-invoice"></xena-icon> `file-invoice`       | Invoice/invoiced      |
| <xena-icon name="fas-arrow-right"></xena-icon> `arrow-right`         | Navigation forward    |
| <xena-icon name="fas-arrow-left"></xena-icon> `arrow-left`           | Navigation backward   |
| <xena-icon name="fas-edit"></xena-icon> `edit`                       | Edit                  |
| <xena-icon name="fas-save"></xena-icon> `save`                       | Save                  |
| <xena-icon name="fas-ellipsis-h"></xena-icon> `ellipsis-h`           | Context menu          |
| <xena-icon name="fas-question-circle"></xena-icon> `question-circle` | Help/support          |

### Data handling

| Icon                                                       | If something is (State) | Icon                                                        | You can (Action) |
| ---------------------------------------------------------- | ----------------------- | ----------------------------------------------------------- | ---------------- |
| <xena-icon name="fas-sync"></xena-icon> `sync`             | Active                  | <xena-icon name="fas-pause"></xena-icon> `pause`            | Stop             |
| <xena-icon name="fas-pause"></xena-icon> `pause`           | Inactive                | <xena-icon name="fas-play"></xena-icon> `play`              | Start            |
| <xena-icon name="fas-lock"></xena-icon> `lock`             | Locked                  | <xena-icon name="fas-unlock"></xena-icon> `unlock`          | Unlock           |
| <xena-icon name="fas-lock-open"></xena-icon> `lock-open`   | Unlocked                | <xena-icon name="fas-lock"></xena-icon> `lock`              | Lock             |
| <xena-icon name="fas-cloud-upload-alt"></xena-icon> `sync` | Published               | <xena-icon name="fas-ban"></xena-icon> `pause`              | Unpublish        |
| <xena-icon name="fas-ban"></xena-icon> `sync`              | Unpublished             | <xena-icon name="fas-cloud-upload-alt"></xena-icon> `pause` | Publish          |
| n/a                                                        | Created                 | <xena-icon name="fas-trash"></xena-icon> `trash`            | Delete           |
| n/a                                                        | Deleted                 | <xena-icon name="fas-undo"></xena-icon> `undo`              | Restore          |
| n/a                                                        | Added                   | <xena-icon name="fas-times"></xena-icon> `times`            | Remove           |
| n/a                                                        | Removed                 | <xena-icon name="fas-plus"></xena-icon> `plus`              | Add/create       |

### Mechanics

| Icon                                           | If something is (State) | Icon                                                                     | You can (Action) |
| ---------------------------------------------- | ----------------------- | ------------------------------------------------------------------------ | ---------------- |
| n/a                                            | Opened/Open             | <xena-icon name="fas-times"></xena-icon> `times`                         | Close            |
| n/a                                            | Closed                  | <xena-icon name="fas-external-link-alt"></xena-icon> `external-link-alt` | Open             |
| n/a                                            | Collapsed               | <xena-icon name="fas-chevron-down"></xena-icon> `chevron-down`           | Expand           |
| n/a                                            | Expanded                | <xena-icon name="fas-chevron-up"></xena-icon> `chevron-up`               | Collapse         |
| n/a                                            | Hidden                  | <xena-icon name="fas-eye"></xena-icon> `eye`                             | Show             |
| n/a                                            | Visible                 | <xena-icon name="fas-eye-slash"></xena-icon> `eye-slash`                 | Hide             |
| <xena-icon name="fas-link"></xena-icon> `link` | Linked                  | <xena-icon name="fas-unlink"></xena-icon> `unlink`                       | Unlink           |
| n/a                                            | Not linked              | <xena-icon name="fas-link"></xena-icon> `link`                           | Link             |
| n/a                                            | Related                 | <xena-icon name="fas-arrow-right"></xena-icon> `arrow-right`             | Go to …          |
| n/a                                            | Split                   | <xena-icon name="fas-object-group"></xena-icon> `object-group`           | Merge            |
| n/a                                            | Merged                  | <xena-icon name="fas-object-ungroup"></xena-icon> `object-ungroup`       | Split            |
| n/a                                            | Signed in               | <xena-icon name="fas-sign-out-alt"></xena-icon> `sign-out-alt`           | Sign out         |
| n/a                                            | Signed out              | <xena-icon name="fas-sign-in-alt"></xena-icon> `sign-in-alt`             | Sign in          |
| n/a                                            | Not installed           | n/a                                                                      | Install          |
| n/a                                            | Installed               | n/a                                                                      | Uninstall        |

### Temporary state

| Icon                                                                           | Temporary state                       |
| ------------------------------------------------------------------------------ | ------------------------------------- |
| <xena-icon name="fas-hourglass-half"></xena-icon> `hourglass-half`             | Awaiting [fx delivery, approval etc.] |
| <xena-icon name="fas-spinner-third"></xena-icon> `spinner-third`               | Loading…                              |
| <xena-icon name="fas-exclamation-triangle"></xena-icon> `exclamation-triangle` | Error                                 |
| <xena-icon name="fas-check"></xena-icon> `check`                               | Saved                                 |
| <xena-icon name="fas-info-circle"></xena-icon> `info-circle`                   | Important                             |

?> See all available icons in [components > icon](components/icon.md).
