# Dialogs

A dialog is an UI element displaying on top of all other content. It facilitates a "conversation" between the system and the user.

There are two types of dialogs:

- **Modal:** The dialog blocks interaction with the main content, requests the user's attention and are requiring user interaction.
- **Non-modal:** The dialog does not disable the main content and does not necessarily require any action.

Dialogs are great for short, relevant tasks because they are close to the context and are less disorientating than navigating to another page. However, dialogs are disruptive and can confuse the user if they popup unsuspected.

## Dialog layout

![A dialog with the header, body, footer, and backdrop marked with numbers 1 to 4.][def1]

1. **Header:** Contains a mandatory title and an optional close button. The title briefly and clearly describes the dialogs task or purpose.
2. **Body:** The content of the dialog to fulfill the task or purpose. If the content is longer than the screen height, the body will have scroll.
3. **Footer:** Contains the action buttons. The first button is the primary action. Use descriptive words for the actions, like "Create", "Delete", "Save" and avoid vague words like "Done" or "OK".
4. **Backdrop:** For modal dialogs, a backdrop (or "overlay") gray out the main content and prevent interaction with it, while the dialog is open.

### Dialog types

- **Informative:** Information from the system. Contains only a single button to dismiss the dialog, commonly "OK".
- **Transactional:** Requires an action to be taken for the modal to be completed and closed. Contains a cancel and primary action buttons. For example, the dialog for creating a new order.
- **Wizard:** Requires several steps to be completed. Often includes input fields and other interactive components like checkboxes and dropdowns. Contains buttons for cancel, previous, and next/completion. For example, the dialog for creating a new fiscal.

For warnings, errors, and other system notification, see the pattern [Notifications](/ux-guide/notifications.md).

### Opening a dialog

Dialogs should only appear when part of a process initiated by the user, for example clicking a button.

![A dialog is opened only after a button is clicked.][def2]

Don’t nest dialogs. One modal should never trigger another modal.

![Illustration of a dialog overlaying another dialog.][def3]

### Closing a dialog

There are multiple ways to close or dismiss a dialog.

- **Close button:** Clicking the close button in the header.
- **Primary action complete:** Completing the task by clicking the primary button in the footer.
- **Cancel:** A cancel button in the footer.
- **Esc:** Pressing the ESC key.
- **Clicking elsewhere:** (Information dialogs only) Clicking the backdrop can close the dialog.

## When to use dialogs

!> Use dialogs sparingly; you are of cause allowed to use them, but be thoughtful about when and how.

**Use dialogs to …**

- Request critical information to continue the process.
- Prevent or correct errors.
- Ease the user's workload.

**Avoid dialogs for …**

- Complex forms and decision making.
- Processes requiring additional information found elsewhere.

!> **Do not** use `xena-modal` to confirm actions. Instead, use [alert dialogs](components/alert.md?id=alert-and-confirm-dialogs).

## Accessibility

### Focus

1. When triggering a dialog, focus should shift to the first interactive element in the dialog.
2. For modal dialogs, focus is trapped inside the dialog.
3. After a modal close, return focus to the element that triggered the dialog (if still available).

## Further reading and inspiration

- [Modal & Nonmodal Dialogs: When (& When Not) to Use Them](https://www.nngroup.com/articles/modal-nonmodal-dialog/)
- [Focus order success criterion](https://www.w3.org/TR/UNDERSTANDING-WCAG20/navigation-mechanisms-focus-order.html)
- [Modal alternatives](https://modalzmodalzmodalz.com/)

[def1]: ../assets/patterns/dialog_anatomy.jpg
[def2]: ../assets/patterns/dialog_openafterclick.svg
[def3]: ../assets/patterns/dialog_nesting.svg
