# Forms

A form is a collection of inputs and settings, the user fills out and then submits to the system. See for example the components [button](/components/button), [checkbox](/components/checkbox), [input](/components/input), [radio](/components/radio) and [select](/components/select).

Forms in EG Xena are often seen when creating or editing orders, partners or alike. But the principles outlined here also apply for single standalone input, like in-context search.

## Form layout

![A form with multiple input fields.][def0]

1. **Header (optional):** Provides context and additional instructions.
2. **Form body:** Area where the user adds the requested information. Labels and help texts guide the user to submit correct data.
3. **Footer:** Buttons to submit the form or cancel it. The action buttons are always at the end of the form.

The above example has a form inside a modal and with multiple steps.

## Alignment and columns

Most often, form inputs are aligned in one column. In some cases, it makes visually sense to have two columns. For example, when entering an address.

![Illustration of two forms: One has all inputs in one column, the other is divided in two columns.][def1]

## Best practices

### Labels

A precise label helps users understand what information to enter. Text fields should always have a label. Do not use colons after label names.

![Illustration of two text input fields: The first has a label of "First name", the other has no label at all.][def2]

In rare circumstances the design may call for a label-less input (maybe an icon is used instead). In cases like this a visually hidden label or the title attribute could be used. But check with accessibility consultants, what works best.

### Default values

When possible, the system can prefill inputs to reduce errors and save time. Other inputs, especially number inputs, have a valid range. Specifying these minimum and/or maximum values can reduce errors.

### Helper text

Persistent text that assists the user in correctly completing a field. It is often used to explain the correct data format. Helper text that appears underneath the field is replaced by an error or warning message if the state changes.

![An input field labeled "Account number". Underneath is a help text, saying "Must be between 6 and 8 digits long".][def3]

### Placeholder text

Optional placeholder text gives an idea or example of the expected data format. It should not be used as a replacement for a label, nor should it contain crucial information.

![Illustration of two input fields: The first is labeled "Zip code" and has placeholder text saying "For example 9000". The other has no label but the placeholder text says "Zip code".][def4]

### Errors and validation

If possible, validation of input fields should always be triggered when the user leaves the input field. This is called "late validation". Alternatively validation should be triggered when the user submits the form. Don't validate the input before the user is done typing it unless it helps the user e.g. showing strength when choosing a password.

Error messages should tell how to fix the error, be in plain language, be in a positive tone and get to the point.

![Illustration of four input fields: First has a good error message of "Must be a four digit number", where the other has a less good message of "Enter a valid zip code". The next input has a good error message of "Enter an email address in the correct format, like name@example.com", and the other has a less useful message of "The email in invalid".][def5]

Input fields should also be validated if the user leaves required input fields without giving any input.

![Illustration of one unput field left without any input. It shows an error message of "Please enter an e-mail.][def6]

## Further reading and inspiration

- [Different types of input validation](https://www.smashingmagazine.com/2022/09/inline-validation-web-forms-ux/)
- [Help users to recover from validation errors](https://design-system.service.gov.uk/patterns/validation/)
- [Form validation and screen readers](https://a11yrules.com/podcast/justin-yarbrough-talks-about-form-validation-and-screen-readers/)
- [Error messages](https://design-system.service.gov.uk/components/error-message/)

[def0]: ../assets/patterns/form_anatomy.jpg
[def1]: ../assets/patterns/form_layout.svg
[def2]: ../assets/patterns/form_labels.svg
[def3]: ../assets/patterns/form_help.svg
[def4]: ../assets/patterns/form_placeholder.svg
[def5]: ../assets/patterns/form_validation.svg
[def6]: ../assets/patterns/form_touched.svg
