# Guideline for tables

## When to use tables

> "Information is considered tabular when logical relationships among text, numbers, images, or other data exist in two dimensions (vertical and horizontal)." – [W3C](https://www.w3.org/TR/WCAG20-TECHS/H51)

**Do use** a table when there are logical relations vertically and horizontally. Here is an example of a simple table with data:

<xena-table>
<xena-column>Article</xena-column>
<xena-column alignment="right">Price</xena-column>
<xena-column>In stock</xena-column>
<xena-row>
<xena-cell>Apple</xena-cell>
<xena-cell alignment="right">5,95</xena-cell>
<xena-cell>Yes</xena-cell>
</xena-row>
<xena-row>
<xena-cell>Orange</xena-cell>
<xena-cell alignment="right">7,95</xena-cell>
<xena-cell>Yes</xena-cell>
</xena-row>
</xena-table>

<div class="grid grid-cols-2 gap-8">
<div>

**Don't** use a table when a list is more appropriate.

<xena-table>
<xena-column>My fiscals</xena-column>
<xena-row><xena-cell>Fiscal 1</xena-cell></xena-row>
<xena-row><xena-cell>Fiscal 2</xena-cell></xena-row>
</xena-table>

</div>
<div>

**Don't** use a table to layout content on a page.

<xena-table>
<xena-column width="70%">Latest news</xena-column>
<xena-column width="30%">Contact us</xena-column>
<xena-row>
<xena-cell><b>NEW: A new component is available</b><br>Learn all about the new component here<br><a>Link</a></xena-cell>
<xena-cell>You can contact us on all social media</xena-cell>
</xena-row>
</xena-table>

</div>
</div>

## How to format a table and its data

The [XenaDS table element](/components/table.md) provides a variety of features to optimize the data presentation. These are described on the table component page. The following content is some advice on best practices.

### Table headers

Name the columns in a way it becomes natural to read the data, also with a screen reader. Column titles should stick to one or two words that describe the data in that column.

- Bad column titles: "Name of article", "The price of the article"
- Better column titles: "Article", "Price"

Well-named column titles will help screen reader users to comprehend the content. For example, a screen reader would say: "Row 2, column 2: Price: 100,00"

For large, complex data tables, having sticky headers can be helpful to understand the content.

If the data can support it, you can have sub header as dividers. For example, a long list of contacts sorted alphabetically, can have sub headers for the letters A, B, C, etc.

Some data sets can have row headers (instead of or along with column headers).

One header can span multiple columns.

### Table rows

To help the user scan the data, borders are separating each row.

If the table is long and wide, added row hover effect will help the user read the data.

For large but simple/less important tables, making the table row more compact can help users glance the data.

On the other hand, a less compact table row can help the user separate the lines. This is better for more complex tables.

### Table cells

For <abbr title="Left to right">LTR</abbr> languages, the standard alignment in table cells is left. But numbers are mostly aligned to the right, to make them easier to compare.

A column should have the same alignment in its headers and cells.

A cell can span multiple columns, using `colspan`.
